/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03023
 |             COOPERATIVE AGREEMENT FOR AIDS COMMUNITY-BASED
 |           OUTREACH/INTERVENTION RESEARCH PROGRAM, 1992-1998
 |                      (DATASET 0002: PROCESS DATA)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03023-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE sitecode  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si1fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si2fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si3fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si4fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si5fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si6_1fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si6_2fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si7_1fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si7_2fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si7_3fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si7_4fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si7_5fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si8fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si9fffff  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE si10_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si10b_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si11ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si12_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si12_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si13ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si14ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si15ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si16ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si17ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si18ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si19ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si20ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si21ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si22_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER' 1='1=SOME' 2='2=ALWAYS' ;
  VALUE si22_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si23ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si24ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si25ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si26ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si27ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si28ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si29ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si30ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si31ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si32ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si32a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si33ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si34ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si35ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si36ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si37ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si38ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si39ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si40ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si40a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si40b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si40c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si40d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si41ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si42ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43e     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si43f     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si44ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si45ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si46ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si47ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si48ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si48_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si48_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si49ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si49a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si49_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si49_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si50ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si50a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si50a_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si50a_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si51_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si51_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si52_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si52_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si54ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si55ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si55a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si55b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si55c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si55d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si56ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si57ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si58ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si59ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si60ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si61ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si62ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si62a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si62b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si62c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si62d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si63ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si64ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si65ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si65a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si66ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si67ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si68ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si68_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si68_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si69ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si69a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si70ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si71ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si72_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si72_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si73ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si74ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si75ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si76_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si76_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si77ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si78a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si78b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si78c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si78a_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si78a_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si78a_3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si79ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si80ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si81ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si82ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si83ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si84ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si85_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si85_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si87ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si88ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si89ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si90ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si91ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si92ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si93ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si94ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si94a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si94b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si94c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si94d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si95ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si96ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si97ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si98ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si100fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si100a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si100b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si101fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si102fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si102b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si102c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si103fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si104fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si105fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si105a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si105b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si105c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si106fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si107fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si108fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si109fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si109a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si110fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si111fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si111a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si112fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si113_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si113_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si114_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si114_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si115_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si115_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si116fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si117fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si118fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si119fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si120fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si120a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si120b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si120c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si120d    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si121fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si122fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si123fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si124fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si125fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si126fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si127fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si128fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si129_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si129_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si129_3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si130fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si131fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si132fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si133fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si134_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si134_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si134_3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si135fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si136fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si137fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si137a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si138fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si138a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si139fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si139a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si140fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si141fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si141a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si142fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si143fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si144fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si145fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si145a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si146fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si147a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si147b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si147c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si147a_f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si147a0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si147a1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si148fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si149fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si150fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si151_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si151_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si153fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si154fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si155fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si156_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si156_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si156_3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si157fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si158fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si159fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si160fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si160a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si161fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si161a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si162fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si162a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=A' 2='2=B' 3='3=OTHER' ;
  VALUE si163fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si164fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si164a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si165fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si166fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si167fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si168fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' 2='2=OPTIONAL' ;
  VALUE si168a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si169fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si170a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si170b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si170c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si170a_f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si170a0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si170a1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si171fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si172fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si173fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si174_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si174_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = $0' 10='10 = $10'
                  12='12 = $12' 15='15 = $15' 20='20 = $20' 25='25 = $25' ;
  VALUE si176fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si177fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si177a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si178fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si178a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si179fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si180fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si180a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si181fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si182fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si182a    -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE si183fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si184fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si185fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si186fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si187fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si188fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si189fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si190fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si191fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si192_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si192_2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si192_3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si193fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si194fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si195fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si196fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si197fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si198fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si199fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si200_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si200a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si201_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si202_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si203_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si204_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si205_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si206_1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si208fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si209fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si210fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si211fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si212fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si213fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si215fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si216fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si217fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si217a_f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si217a0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si217a1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si217b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si218fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si218a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si218b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE si218c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si218d_f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si218d0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE si218d1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sesadur   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sesbdur   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sesaodur  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sesbodur  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE outdur    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE distribf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE distinj   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE distsex   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehndla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehcndma  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehalla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehndlb   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehcndmb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rehallb   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sidemoa   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sidemob   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sirhsla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sirhslb   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis1ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis2a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE sis2b     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE sis2c     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE sis2d     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE sis3ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis4ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis5ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis6ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis7ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis8ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis9ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis9a     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis10fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis11fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis12fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis12a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis13fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis14fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis15fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis16fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis17fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis17a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis18fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis19fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis20fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis21fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis22fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis23fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis24fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis25fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis26fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis27fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis28fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis29fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis30fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis31fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis32fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis33fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis34fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis35fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis36a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis36b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis36c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis37a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis37b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis37c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis38fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis39fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis40fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis41fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis42fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis43fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis43a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis44fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis45fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis46fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis47fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis48fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis49fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis50fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis51fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis52fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis53fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis54fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis55fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis56fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis57fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis58fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis59fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis60fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis61fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis62a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis62b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis62c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis63a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis63b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis63c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis64fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis65fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis66fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis67fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis68fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis69fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis69a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis70fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis71fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=YES, ALL CLIENTS'
                  2='2=YES, WOMEN CLIENTS ONLY' 3='3=NO' ;
  VALUE sis72fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis73fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis74fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis75fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis76fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis77fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis78fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis79fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis80fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis81fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis82fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis83fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis84fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis85fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis86fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis87fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis88a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis88b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis88c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis89a    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis89b    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis89c    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE sis90fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis91fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis92fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis93fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis94fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis95fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis96fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis97fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis98fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis99fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis100ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis101ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis102ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis103a   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis103b   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis103c   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis106ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis107ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis108ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis109ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis110ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis111ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis112ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis113ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis114ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis115ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis116ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis117a   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis117b   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis117c   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis120ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis121ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis122ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis123ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis124ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis125ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis126ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis127ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis128ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis129ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis130ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NEVER'
                  1='1=OCCASIONALLY/ON REQUEST' 2='2=ROUTINELY' ;
  VALUE sis131a   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis131b   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis131c   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE sis134ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis135ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis136ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis137ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis138ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis139ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis140ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis141ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE sis142ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL' 2='2=SMALL'
                  3='3=MODERATE' 4='4=LARGE' 5='5=VERY LARGE' ;
  VALUE einum     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei1fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei2_1fff  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ei2_2fff  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ei2_3fff  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ei2_4fff  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ei2_5fff  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ei2_6fff  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ei3a_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei3a_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei3a_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei3a_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei3b      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=STRUCTURE'
                  2='2=SEMI-STRUCTURE' 3='3=FLEXIBLE' ;
  VALUE ei4a_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei4a_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei4b_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei4b_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei4b_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei4b_6ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei5_1fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei5_2fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei6fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=AT THE SAME TIME'
                  2='2=8-14 DAYS AFTER' 3='3=15 OR MORE DAYS' ;
  VALUE ei7a_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_6ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_7ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_8ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_9ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_10f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_11f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7a_12f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_6ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_7ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_8ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_9ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei7b_10f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_6ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_7ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_8ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_9ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_10f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_11f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_12f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_13f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8a_14f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8b_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8b_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8b_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei8b_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei9fffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ei10ffff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=SOME' 2='2=ALL' ;
  VALUE ei11_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_6ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_7ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_8ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_9ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_10f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_11f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_12f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_13f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_14f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei11_15f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT IMPORTANT'
                  1='1=SLIGHTLY IMPORTANT' 2='2=SOMEWHAT IMPORTANT'
                  3='3=VERY IMPORTANT' ;
  VALUE ei12_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ei14_1ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE ei14_2ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE ei14_3ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE ei14_4ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE ei14_5ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT CHECKED' 1='1=CHECKED' ;
  VALUE eidemo    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eirhsl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eiacta    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eiactb    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eidista   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eidistb   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eidur     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eiadur    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eibdur    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eiaodur   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eibodur   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE eiind     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = NO' 1='1 = YES' ;
  VALUE eicouple  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = NO' 1='1 = YES' ;
  VALUE eigroup   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0 = NO' 1='1 = YES' ;
  VALUE xdamc     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE aintcou   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintedu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintboth  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintoth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintsp    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=INTERACTIVE APPROACH'
                  2='2=FACILITATION/REFERRALS' 3='3=NEITHER' ;
  VALUE aintav    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aavvideo  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aavhand   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aavother  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aavsp     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=PHOTOS DEMO NEEDLE CLNG'
                  2='2=CULTURAL APPROP. VISUAL AIDS'
                  3='3=CASE STUDY STORIES,' 4='4=DRY ERASE BOARD'
                  5='5=CLIENTS DRAWINGS AND WORKSHEETS' 6='6=PHOTO SLIDES'
                  7='7=KNOWLEDGE TESTING' ;
  VALUE aintdrug  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintsex   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE abarrier  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE asupport  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE acues     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE asetgoal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aintper   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE atb       -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aanatomy  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aapclien  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aselfhlp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE acommit   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE acomprtn  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE acompmed  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE alifpain  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE abldtrst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE adiscrim  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE adomviol  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE afacacc   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE afamiss   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE afoodprp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE ahlthtx   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE ahlthtop  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE ahomeles  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aposat    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE alifpatt  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE amordemo  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE anegskil  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE apeersup  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aroles    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aredubeh  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE apoverty  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE apwrles   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE apromslf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE atbtst    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE adiscst   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE arespect  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE arolplay  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aslfeff   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aslfenh   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aslfest   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE asklltra  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE astrman   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE asocials  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aphotdem  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE atalid    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE atrust    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aethcul   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE awllbng   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE aoth      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NOT VERY' 1='1=SOMEWHAT'
                  2='2=VERY' ;
  VALUE ahiv      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothiss   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aboth     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ahivfrst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aissfrst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aind      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE agrp      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE agrpsz    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=1-2 HLTH ED & 2-7 CLIENTS'
                  1='1=2-3' 2='2=3-9' 3='3=2-20' 4='4=2-8' 5='5=2 OR MORE'
                  6='6=3-6' 7='7=10-12' 8='8=VARIABLE' ;
  VALUE agrpcomp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO ANSWER'
                  1='1=SEX PRTNR, FRIENDS, FAMILY' 2='2=INTERVENTION CHARTS'
                  3='3=DRUG NETWORKS & PART'
                  4='4=ETHNIC TARGET LATINS/AFR AMER' 5='5=PERSONAL NETWORK'
                  6='6=AFRICAN AMER MALE IV' 7='7=MIXED BOTH GENDERS'
                  8='8=WOMENS, MENS GROUP' 10='10=HEALTH EDUCATORS & CLIENTS' ;
  VALUE aoth_     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aoth_sp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=COUPLES UPON REQUEST'
                  2='2=COMMUNITY BASED' 3='3=THOSE VISITS W/FAMILY'
                  4='4=INDIVIDUAL GROUP AND OTHER' 5='5=MONTHLY SOCIALS' ;
  VALUE aprojoff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE astreet   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE avan      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothplac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothsppl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE'
                  1='1=VEHICLES, HOMES AND RESTURANTS'
                  2='2=HOMES/BARS/CARS/CRACK HOUSES'
                  3='3=PROJECT OFFICE/VAN/STREET/COMMUNITY CN'
                  4='4=ACCOMPANY CLNT TO DRUG TX/SELF-HLP GRP'
                  5='5=CLIENTS HOMES' ;
  VALUE apref_    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ases1fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE ases2fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE ases3fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE ases4fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE ases5fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE ases6fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=0' 1='1=15-20 MINS'
                  2='2=55 MINS' 3='3=30-60 MINS FIELD' 4='4=15-60 MINS'
                  5='5=60 MINS' 6='6=45-60 MINS' 7='7=90 MINS' 8='8=50 MINS'
                  9='9=45 MINUTES INDIVIDUAL' 10='10=60-90 MINS'
                  11='11=15 MINS' 12='12=VARIES' 13='13=20 MINS'
                  14='14=60 MINUTES GROUP' 15='15=3 HRS SOCIALS'
                  16='16=30 MINUTES FUP' 17='17=45 MINS' ;
  VALUE anone     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aphone    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aphone_   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=IF MISS APPOINTMENT'
                  2='2=1 FOLUP' 3='3=5 CALLS' 4='4=AS NEEDED UP TO 1 MONTH' ;
  VALUE aoutwor   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aoutwor_  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO ANSWER' 1='1=3-4 CALLS'
                  2='2=IF MISS APPOINTMENT' 3='3=4 CALLS'
                  4='4=AS NEEDED UP TO 1 WEEK' 5='5=2ND & 3RD SESSION'
                  6='6=1 CALL' ;
  VALUE adropses  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE adropspe  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=THREE' 2='2=ANY #'
                  3='3=AS MANY AS CLIENTS WISH' 4='4=IF CLIENT WISHES' ;
  VALUE asupgrp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE algthses  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=UP TO 2 MONTHS AFTER COMP'
                  2='2=15-20 MIN UP UNTIL 5' 3='3=UP TO 1 HOUR'
                  4='4=UP TO 15 MIN' ;
  VALUE aoftngrp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=WHENEVER HIV +' 2='2=MONTHLY' ;
  VALUE aothrein  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothsp    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE'
                  1='1=OUTREACH WRKRS/CASE MANAGER FOLUP'
                  2='2=HIV FORUMS FOR HIV +'
                  3='3=REINFORCEMENT OF INDIVIDUAL'
                  4='4=INFORMAL CLIENT-INTERVENTION' ;
  VALUE aincent   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE adesc     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO ANSWER'
                  1='1=SODA/COFFEE/SANDWICH' 2='2=BUS TICKET, VAN RIDE'
                  3='3=DIPLOMA AFTER ATTEND'
                  4='4=FORMAL SES: 2 MCDONALDS COUPONS'
                  5='5=FOOD/SURVIVAL KIT/$5 FOR TRANS'
                  6='6=$10 MEAL VOUCHERS' 7='7=FOOD COUPONS/BUS TICKETS'
                  8='8=BUS PASS/HYGIENE SUBSIDY' ;
  VALUE astart    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE acomp     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE atot      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE atotsp    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=BONDING SESSION'
                  2='2=7 DAYS AFTER PT' 3='3=ASAP AFTERWARD'
                  4='4=START AT STANDARD CA' ;
  VALUE apaid     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE agender   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NO ANSWER' 2='2=MALE'
                  3='3=FEMALE' 4='4=BOTH' ;
  VALUE ahedm     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ahedb     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ahedn     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE apeercon  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE anurse    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE adrgcon   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothint   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothspin  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=HEALTH PSYCHOLOGY GRADUATE'
                  2='2=SOCIAL WORKER' 3='3=OUTREACH WORKER' ;
  VALUE atransp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ahivtest  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ahivcoun  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aurintst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE aothis2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=ADDITIONAL HEALTH SCREENING'
                  2='2=ADDITIONAL INFORMATION' 3='3=CASE MANAGEMENT ADVOCACY'
                  4='4=UTILIZATION OF TIME' 5='5=MONEY MANAGEMENT'
                  6='6=CHANGE IN ? NORMS' 7='7=RISK REDUCTION FOLUP' ;
  VALUE aothis1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=ADDITIONAL HEALTH SCREENING'
                  2='2=ADDITIONAL INFORMATION' 3='3=CASE MANAGEMENT ADVOCACY'
                  4='4=UTILIZATION OF TIME' 5='5=MONEY MANAGEMENT'
                  6='6=CHANGE IN ? NORMS' 7='7=RISK REDUCTION FOLUP' ;
  VALUE aothis3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=ADDITIONAL HEALTH SCREENING'
                  2='2=ADDITIONAL INFORMATION' 3='3=CASE MANAGEMENT ADVOCACY'
                  4='4=UTILIZATION OF TIME' 5='5=MONEY MANAGEMENT'
                  6='6=CHANGE IN ? NORMS' 7='7=RISK REDUCTION FOLUP' ;
  VALUE aindsz    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=3-9' 2='2=2-20'
                  8='8=OLD NO FORM NO ANSWER' ;
  VALUE aindcomp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=INTERVENTION CHARTS'
                  2='2=AMC DRUG NETWORKS & PART' 3='3=AMC OLD FORM NO ANSWER' ;
  VALUE ld88hivp  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld90hivp  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld92hivp  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ld94hivp  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ld96hivp  -9.00='-9 = SKIP, INELIG, NA' -8.00='-8 = REFUSED'
                  -7.00='-7 = DO NOT KNOW, UNSURE'
                  -6.00='-6 = NOT APPLIC OR REFUSED'
                  -5.00='-5 = SYSTEM MISSING' -4.00='-4 = INVALID VALUE' ;
  VALUE ld88accp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90accp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92accp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94accp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96accp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88hivi  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld90hivi  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld92hivi  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld94hivi  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld96hivi  -9.000='-9 = SKIP, INELIG, NA' -8.000='-8 = REFUSED'
                  -7.000='-7 = DO NOT KNOW, UNSURE'
                  -6.000='-6 = NOT APPLIC OR REFUSED'
                  -5.000='-5 = SYSTEM MISSING' -4.000='-4 = INVALID VALUE' ;
  VALUE ld88acci  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90acci  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92acci  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94acci  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96acci  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88phav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90phav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92phav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94phav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96phav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88phus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90phus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92phus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94phus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96phus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88phac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90phac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92phac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94phac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96phac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88neav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90neav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92neav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94neav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96neav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88neus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90neus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92neus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94neus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96neus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88neac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90neac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92neac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94neac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96neac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88dbav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90dbav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92dbav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94dbav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96dbav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88dbus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90dbus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92dbus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94dbus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96dbus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88dbac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90dbac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92dbac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94dbac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96dbac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88sdav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90sdav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92sdav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94sdav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96sdav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88sdus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90sdus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92sdus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94sdus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96sdus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88sdac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90sdac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92sdac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94sdac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96sdac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88sgav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90sgav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92sgav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94sgav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96sgav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88sgus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90sgus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92sgus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94sgus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96sgus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88sgac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90sgac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92sgac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94sgac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96sgac  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88ne0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90ne0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92ne0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ne0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ne0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88ne1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90ne1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92ne1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ne1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ne1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88ne2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90ne2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92ne2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ne2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ne2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88necf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90necf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92necf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94necf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96necf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88ne3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90ne3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92ne3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ne3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ne3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90op1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92op1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94op1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96op1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92op2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94op2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96op2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94op3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96op3f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90maxf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92maxf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94maxf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96maxf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ma0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ma0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ma1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ma1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90annf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld92annf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld94annf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld96annf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld96an0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld88laws  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90laws  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92laws  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94laws  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96laws  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88lawl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90lawl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92lawl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94lawl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96lawl  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88norx  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=VERY FEW' 2='2=FEW'
                  3='3=MANY' ;
  VALUE ld90norx  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=VERY FEW' 2='2=FEW'
                  3='3=MANY' ;
  VALUE ld92norx  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=VERY FEW' 2='2=FEW'
                  3='3=MANY' ;
  VALUE ld94norx  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=VERY FEW' 2='2=FEW'
                  3='3=MANY' ;
  VALUE ld96norx  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=VERY FEW' 2='2=FEW'
                  3='3=MANY' ;
  VALUE ld88minp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=FEW' 2='2=MANY' ;
  VALUE ld90minp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=FEW' 2='2=MANY' ;
  VALUE ld92minp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=FEW' 2='2=MANY' ;
  VALUE ld94minp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=FEW' 2='2=MANY' ;
  VALUE ld96minp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NONE' 1='1=FEW' 2='2=MANY' ;
  VALUE ld88id    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90id    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92id    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94id    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96id    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88sig   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90sig   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92sig   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94sig   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96sig   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88prdb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90prdb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92prdb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94prdb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96prdb  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88dtpp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90dtpp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92dtpp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94dtpp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96dtpp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88dtpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90dtpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92dtpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94dtpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96dtpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88htcp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90htcp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92htcp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94htcp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96htcp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88htcr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90htcr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92htcr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94htcr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96htcr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88stdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90stdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92stdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94stdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96stdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88stdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90stdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92stdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94stdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96stdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88hopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90hopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92hopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94hopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96hopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88hopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90hopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92hopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94hopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96hopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88oopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90oopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92oopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94oopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96oopp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88oopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90oopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92oopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94oopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96oopr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88hcmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90hcmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92hcmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94hcmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96hcmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88hcmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90hcmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92hcmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94hcmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96hcmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88ocmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90ocmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92ocmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94ocmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96ocmp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88ocmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90ocmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92ocmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94ocmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96ocmr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88msp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90msp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92msp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94msp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96msp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88msr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90msr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92msr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94msr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96msr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88hlp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90hlp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92hlp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94hlp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96hlp   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88hlr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90hlr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92hlr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94hlr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96hlr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld88oipp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90oipp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92oipp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94oipp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96oipp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88oipr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld90oipr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld92oipr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld94oipr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ld96oipr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=NOT AT ALL'
                  2='2=VERY SMALL EXTENT' 3='3=SMALL EXTENT'
                  4='4=MODERATE EXTENT' 5='5=LARGE EXTENT'
                  6='6=VERY LARGE EXTENT' ;
  VALUE ldpopest  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld88idu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld88conf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88geo   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld88tran  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY BAD' 2='2=BAD'
                  3='3=MODERATE' 4='4=GOOD' 5='5=VERY GOOD' ;
  VALUE ld88imm   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88emi   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90idu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90conf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90geo   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld90tran  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY BAD' 2='2=BAD'
                  3='3=MODERATE' 4='4=GOOD' 5='5=VERY GOOD' ;
  VALUE ld90imm   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90emi   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92idu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld92conf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92geo   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld92tran  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY BAD' 2='2=BAD'
                  3='3=MODERATE' 4='4=GOOD' 5='5=VERY GOOD' ;
  VALUE ld92imm   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92emi   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94idu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld94conf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94geo   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld94tran  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY BAD' 2='2=BAD'
                  3='3=MODERATE' 4='4=GOOD' 5='5=VERY GOOD' ;
  VALUE ld94imm   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94emi   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96idu   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld96conf  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96geo   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld96tran  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY BAD' 2='2=BAD'
                  3='3=MODERATE' 4='4=GOOD' 5='5=VERY GOOD' ;
  VALUE ld96imm   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96emi   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88hl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88jail  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88trns  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88inst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90hl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90jail  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90trns  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90inst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92hl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92jail  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92trns  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92inst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94hl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94jail  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94trns  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94inst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96hl    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96jail  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96trns  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96inst  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88male  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90male  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92male  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94male  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96male  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88fem   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90fem   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92fem   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94fem   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96fem   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88u25f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90u25f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92u25f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94u25f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96u25f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88253f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90253f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92253f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94253f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96253f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88g35f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90g35f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92g35f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94g35f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96g35f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88bla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90bla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92bla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94bla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96bla   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88whit  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90whit  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92whit  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94whit  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96whit  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88hisp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90hisp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92hisp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94hisp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96hisp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88othr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90othr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92othr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94othr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96othr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88oth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90oth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92oth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94oth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96oth   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88her   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90her   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld92her   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld94her   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld96her   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld88coc   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90coc   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld92coc   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld94coc   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld96coc   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld88sped  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90sped  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld92sped  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld94sped  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld96sped  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld88meth  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90meth  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld92meth  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld94meth  -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld96meth  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld88otdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90otdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld92otdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld94otdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld96otdr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld88co0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90co0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92co0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94co0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96co0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88hera  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90hera  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92hera  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94hera  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96hera  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88coca  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90coca  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92coca  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94coca  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96coca  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88spda  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90spda  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92spda  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94spda  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96spda  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88meta  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90meta  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92meta  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94meta  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96meta  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88otha  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90otha  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92otha  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94otha  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96otha  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88herp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90herp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92herp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94herp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96herp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88cocp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90cocp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92cocp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94cocp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96cocp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88spdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90spdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92spdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94spdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96spdp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88metp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90metp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92metp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94metp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96metp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88othp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90othp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92othp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94othp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96othp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88pop   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ld90pop   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld92pop   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld94pop   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld96pop   -9.0='-9 = SKIP, INELIG, NA' -8.0='-8 = REFUSED'
                  -7.0='-7 = DO NOT KNOW, UNSURE'
                  -6.0='-6 = NOT APPLIC OR REFUSED'
                  -5.0='-5 = SYSTEM MISSING' -4.0='-4 = INVALID VALUE' ;
  VALUE ld88co1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90co1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92co1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94co1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96co1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88gal   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld90gal   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld92gal   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld94gal   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld96gal   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld88ngal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90ngal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92ngal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94ngal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96ngal  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88disp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld90disp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld92disp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld94disp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld96disp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO' 1='1=YES' ;
  VALUE ld88har   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90har   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92har   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94har   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96har   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88init  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld90init  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld92init  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld94init  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld96init  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=SMALL EXTENT'
                  2='2=MODERATE EXTENT' 3='3=GREAT EXTENT' ;
  VALUE ld88nini  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld90nini  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld92nini  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld94nini  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld96nini  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 0='0=NO CHANGE' 1='1=INCREASE'
                  2='2=DECREASE' ;
  VALUE ld88co2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld90co2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld92co2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld94co2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld96co2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY LOW' 2='2=LOW'
                  3='3=MODERATE' 4='4=HIGH' 5='5=VERY HIGH' ;
  VALUE ld88avai  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90avai  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92avai  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94avai  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96avai  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld88blch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld90blch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld92blch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld94blch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ld96blch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ldintyr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE ldintsvc  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ldintned  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=LIMITED EXTENT' 3='3=MODERATE EXTENT'
                  4='4=LARGE EXTENT' 5='5=VERY LARGE EXTENT' ;
  VALUE ldintsrc  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE ldinttrt  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=LIMITED EXTENT' 3='3=MODERATE EXTENT'
                  4='4=LARGE EXTENT' 5='5=VERY LARGE EXTENT' ;
  VALUE ldintacc  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=VERY SMALL EXTENT'
                  2='2=SMALL EXTENT' 3='3=MODERATE EXTENT' 4='4=LARGE EXTENT'
                  5='5=VERY LARGE EXTENT' ;
  VALUE pharmava  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE needleav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE diabava   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE dealerav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE gallerav  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail88f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail90f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail92f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail94f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE avail96f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE pharmuse  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE needluse  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE diabuse   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE dlruse    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE gallerus  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used88ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used90ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used92ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used94ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE used96ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep       -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep88fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep90fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep92fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep94fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE nep96fff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE intpro8f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE intpro9f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE intpro0f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE intpro1f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE intpro2f  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchd88ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchd90ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchd92ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchd94ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchd96ff  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE progtot   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE rchdtot   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE norx      -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE drugtrtp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivtestp  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE stdprog   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivorprg  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othorprg  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivcmprg  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othcmprg  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE medsvprg  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hlprog    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othintpr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE drugtrtr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivtestr  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE stdrchd   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivorrch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othorrch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hivcmrch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othcmrch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE medsvrch  -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE hlrchd    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE othintr   -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE early     -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' ;
  VALUE design    -9='-9 = SKIP, INELIG, NA' -8='-8 = REFUSED'
                  -7='-7 = DO NOT KNOW, UNSURE'
                  -6='-6 = NOT APPLIC OR REFUSED' -5='-5 = SYSTEM MISSING'
                  -4='-4 = INVALID VALUE' 1='1=DESIGN' 2='2=DEFAULT'
                  3='3=BOTH' 4='4=NEITHER' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=2815;
INPUT
        CASEID 1-6              SITECODE 7-9            SI1 10-11
        SI2 12-13               SI3 14-15               SI4 16-17
        SI5 18-19               SI6_1 20-21             SI6_2 22-23
        SI7_1 24-25             SI7_2 26-27             SI7_3 28-29
        SI7_4 30-31             SI7_5 32-33             SI8 34-35
        SI9 36-38 .1            SI10_1 39-40            SI10B_2 41-42
        SI11 43-44              SI12_1 45-46            SI12_2 47-49
        SI13 50-51              SI14 52-53              SI15 54-55
        SI16 56-57              SI17 58-59              SI18 60-61
        SI19 62-63              SI20 64-65              SI21 66-67
        SI22_1 68               SI22_2 69-70            SI23 71-72
        SI24 73-74              SI25 75                 SI26 76
        SI27 77                 SI28 78                 SI29 79
        SI30 80                 SI31 81                 SI32 82
        SI32A 83-84             SI33 85-86              SI34 87-88
        SI35 89-90              SI36 91-92              SI37 93-94
        SI38 95-96              SI39 97-98              SI40 99
        SI40A 100-101           SI40B 102-103           SI40C 104-105
        SI40D 106-107           SI41 108-109            SI42 110-111
        SI43 112-113            SI43A 114-115           SI43B 116-117
        SI43C 118-119           SI43D 120-121           SI43E 122-123
        SI43F 124-125           SI44 126-127            SI45 128-129
        SI46 130-131            SI47 132-133            SI48 134-135
        SI48_1 136-137          SI48_2 138-140          SI49 141-142
        SI49A 143-144           SI49_1 145-146          SI49_2 147-149
        SI50 150-151            SI50A 152-153           SI50A_1 154-155
        SI50A_2 156-158         SI51_1 159-160          SI51_2 161-162
        SI52_1 163              SI52_2 164-165          SI54 166
        SI55 167                SI55A 168-169           SI55B 170-171
        SI55C 172-173           SI55D 174-175           SI56 176-177
        SI57 178-179            SI58 180-181            SI59 182-183
        SI60 184-185            SI61 186-187            SI62 188
        SI62A 189-190           SI62B 191-192           SI62C 193-194
        SI62D 195-196           SI63 197-198            SI64 199-200
        SI65 201-202            SI65A 203-204           SI66 205-206
        SI67 207-208            SI68 209-210            SI68_1 211-212
        SI68_2 213-215          SI69 216                SI69A 217-218
        SI70 219-220            SI71 221                SI72_1 222-223
        SI72_2 224-225          SI73 226-227            SI74 228-229
        SI75 230                SI76_1 231-232          SI76_2 233-234
        SI77 235-236            SI78A 237-238           SI78B 239-240
        SI78C 241-242           SI78A_1 243-244         SI78A_2 245-246
        SI78A_3 247-248         SI79 249-250            SI80 251-252
        SI81 253-254            SI82 255-256            SI83 257-258
        SI84 259-260            SI85_1 261              SI85_2 262-263
        SI87 264-265            SI88 266-267            SI89 268-269
        SI90 270-271            SI91 272-273            SI92 274-275
        SI93 276-277            SI94 278-279            SI94A 280-281
        SI94B 282-283           SI94C 284-285           SI94D 286-287
        SI95 288-290            SI96 291-292            SI97 293
        SI98 294-296            SI100 297-298           SI100A 299-300
        SI100B 301-302          SI101 303-304           SI102 305-306
        SI102B 307-308          SI102C 309-310          SI103 311-312
        SI104 313-314           SI105 315-316           SI105A 317-318
        SI105B 319-320          SI105C 321-322          SI106 323-324
        SI107 325-326           SI108 327-328           SI109 329-330
        SI109A 331-332          SI110 333-334           SI111 335-336
        SI111A 337-338          SI112 339-340           SI113_1 341-342
        SI113_2 343-345         SI114_1 346-347         SI114_2 348-349
        SI115_1 350-351         SI115_2 352-353         SI116 354-355
        SI117 356-357           SI118 358-359           SI119 360-361
        SI120 362-363           SI120A 364-365          SI120B 366-367
        SI120C 368-369          SI120D 370-371          SI121 372-373
        SI122 374-375           SI123 376-377           SI124 378-379
        SI125 380-381           SI126 382-383           SI127 384
        SI128 385-386           SI129_1 387-388         SI129_2 389-390
        SI129_3 391-392         SI130 393-394           SI131 395-396
        SI132 397-398           SI133 399-400           SI134_1 401-402
        SI134_2 403-404         SI134_3 405-406         SI135 407-408
        SI136 409-410           SI137 411-412           SI137A 413-414
        SI138 415-416           SI138A 417-418          SI139 419-420
        SI139A 421-422          SI140 423-424           SI141 425-426
        SI141A 427-428          SI142 429-430           SI143 431-432
        SI144 433-434           SI145 435-436           SI145A 437-438
        SI146 439-440           SI147A 441-442          SI147B 443-444
        SI147C 445-446          SI147A_1 447-448        SI147A_2 449-450
        SI147A_3 451-452        SI148 453-454           SI149 455-456
        SI150 457-458           SI151_1 459-460         SI151_2 461-462
        SI153 463-464           SI154 465-466           SI155 467-468
        SI156_1 469-470         SI156_2 471-472         SI156_3 473-475
        SI157 476-477           SI158 478-479           SI159 480-481
        SI160 482-483           SI160A 484-485          SI161 486-487
        SI161A 488-489          SI162 490-491           SI162A 492-493
        SI163 494-495           SI164 496-497           SI164A 498-499
        SI165 500-501           SI166 502-503           SI167 504-505
        SI168 506-507           SI168A 508-509          SI169 510-511
        SI170A 512-513          SI170B 514-515          SI170C 516-517
        SI170A_1 518-519        SI170A_2 520-521        SI170A_3 522-523
        SI171 524-525           SI172 526-527           SI173 528-529
        SI174_1 530-531         SI174_2 532-533         SI176 534-535
        SI177 536-537           SI177A 538-540          SI178 541-542
        SI178A 543-544          SI179 545-546           SI180 547-548
        SI180A 549-550          SI181 551-552           SI182 553-554
        SI182A 555-558 .1       SI183 559-560           SI184 561-562
        SI185 563-564           SI186 565-566           SI187 567-568
        SI188 569-570           SI189 571-572           SI190 573-574
        SI191 575-576           SI192_1 577-578         SI192_2 579-580
        SI192_3 581-582         SI193 583-584           SI194 585-586
        SI195 587-588           SI196 589-590           SI197 591
        SI198 592               SI199 593-594           SI200_1 595-596
        SI200A 597-598          SI201_1 599-600         SI202_1 601-602
        SI203_1 603-604         SI204_1 605-606         SI205_1 607-608
        SI206_1 609             SI208 610-611           SI209 612-613
        SI210 614-615           SI211 616-617           SI212 618-619
        SI213 620-621           SI215 622-623           SI216 624-625
        SI217 626-627           SI217A_1 628-629        SI217A_2 630-631
        SI217A_3 632-633        SI217B 634-635          SI218 636
        SI218A 637-638          SI218B 639-640          SI218C 641-642
        SI218D_1 643-644        SI218D_2 645-646        SI218D_3 647-648
        SESADUR 649-651         SESBDUR 652-654         SESAODUR 655-657
        SESBODUR 658-660        OUTDUR 661-663          DISTRIB1 664-665
        DISTINJ 666-667         DISTSEX 668-669         REHNDLA 670
        REHCNDMA 671-672        REHALLA 673             REHNDLB 674
        REHCNDMB 675-676        REHALLB 677             SIDEMOA 678
        SIDEMOB 679             SIRHSLA 680-681         SIRHSLB 682-683
        SIS1 684-685            SIS2A 686-687           SIS2B 688-689
        SIS2C 690-691           SIS2D 692-693           SIS3 694-698
        SIS4 699-702            SIS5 703-706            SIS6 707-710
        SIS7 711-715            SIS8 716-717            SIS9 718-719
        SIS9A 720-721           SIS10 722-723           SIS11 724-725
        SIS12 726-727           SIS12A 728-729          SIS13 730-731
        SIS14 732-733           SIS15 734-735           SIS16 736-737
        SIS17 738-739           SIS17A 740-741          SIS18 742-743
        SIS19 744-745           SIS20 746-749           SIS21 750-753
        SIS22 754-757           SIS23 758-761           SIS24 762-766
        SIS25 767-770           SIS26 771-774           SIS27 775-778
        SIS28 779-780           SIS29 781-782           SIS30 783-784
        SIS31 785-786           SIS32 787-788           SIS33 789-790
        SIS34 791-792           SIS35 793-794           SIS36A 795-796
        SIS36B 797-798          SIS36C 799-800          SIS37A 801-802
        SIS37B 803-804          SIS37C 805-806          SIS38 807-808
        SIS39 809-810           SIS40 811-812           SIS41 813-814
        SIS42 815-816           SIS43 817-818           SIS43A 819-820
        SIS44 821-822           SIS45 823-824           SIS46 825-828
        SIS47 829-832           SIS48 833-836           SIS49 837-840
        SIS50 841-845           SIS51 846-848           SIS52 849-852
        SIS53 853-856           SIS54 857-858           SIS55 859-860
        SIS56 861-862           SIS57 863-864           SIS58 865-866
        SIS59 867-868           SIS60 869-870           SIS61 871-872
        SIS62A 873-874          SIS62B 875-876          SIS62C 877-878
        SIS63A 879-880          SIS63B 881-882          SIS63C 883-884
        SIS64 885-886           SIS65 887-888           SIS66 889-890
        SIS67 891-892           SIS68 893-894           SIS69 895-896
        SIS69A 897-898          SIS70 899-900           SIS71 901-902
        SIS72 903-906           SIS73 907-909           SIS74 910-912
        SIS75 913-915           SIS76 916-919           SIS77 920-922
        SIS78 923-925           SIS79 926-928           SIS80 929-930
        SIS81 931-932           SIS82 933-934           SIS83 935-936
        SIS84 937-938           SIS85 939-940           SIS86 941-942
        SIS87 943-944           SIS88A 945-946          SIS88B 947-948
        SIS88C 949-950          SIS89A 951-952          SIS89B 953-954
        SIS89C 955-956          SIS90 957-958           SIS91 959-960
        SIS92 961-962           SIS93 963-964           SIS94 965-966
        SIS95 967-968           SIS96 969-970           SIS97 971-972
        SIS98 973-974           SIS99 975-976           SIS100 977-978
        SIS101 979-980          SIS102 981-982          SIS103A 983-984
        SIS103B 985-986         SIS103C 987-988         SIS106 989-990
        SIS107 991-992          SIS108 993-994          SIS109 995-996
        SIS110 997-998          SIS111 999-1000         SIS112 1001-1002
        SIS113 1003-1004        SIS114 1005-1006        SIS115 1007-1008
        SIS116 1009-1010        SIS117A 1011-1012       SIS117B 1013-1014
        SIS117C 1015-1016       SIS120 1017-1018        SIS121 1019-1020
        SIS122 1021-1022        SIS123 1023-1024        SIS124 1025-1026
        SIS125 1027-1028        SIS126 1029-1030        SIS127 1031-1032
        SIS128 1033-1034        SIS129 1035-1036        SIS130 1037-1038
        SIS131A 1039-1040       SIS131B 1041-1042       SIS131C 1043-1044
        SIS134 1045-1046        SIS135 1047-1048        SIS136 1049-1050
        SIS137 1051-1052        SIS138 1053-1054        SIS139 1055-1056
        SIS140 1057-1058        SIS141 1059-1060        SIS142 1061-1062
        EINUM 1063-1064         EI1 1065-1066           EI2_1 1067-1071 .2
        EI2_2 1072-1075 .1      EI2_3 1076-1080 .2      EI2_4 1081-1085 .2
        EI2_5 1086-1090 .2      EI2_6 1091-1095 .2      EI3A_1 1096-1097
        EI3A_2 1098-1099        EI3A_3 1100-1101        EI3A_4 1102-1103
        EI3B 1104-1105          EI4A_1 1106-1108        EI4A_2 1109-1111
        EI4B_3 1112-1114        EI4B_4 1115-1117        EI4B_5 1118-1119
        EI4B_6 1120-1122        EI5_1 1123-1125         EI5_2 1126-1127
        EI6 1128-1129           EI7A_1 1130-1131        EI7A_2 1132-1133
        EI7A_3 1134-1135        EI7A_4 1136-1137        EI7A_5 1138-1139
        EI7A_6 1140-1141        EI7A_7 1142-1143        EI7A_8 1144-1145
        EI7A_9 1146-1147        EI7A_10 1148-1149       EI7A_11 1150-1151
        EI7A_12 1152-1153       EI7B_1 1154-1155        EI7B_2 1156-1157
        EI7B_3 1158-1159        EI7B_4 1160-1161        EI7B_5 1162-1163
        EI7B_6 1164-1165        EI7B_7 1166-1167        EI7B_8 1168-1169
        EI7B_9 1170-1171        EI7B_10 1172-1173       EI8A_1 1174-1175
        EI8A_2 1176-1177        EI8A_3 1178-1179        EI8A_4 1180-1181
        EI8A_5 1182-1183        EI8A_6 1184-1185        EI8A_7 1186-1187
        EI8A_8 1188-1189        EI8A_9 1190-1191        EI8A_10 1192-1193
        EI8A_11 1194-1195       EI8A_12 1196-1197       EI8A_13 1198-1199
        EI8A_14 1200-1201       EI8B_1 1202-1203        EI8B_2 1204-1205
        EI8B_3 1206-1207        EI8B_4 1208-1209        EI9 1210-1211
        EI10 1212-1213          EI11_1 1214-1215        EI11_2 1216-1217
        EI11_3 1218-1219        EI11_4 1220-1221        EI11_5 1222-1223
        EI11_6 1224-1225        EI11_7 1226-1227        EI11_8 1228-1229
        EI11_9 1230-1231        EI11_10 1232-1233       EI11_11 1234-1235
        EI11_12 1236-1237       EI11_13 1238-1239       EI11_14 1240-1241
        EI11_15 1242-1243       EI12_2 1244-1245        EI14_1 1246-1247
        EI14_2 1248-1249        EI14_3 1250-1251        EI14_4 1252-1253
        EI14_5 1254-1255        EIDEMO 1256-1257        EIRHSL 1258-1259
        EIACTA 1260-1261        EIACTB 1262-1263        EIDISTA 1264-1265
        EIDISTB 1266-1267       EIDUR 1268-1270         EIADUR 1271-1273
        EIBDUR 1274-1276        EIAODUR 1277-1279       EIBODUR 1280-1282
        EIIND 1283              EICOUPLE 1284           EIGROUP 1285
        XDAMC 1286-1289         AINTCOU 1290-1291       AINTEDU 1292-1293
        AINTBOTH 1294-1295      AINTOTH 1296-1297       AINTSP 1298-1299
        AINTAV 1300-1301        AAVVIDEO 1302-1303      AAVHAND 1304-1305
        AAVOTHER 1306-1307      AAVSP 1308-1309         AINTDRUG 1310-1311
        AINTSEX 1312-1313       ABARRIER 1314-1315      ASUPPORT 1316-1317
        ACUES 1318-1319         ASETGOAL 1320-1321      AINTPER 1322-1323
        ATB 1324-1325           AANATOMY 1326-1327      AAPCLIEN 1328-1329
        ASELFHLP 1330-1331      ACOMMIT 1332-1333       ACOMPRTN 1334-1335
        ACOMPMED 1336-1337      ALIFPAIN 1338-1339      ABLDTRST 1340-1341
        ADISCRIM 1342-1343      ADOMVIOL 1344-1345      AFACACC 1346-1347
        AFAMISS 1348-1349       AFOODPRP 1350-1351      AHLTHTX 1352-1353
        AHLTHTOP 1354-1355      AHOMELES 1356-1357      APOSAT 1358-1359
        ALIFPATT 1360-1361      AMORDEMO 1362-1363      ANEGSKIL 1364-1365
        APEERSUP 1366-1367      AROLES 1368-1369        AREDUBEH 1370-1371
        APOVERTY 1372-1373      APWRLES 1374-1375       APROMSLF 1376-1377
        ATBTST 1378-1379        ADISCST 1380-1381       ARESPECT 1382-1383
        AROLPLAY 1384-1385      ASLFEFF 1386-1387       ASLFENH 1388-1389
        ASLFEST 1390-1391       ASKLLTRA 1392-1393      ASTRMAN 1394-1395
        ASOCIALS 1396-1397      APHOTDEM 1398-1399      ATALID 1400-1401
        ATRUST 1402-1403        AETHCUL 1404-1405       AWLLBNG 1406-1407
        AOTH 1408-1409          AHIV 1410-1411          AOTHISS 1412-1413
        ABOTH 1414-1415         AHIVFRST 1416-1417      AISSFRST 1418-1419
        AIND 1420-1421          AGRP 1422-1423          AGRPSZ 1424-1425
        AGRPCOMP 1426-1427      AOTH_ 1428-1429         AOTH_SP 1430-1431
        APROJOFF 1432-1433      ASTREET 1434-1435       AVAN 1436-1437
        AOTHPLAC 1438-1439      AOTHSPPL 1440-1441      APREF_ 1442-1443
        ASES1 1444-1445         ASES2 1446-1447         ASES3 1448-1449
        ASES4 1450-1451         ASES5 1452-1453         ASES6 1454-1455
        ANONE 1456-1457         APHONE 1458-1459        APHONE_ 1460-1461
        AOUTWOR 1462-1463       AOUTWOR_ 1464-1465      ADROPSES 1466-1467
        ADROPSPE 1468-1469      ASUPGRP 1470-1471       ALGTHSES 1472-1473
        AOFTNGRP 1474-1475      AOTHREIN 1476-1477      AOTHSP 1478-1479
        AINCENT 1480-1481       ADESC 1482-1483         ASTART 1484-1485
        ACOMP 1486-1487         ATOT 1488-1489          ATOTSP 1490-1491
        APAID 1492-1493         AGENDER 1494-1495       AHEDM 1496-1497
        AHEDB 1498-1499         AHEDN 1500-1501         APEERCON 1502-1503
        ANURSE 1504-1505        ADRGCON 1506-1507       AOTHINT 1508-1509
        AOTHSPIN 1510-1511      ATRANSP 1512-1513       AHIVTEST 1514-1515
        AHIVCOUN 1516-1517      AURINTST 1518-1519      AOTHIS2 1520-1521
        AOTHIS1 1522-1523       AOTHIS3 1524-1525       AINDSZ 1526-1527
        AINDCOMP 1528-1529      LD88HIVP 1530-1535 .3   LD90HIVP 1536-1541 .3
        LD92HIVP 1542-1546 .2   LD94HIVP 1547-1551 .2   LD96HIVP 1552-1556 .2
        LD88ACCP 1557-1558      LD90ACCP 1559-1560      LD92ACCP 1561-1562
        LD94ACCP 1563-1564      LD96ACCP 1565-1566      LD88HIVI 1567-1572 .3
        LD90HIVI 1573-1578 .3   LD92HIVI 1579-1584 .3   LD94HIVI 1585-1590 .3
        LD96HIVI 1591-1596 .3   LD88ACCI 1597-1598      LD90ACCI 1599-1600
        LD92ACCI 1601-1602      LD94ACCI 1603-1604      LD96ACCI 1605-1606
        LD88PHAV 1607-1608      LD90PHAV 1609-1610      LD92PHAV 1611-1612
        LD94PHAV 1613-1614      LD96PHAV 1615-1616      LD88PHUS 1617-1618
        LD90PHUS 1619-1620      LD92PHUS 1621-1622      LD94PHUS 1623-1624
        LD96PHUS 1625-1626      LD88PHAC 1627-1628      LD90PHAC 1629-1630
        LD92PHAC 1631-1632      LD94PHAC 1633-1634      LD96PHAC 1635-1636
        LD88NEAV 1637-1638      LD90NEAV 1639-1640      LD92NEAV 1641-1642
        LD94NEAV 1643-1644      LD96NEAV 1645-1646      LD88NEUS 1647-1648
        LD90NEUS 1649-1650      LD92NEUS 1651-1652      LD94NEUS 1653-1654
        LD96NEUS 1655-1656      LD88NEAC 1657-1658      LD90NEAC 1659-1660
        LD92NEAC 1661-1662      LD94NEAC 1663-1664      LD96NEAC 1665-1666
        LD88DBAV 1667-1668      LD90DBAV 1669-1670      LD92DBAV 1671-1672
        LD94DBAV 1673-1674      LD96DBAV 1675-1676      LD88DBUS 1677-1678
        LD90DBUS 1679-1680      LD92DBUS 1681-1682      LD94DBUS 1683-1684
        LD96DBUS 1685-1686      LD88DBAC 1687-1688      LD90DBAC 1689-1690
        LD92DBAC 1691-1692      LD94DBAC 1693-1694      LD96DBAC 1695-1696
        LD88SDAV 1697-1698      LD90SDAV 1699-1700      LD92SDAV 1701-1702
        LD94SDAV 1703-1704      LD96SDAV 1705-1706      LD88SDUS 1707-1708
        LD90SDUS 1709-1710      LD92SDUS 1711-1712      LD94SDUS 1713-1714
        LD96SDUS 1715-1716      LD88SDAC 1717-1718      LD90SDAC 1719-1720
        LD92SDAC 1721-1722      LD94SDAC 1723-1724      LD96SDAC 1725-1726
        LD88SGAV 1727-1728      LD90SGAV 1729-1730      LD92SGAV 1731-1732
        LD94SGAV 1733-1734      LD96SGAV 1735-1736      LD88SGUS 1737-1738
        LD90SGUS 1739-1740      LD92SGUS 1741-1742      LD94SGUS 1743-1744
        LD96SGUS 1745-1746      LD88SGAC 1747-1748      LD90SGAC 1749-1750
        LD92SGAC 1751-1752      LD94SGAC 1753-1754      LD96SGAC 1755-1756
        LD88NE01 1757-1758      LD90NE01 1759-1760      LD92NE01 1761-1762
        LD94NE01 1763-1764      LD96NE01 1765-1766      LD88NE02 1767-1768
        LD90NE02 1769-1770      LD92NE02 1771-1772      LD94NE02 1773-1774
        LD96NE02 1775-1776      LD88NE03 1777-1778      LD90NE03 1779-1780
        LD92NE03 1781-1782      LD94NE03 1783-1784      LD96NE03 1785-1786
        LD88NEC1 1787-1788      LD90NEC1 1789-1790      LD92NEC1 1791-1792
        LD94NEC1 1793-1794      LD96NEC1 1795-1796      LD88NEC2 1797-1798
        LD90NEC2 1799-1800      LD92NEC2 1801-1802      LD94NEC2 1803-1804
        LD96NEC2 1805-1806      LD90OP1 1807-1808       LD92OP1 1809-1810
        LD94OP1 1811-1812       LD96OP1 1813-1814       LD92OP2 1815-1816
        LD94OP2 1817-1818       LD96OP2 1819-1820       LD94OP3 1821-1822
        LD96OP3 1823-1824       LD90MAX1 1825-1826      LD92MAX1 1827-1828
        LD94MAX1 1829-1830      LD96MAX1 1831-1832      LD94MAX2 1833-1834
        LD96MAX2 1835-1836      LD94MAX3 1837-1838      LD96MAX3 1839-1840
        LD90ANN1 1841-1845      LD92ANN1 1846-1851      LD94ANN1 1852-1857
        LD96ANN1 1858-1863      LD96ANN2 1864-1868      LD88LAWS 1869-1870
        LD90LAWS 1871-1872      LD92LAWS 1873-1874      LD94LAWS 1875-1876
        LD96LAWS 1877-1878      LD88LAWL 1879-1880      LD90LAWL 1881-1882
        LD92LAWL 1883-1884      LD94LAWL 1885-1886      LD96LAWL 1887-1888
        LD88NORX 1889-1890      LD90NORX 1891-1892      LD92NORX 1893-1894
        LD94NORX 1895-1896      LD96NORX 1897-1898      LD88MINP 1899-1900
        LD90MINP 1901-1902      LD92MINP 1903-1904      LD94MINP 1905-1906
        LD96MINP 1907-1908      LD88ID 1909-1910        LD90ID 1911-1912
        LD92ID 1913-1914        LD94ID 1915-1916        LD96ID 1917-1918
        LD88SIG 1919-1920       LD90SIG 1921-1922       LD92SIG 1923-1924
        LD94SIG 1925-1926       LD96SIG 1927-1928       LD88PRDB 1929-1930
        LD90PRDB 1931-1932      LD92PRDB 1933-1934      LD94PRDB 1935-1936
        LD96PRDB 1937-1938      LD88DTPP 1939-1940      LD90DTPP 1941-1942
        LD92DTPP 1943-1944      LD94DTPP 1945-1946      LD96DTPP 1947-1948
        LD88DTPR 1949-1950      LD90DTPR 1951-1952      LD92DTPR 1953-1954
        LD94DTPR 1955-1956      LD96DTPR 1957-1958      LD88HTCP 1959-1960
        LD90HTCP 1961-1962      LD92HTCP 1963-1964      LD94HTCP 1965-1966
        LD96HTCP 1967-1968      LD88HTCR 1969-1970      LD90HTCR 1971-1972
        LD92HTCR 1973-1974      LD94HTCR 1975-1976      LD96HTCR 1977-1978
        LD88STDP 1979-1980      LD90STDP 1981-1982      LD92STDP 1983-1984
        LD94STDP 1985-1986      LD96STDP 1987-1988      LD88STDR 1989-1990
        LD90STDR 1991-1992      LD92STDR 1993-1994      LD94STDR 1995-1996
        LD96STDR 1997-1998      LD88HOPP 1999-2000      LD90HOPP 2001-2002
        LD92HOPP 2003-2004      LD94HOPP 2005-2006      LD96HOPP 2007-2008
        LD88HOPR 2009-2010      LD90HOPR 2011-2012      LD92HOPR 2013-2014
        LD94HOPR 2015-2016      LD96HOPR 2017-2018      LD88OOPP 2019-2020
        LD90OOPP 2021-2022      LD92OOPP 2023-2024      LD94OOPP 2025-2026
        LD96OOPP 2027-2028      LD88OOPR 2029-2030      LD90OOPR 2031-2032
        LD92OOPR 2033-2034      LD94OOPR 2035-2036      LD96OOPR 2037-2038
        LD88HCMP 2039-2040      LD90HCMP 2041-2042      LD92HCMP 2043-2044
        LD94HCMP 2045-2046      LD96HCMP 2047-2048      LD88HCMR 2049-2050
        LD90HCMR 2051-2052      LD92HCMR 2053-2054      LD94HCMR 2055-2056
        LD96HCMR 2057-2058      LD88OCMP 2059-2060      LD90OCMP 2061-2062
        LD92OCMP 2063-2064      LD94OCMP 2065-2066      LD96OCMP 2067-2068
        LD88OCMR 2069-2070      LD90OCMR 2071-2072      LD92OCMR 2073-2074
        LD94OCMR 2075-2076      LD96OCMR 2077-2078      LD88MSP 2079-2080
        LD90MSP 2081-2082       LD92MSP 2083-2084       LD94MSP 2085-2086
        LD96MSP 2087-2088       LD88MSR 2089-2090       LD90MSR 2091-2092
        LD92MSR 2093-2094       LD94MSR 2095-2096       LD96MSR 2097-2098
        LD88HLP 2099-2100       LD90HLP 2101-2102       LD92HLP 2103-2104
        LD94HLP 2105-2106       LD96HLP 2107-2108       LD88HLR 2109-2110
        LD90HLR 2111-2112       LD92HLR 2113-2114       LD94HLR 2115-2116
        LD96HLR 2117-2118       LD88OIPP 2119-2120      LD90OIPP 2121-2122
        LD92OIPP 2123-2124      LD94OIPP 2125-2126      LD96OIPP 2127-2128
        LD88OIPR 2129-2130      LD90OIPR 2131-2132      LD92OIPR 2133-2134
        LD94OIPR 2135-2136      LD96OIPR 2137-2138      LDPOPEST 2139-2145
        LD88IDU 2146-2151       LD88CONF 2152-2153      LD88GEO 2154-2155
        LD88TRAN 2156-2157      LD88IMM 2158-2159       LD88EMI 2160-2161
        LD90IDU 2162-2167       LD90CONF 2168-2169      LD90GEO 2170-2171
        LD90TRAN 2172-2173      LD90IMM 2174-2175       LD90EMI 2176-2177
        LD92IDU 2178-2183       LD92CONF 2184-2185      LD92GEO 2186-2187
        LD92TRAN 2188-2189      LD92IMM 2190-2191       LD92EMI 2192-2193
        LD94IDU 2194-2199       LD94CONF 2200-2201      LD94GEO 2202-2203
        LD94TRAN 2204-2205      LD94IMM 2206-2207       LD94EMI 2208-2209
        LD96IDU 2210-2215       LD96CONF 2216-2217      LD96GEO 2218-2219
        LD96TRAN 2220-2221      LD96IMM 2222-2223       LD96EMI 2224-2225
        LD88HL 2226-2227        LD88JAIL 2228-2229      LD88TRNS 2230-2231
        LD88INST 2232-2233      LD90HL 2234-2235        LD90JAIL 2236-2237
        LD90TRNS 2238-2239      LD90INST 2240-2241      LD92HL 2242-2243
        LD92JAIL 2244-2245      LD92TRNS 2246-2247      LD92INST 2248-2249
        LD94HL 2250-2251        LD94JAIL 2252-2253      LD94TRNS 2254-2255
        LD94INST 2256-2257      LD96HL 2258-2259        LD96JAIL 2260-2261
        LD96TRNS 2262-2263      LD96INST 2264-2265      LD88MALE 2266-2267
        LD90MALE 2268-2269      LD92MALE 2270-2271      LD94MALE 2272-2273
        LD96MALE 2274-2275      LD88FEM 2276-2277       LD90FEM 2278-2279
        LD92FEM 2280-2281       LD94FEM 2282-2283       LD96FEM 2284-2285
        LD88U25 2286-2287       LD90U25 2288-2289       LD92U25 2290-2291
        LD94U25 2292-2293       LD96U25 2294-2295       LD882535 2296-2297
        LD902535 2298-2299      LD922535 2300-2301      LD942535 2302-2303
        LD962535 2304-2305      LD88G35 2306-2307       LD90G35 2308-2309
        LD92G35 2310-2311       LD94G35 2312-2313       LD96G35 2314-2315
        LD88BLA 2316-2317       LD90BLA 2318-2319       LD92BLA 2320-2321
        LD94BLA 2322-2323       LD96BLA 2324-2325       LD88WHIT 2326-2327
        LD90WHIT 2328-2329      LD92WHIT 2330-2331      LD94WHIT 2332-2333
        LD96WHIT 2334-2335      LD88HISP 2336-2337      LD90HISP 2338-2339
        LD92HISP 2340-2341      LD94HISP 2342-2343      LD96HISP 2344-2345
        LD88OTHR 2346-2347      LD90OTHR 2348-2349      LD92OTHR 2350-2351
        LD94OTHR 2352-2353      LD96OTHR 2354-2355      LD88OTH 2356-2357
        LD90OTH 2358-2359       LD92OTH 2360-2361       LD94OTH 2362-2363
        LD96OTH 2364-2365       LD88HER 2366-2367       LD90HER 2368-2371 .1
        LD92HER 2372-2375 .1    LD94HER 2376-2379 .1    LD96HER 2380-2383 .1
        LD88COC 2384-2386       LD90COC 2387-2391 .1    LD92COC 2392-2396 .1
        LD94COC 2397-2401 .1    LD96COC 2402-2406 .1    LD88SPED 2407-2408
        LD90SPED 2409-2412 .1   LD92SPED 2413-2416 .1   LD94SPED 2417-2420 .1
        LD96SPED 2421-2424 .1   LD88METH 2425-2426      LD90METH 2427-2428
        LD92METH 2429-2430      LD94METH 2431-2434 .1   LD96METH 2435-2436
        LD88OTDR 2437-2438      LD90OTDR 2439-2440      LD92OTDR 2441-2442
        LD94OTDR 2443-2444      LD96OTDR 2445-2446      LD88CON1 2447-2448
        LD90CON1 2449-2450      LD92CON1 2451-2452      LD94CON1 2453-2454
        LD96CON1 2455-2456      LD88HERA 2457-2458      LD90HERA 2459-2460
        LD92HERA 2461-2462      LD94HERA 2463-2464      LD96HERA 2465-2466
        LD88COCA 2467-2468      LD90COCA 2469-2470      LD92COCA 2471-2472
        LD94COCA 2473-2474      LD96COCA 2475-2476      LD88SPDA 2477-2478
        LD90SPDA 2479-2480      LD92SPDA 2481-2482      LD94SPDA 2483-2484
        LD96SPDA 2485-2486      LD88META 2487-2488      LD90META 2489-2490
        LD92META 2491-2492      LD94META 2493-2494      LD96META 2495-2496
        LD88OTHA 2497-2498      LD90OTHA 2499-2500      LD92OTHA 2501-2502
        LD94OTHA 2503-2504      LD96OTHA 2505-2506      LD88HERP 2507-2508
        LD90HERP 2509-2510      LD92HERP 2511-2512      LD94HERP 2513-2514
        LD96HERP 2515-2516      LD88COCP 2517-2518      LD90COCP 2519-2520
        LD92COCP 2521-2522      LD94COCP 2523-2524      LD96COCP 2525-2526
        LD88SPDP 2527-2528      LD90SPDP 2529-2530      LD92SPDP 2531-2532
        LD94SPDP 2533-2534      LD96SPDP 2535-2536      LD88METP 2537-2538
        LD90METP 2539-2540      LD92METP 2541-2542      LD94METP 2543-2544
        LD96METP 2545-2546      LD88OTHP 2547-2548      LD90OTHP 2549-2550
        LD92OTHP 2551-2552      LD94OTHP 2553-2554      LD96OTHP 2555-2556
        LD88POP 2557-2558       LD90POP 2559-2562 .1    LD92POP 2563-2566 .1
        LD94POP 2567-2570 .1    LD96POP 2571-2574 .1    LD88CON2 2575-2576
        LD90CON2 2577-2578      LD92CON2 2579-2580      LD94CON2 2581-2582
        LD96CON2 2583-2584      LD88GAL 2585-2586       LD90GAL 2587-2588
        LD92GAL 2589-2590       LD94GAL 2591-2592       LD96GAL 2593-2594
        LD88NGAL 2595-2596      LD90NGAL 2597-2598      LD92NGAL 2599-2600
        LD94NGAL 2601-2602      LD96NGAL 2603-2604      LD88DISP 2605-2606
        LD90DISP 2607-2608      LD92DISP 2609-2610      LD94DISP 2611-2612
        LD96DISP 2613-2614      LD88HAR 2615-2616       LD90HAR 2617-2618
        LD92HAR 2619-2620       LD94HAR 2621-2622       LD96HAR 2623-2624
        LD88INIT 2625-2626      LD90INIT 2627-2628      LD92INIT 2629-2630
        LD94INIT 2631-2632      LD96INIT 2633-2634      LD88NINI 2635-2636
        LD90NINI 2637-2638      LD92NINI 2639-2640      LD94NINI 2641-2642
        LD96NINI 2643-2644      LD88CON3 2645-2646      LD90CON3 2647-2648
        LD92CON3 2649-2650      LD94CON3 2651-2652      LD96CON3 2653-2654
        LD88AVAI 2655-2656      LD90AVAI 2657-2658      LD92AVAI 2659-2660
        LD94AVAI 2661-2662      LD96AVAI 2663-2664      LD88BLCH 2665-2666
        LD90BLCH 2667-2668      LD92BLCH 2669-2670      LD94BLCH 2671-2672
        LD96BLCH 2673-2674      LDINTYR 2675-2678       LDINTSVC 2679-2680
        LDINTNED 2681-2682      LDINTSRC 2683-2684      LDINTTRT 2685-2686
        LDINTACC 2687-2688      PHARMAVA 2689-2690      NEEDLEAV 2691-2692
        DIABAVA 2693-2694       DEALERAV 2695-2696      GALLERAV 2697-2698
        AVAIL 2699-2700         AVAIL88 2701-2702       AVAIL90 2703-2704
        AVAIL92 2705-2706       AVAIL94 2707-2708       AVAIL96 2709-2710
        PHARMUSE 2711-2712      NEEDLUSE 2713-2714      DIABUSE 2715-2716
        DLRUSE 2717-2718        GALLERUS 2719-2720      USED 2721-2722
        USED88 2723-2724        USED90 2725-2726        USED92 2727-2728
        USED94 2729-2730        USED96 2731-2732        NEP 2733-2734
        NEP88 2735-2736         NEP90 2737-2738         NEP92 2739-2740
        NEP94 2741-2742         NEP96 2743-2744         INTPRO88 2745-2746
        INTPRO90 2747-2748      INTPRO92 2749-2750      INTPRO94 2751-2752
        INTPRO96 2753-2754      RCHD88 2755-2756        RCHD90 2757-2758
        RCHD92 2759-2760        RCHD94 2761-2762        RCHD96 2763-2764
        PROGTOT 2765-2766       RCHDTOT 2767-2769       NORX 2770-2771
        DRUGTRTP 2772-2773      HIVTESTP 2774-2775      STDPROG 2776-2777
        HIVORPRG 2778-2779      OTHORPRG 2780-2781      HIVCMPRG 2782-2783
        OTHCMPRG 2784-2785      MEDSVPRG 2786-2787      HLPROG 2788-2789
        OTHINTPR 2790-2791      DRUGTRTR 2792-2793      HIVTESTR 2794-2795
        STDRCHD 2796-2797       HIVORRCH 2798-2799      OTHORRCH 2800-2801
        HIVCMRCH 2802-2803      OTHCMRCH 2804-2805      MEDSVRCH 2806-2807
        HLRCHD 2808-2809        OTHINTR 2810-2811       EARLY 2812-2813
        DESIGN 2814-2815        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'DUMMY CASEID - NOT LINKABLE TO RESPONDEN'
   SITECODE= 'New site (same site, same random recode)'
   SI1     = 'SI RECRUITMENT BY RECEPTIONIST/CLERKS'
   SI2     = 'SI RECRUITMENT BY OUTREACH WORKERS'
   SI3     = 'SI RECRUITMENT BY INTERVIEWERS'
   SI4     = 'SI RECRUITMENT BY HIV INTERVENTIONISTS'
   SI5     = 'SI RECRUITMENT BY OTHER RECRUITERS'
   SI6_1   = 'SI # MALE OUTREACH WORKERS'
   SI6_2   = 'SI # FEMALE OUTREACH WORKERS'
   SI7_1   = 'SI # WHITE OUTREACH WORKERS'
   SI7_2   = 'SI # BLACK OUTREACH WORKERS'
   SI7_3   = 'SI # HISPANIC OUTREACH WORKERS'
   SI7_4   = 'SI # OTHER OUTREACH WORKERS'
   SI7_5   = 'SI # OUTREACH WORKERS:NA'
   SI8     = 'SI % OUTREACH WORKER TURNOVER RATE'
   SI9     = 'SI AVG # CONTACTS BEFORE RECRUITMENT'
   SI10_1  = 'SI RANGE OF NUMBER OF CONTACTS (LOWER)'
   SI10B_2 = 'SI RANGE OF NUMBER OF CONTACTS (UPPER)'
   SI11    = 'SI AVERAGE TIME PER CONTACT (MINS)'
   SI12_1  = 'SI RANGE OF MINS PER CONTACT (LOWER)'
   SI12_2  = 'SI RANGE OF MINS PER CONTACT (UPPER)'
   SI13    = 'SI AVG PERCENT WALK-INS'
   SI14    = 'SI OUTREACH: DESCRIPTION OF STUDY'
   SI15    = 'SI OUTREACH: OFFER HIV TEST'
   SI16    = 'SI OUTREACH: DISTRIBUTE HIV LIT.'
   SI17    = 'SI OUTREACH: DISTRIBUTE CONDOMS'
   SI18    = 'SI OUTREACH: DEMONSTRATE CONDOMS'
   SI19    = 'SI OUTREACH: DISTRIBUTE BLEACH'
   SI20    = 'SI OUTREACH: DEMO NEEDLE DISINFECTION'
   SI21    = 'SI OUTREACH: DISTRIBUTE RINSE WATER'
   SI22_1  = 'SI OUTREACH: MONETARY REIMBURSEMENT'
   SI22_2  = 'SI OUTREACH: RECRUITMENT REIMBURSEMENT'
   SI23    = 'SI OUTREACH: ROUTINELY DISTRIB OTH LIT'
   SI24    = 'SI OUTREACH: DISTRIBUTE OTH LIT ON REQ'
   SI25    = 'SI SPECIAL RECRUITMENT CRITERIA'
   SI26    = 'SI RECRUITMENT CRITERIA CHANGED'
   SI27    = 'SI HOMELESS NOT RECRUITED'
   SI28    = 'SI PERSONS LEAVING AREA NOT RECRUITED'
   SI29    = 'SI OTHER RECRUITMENT CRITERIA'
   SI30    = 'SI INDIVIDUAL RANDOM ASSIGNMENT'
   SI31    = 'SI DAY/WEEK RANDOM ASSIGNMENT'
   SI32    = 'SI NEIGHBORHOOD ASSIGNMENT'
   SI32A   = 'SI CROSSOVER DESIGN'
   SI33    = 'SI OTHER SAMPLING/ASSIGNMENT DESIGN'
   SI34    = 'SI INTAKE: RECEPTIONISTS/CLERKS'
   SI35    = 'SI INTAKE: OUTREACH WORKERS'
   SI36    = 'SI INTAKE: INTERVIEWERS'
   SI37    = 'SI INTAKE: HIV INTERVENTIONISTS'
   SI38    = 'SI INTAKE: ASSESSMENT CENTER COORDS'
   SI39    = 'SI INTAKE: OTHER INTAKE PERSONNEL'
   SI40    = 'SI INTAKE: MATCH STAFF TO CLIENT'
   SI40A   = 'SI INTAKE: MATCH ON LANGUAGE'
   SI40B   = 'SI INTAKE: MATCH ON GENDER'
   SI40C   = 'SI INTAKE: MATCH ON RACE/ETHNICITY'
   SI40D   = 'SI INTAKE: MATCH ON OTHER'
   SI41    = 'SI INTAKE TURNOVER RATE'
   SI42    = 'SI INTAKE: EXPLAIN RESEARCH'
   SI43    = 'SI INTAKE: CONFIRM ELIGIBILITY'
   SI43A   = 'SI INTAKE: CHECK TRACK MARKS'
   SI43B   = 'SI INTAKE: TEST URINE'
   SI43C   = 'SI INTAKE: CONFIRM AGE (18+)'
   SI43D   = 'SI INTAKE: CONFIRM OUT OF TREATMENT'
   SI43E   = 'SI INTAKE: NOT PARTICIPATED IN CA'
   SI43F   = 'SI INTAKE: OTHER ELIGIBILITY CRITERIA'
   SI44    = 'SI INTAKE: INFORMED CONSENT'
   SI45    = 'SI INTAKE: OTHER INTAKE PROCEDURES'
   SI46    = 'SI INTAKE: INELIGIBLES REFERRED'
   SI47    = 'SI INTAKE: DATA ON INELIGIBLES KEPT'
   SI48    = 'SI AVERAGE TIME IN INTAKE (MINS)'
   SI48_1  = 'SI RANGE OF TIME IN INTAKE(MINS)(LOWER)'
   SI48_2  = 'SI RANGE OF TIME IN INTAKE(MINS)(UPPER)'
   SI49    = 'SI INTAKE: ADMINISTRATION OF RBA'
   SI49A   = 'SI AVERAGE TIME FOR RBA (MINS)'
   SI49_1  = 'SI RANGE OF TIME FOR RBA(MINS)(LOWER)'
   SI49_2  = 'SI RANGE OF TIME FOR RBA(MINS)(UPPER)'
   SI50    = 'SI INTAKE: ADMINISTER SUPPLEMENTALS'
   SI50A   = 'SI AVERAGE TIME FOR SUPPLS (MINS)'
   SI50A_1 = 'SI RANGE OF TIME FOR SUPPLS(MINS)(LOWER)'
   SI50A_2 = 'SI RANGE OF TIME FOR SUPPLS(MINS)(UPPER)'
   SI51_1  = 'SI INTAKE: REIMBURSEMENT FOR RBA'
   SI51_2  = 'SI INTAKE: RBA REIMBURSEMENT'
   SI52_1  = 'SI INTAKE: REIMBURSEMENT FOR SUPPLS'
   SI52_2  = 'SI INTAKE: SUPPLS REIMBURSEMENT'
   SI54    = 'SI INTAKE: OTHER INCENTIVES'
   SI55    = 'SI RBA MATCH TO STAFF TO CLIENT'
   SI55A   = 'SI RBA MATCH ON LANGUAGE'
   SI55B   = 'SI RBA MATCH ON GENDER'
   SI55C   = 'SI RBA MATCH ON RACE/ETHNICITY'
   SI55D   = 'SI RBA MATCH ON OTHER'
   SI56    = 'SI S1 INVOLVED RECEPTIONIST/CLERKS'
   SI57    = 'SI S1 INVOLVED OUTREACH WORKERS'
   SI58    = 'SI S1 INVOLVED INTERVIEWERS'
   SI59    = 'SI S1 INVOLVED HIV INTERVENTIONISTS'
   SI60    = 'SI S1 INVOLVED ASSESSMENT CENTER COORDS'
   SI61    = 'SI S1 INVOLVED OTHER PERSONNEL'
   SI62    = 'SI S1 MATCH STAFF TO CLIENT'
   SI62A   = 'SI S1 MATCH ON LANGUAGE'
   SI62B   = 'SI S1 MATCH ON GENDER'
   SI62C   = 'SI S1 MATCH ON RACE/ETHNICITY'
   SI62D   = 'SI S1 MATCH ON OTHER'
   SI63    = 'SI S1 INTERVENTION STAFF TURNOVER RATE'
   SI64    = 'SI SESSION I SAME DAY AS RBA'
   SI65    = 'SI SESSION I AFTER RBA DATE'
   SI65A   = 'SI AVERAGE DAYS RBA TO S1'
   SI66    = 'SI S1 INDIVIDUAL COUNSELING OFFERED'
   SI67    = 'SI S1 COUPLES COUNSELING OFFERED'
   SI68    = 'SI AVERAGE TIME IN SESSION 1 (MINS)'
   SI68_1  = 'SI RANGE OF TIME IN SESS 1(MINS)(LOWER)'
   SI68_2  = 'SI RANGE OF TIME IN SESS 1(MINS)(UPPER)'
   SI69    = 'SI S1 REVIEW OF A CUE CARDS'
   SI69A   = 'SI S1 HOW CUE CARDS USED'
   SI70    = 'SI S1 AUDIO/VIDEO SCREENING'
   SI71    = 'SI S1 DEMONSTRATE NEEDLE CLEANING'
   SI72_1  = 'SI S1 REHEARSE NEEDLE CLEANING'
   SI72_2  = 'SI S1 AVERAGE TIMES REHEARSE CLEANING'
   SI73    = 'SI S1 DISTRIBUTE BLEACH'
   SI74    = 'SI S1 DISTRIBUTE RINSE WATER'
   SI75    = 'SI S1 DEMONSTRATE CONDOM USE'
   SI76_1  = 'SI S1 REHEARSE CONDOM USE'
   SI76_2  = 'SI S1 AVERAGE TIMES REHEARSE CONDOMS'
   SI77    = 'SI S1 DISTRIBUTE CONDOMS'
   SI78A   = 'SI S1 ADDED NEW BLEACH GUIDELINES'
   SI78B   = 'SI S1 ADDED TUBERCULOSIS'
   SI78C   = 'SI S1 ADDED HEPATITIS'
   SI78A_1 = 'SI AVERAGE TIME ADDED SESSION 1 (MINS'
   SI78A_2 = 'SI RANGE OF TIME ADD SESS 1(MINS)(LOWER)'
   SI78A_3 = 'SI RANGE OF TIME ADD SESS 1(MINS)(UPPER)'
   SI79    = 'SI S1 DISTRIBUTE HIV LITERATURE'
   SI80    = 'SI S1 DISTRIBUTE LITERATURE ROUTINELY'
   SI81    = 'SI S1 DISTRIBUTE LITERATURE ON REQUEST'
   SI82    = 'SI S1 CHANGES IN STANDARD INTERVENTION'
   SI83    = 'SI S1 DISCUSS HIV ANTIBODY TEST'
   SI84    = 'SI S1 OTHER ACTIVITIES/MATERIALS'
   SI85_1  = 'SI S1 MONETARY REIMBURSEMENT'
   SI85_2  = 'SI S1 REIMBURSEMENT AMOUNT'
   SI87    = 'SI S1 OTHER INCENTIVES FOR ATTENDANCE'
   SI88    = 'SI S1 ADAPT SI FOR GENDER/ETHNICITY'
   SI89    = 'SI HIV OUTREACH WORKERS INVOLVED'
   SI90    = 'SI HIV INTERVIEWERS INVOLVED'
   SI91    = 'SI HIV PHLEBOTOMISTS INVOLVED'
   SI92    = 'SI HIV HIV INTERVENTIONISTS INVOLVED'
   SI93    = 'SI HIV OTHER PERSONNEL INVOLVED'
   SI94    = 'SI HIV MATCH STAFF TO CLIENT'
   SI94A   = 'SI HIV MATCH ON LANGUAGE'
   SI94B   = 'SI HIV MATCH ON GENDER'
   SI94C   = 'SI HIV MATCH ON RACE/ETHNICITY'
   SI94D   = 'SI HIV MATCH ON OTHER'
   SI95    = 'SI HIV TEST STAFF TURNOVER RATE'
   SI96    = 'SI HIV TESTING OFFERED TO ALL CLIENTS'
   SI97    = 'SI HIV TEST REQUIRED FOR PARTICIPATION'
   SI98    = 'SI HIV AVERAGE PERCENT TESTED'
   SI100   = 'SI HIV CONFIRM RESULTS OF HIV+ REFUSERS'
   SI100A  = 'SI HIV OBTAIN CONFIRMING DOCUMENTATION'
   SI100B  = 'SI HIV REPORT CONFIRMATION ON HTR'
   SI101   = 'SI HIV TESTING ON_SITE OFFICE LOCATION'
   SI102   = 'SI HIV TEST AT CLINIC'
   SI102B  = 'SI HIV ROUND TRIP DISTANCE (MILES)'
   SI102C  = 'SI HIV ROUND TRIP TIME (MINUTES)'
   SI103   = 'SI HIV TEST IN MOBILE VAN'
   SI104   = 'SI HIV TESTING REFERRED OUT'
   SI105   = 'SI HIV TESTING AT INTAKE'
   SI105A  = 'SI HIV TEST BEFORE RBA'
   SI105B  = 'SI HIV TEST BEFORE SESSION 1'
   SI105C  = 'SI HIV TIMING OF TEST VARIABLE'
   SI106   = 'SI HIV TESTING AT SESSION 2'
   SI107   = 'SI HIV TESTING AT OTHER TIME'
   SI108   = 'SI HIV SEPARATE ADMIN OF INFORMD CONSENT'
   SI109   = 'SI HIV INCENTIVES FOR TESTING'
   SI109A  = 'SI HIV INCENTIVE AMOUNT'
   SI110   = 'SI HIV ADDITIONAL COUNSELING'
   SI111   = 'SI HIV REPORT HIV+ CLIENTS NAMES'
   SI111A  = 'SI HIV REPORTING HIV+ REQUIRED'
   SI112   = 'SI HIV REPORT AGGREGATED DATA ON HIV+'
   SI113_1 = 'SI HIV TESTING VENOUS'
   SI113_2 = 'SI HIV AVERAGE PERCENT VENOUS'
   SI114_1 = 'SI HIV TESTING FINGERSTICKS'
   SI114_2 = 'SI HIV AVERAGE PERCENT FINGERSTICKS'
   SI115_1 = 'SI HIV TESTING OTHER METHOD'
   SI115_2 = 'SI HIV AVERAGE PERCENT OTHER METHOD'
   SI116   = 'SI S2 OUTREACH WORKERS INVOLVED'
   SI117   = 'SI S2 INTERVIEWERS INVOLVED'
   SI118   = 'SI S2 HIV INTERVENTIONISTS INVOLVED'
   SI119   = 'SI S2 OTHER PERSONNEL INVOLVED'
   SI120   = 'SI S2 MATCH STAFF TO CLIENT'
   SI120A  = 'SI S2 MATCH ON LANGUAGE'
   SI120B  = 'SI S2 MATCH ON GENDER'
   SI120C  = 'SI S2 MATCH ON RACE/ETHNICITY'
   SI120D  = 'SI S2 MATCH ON OTHER'
   SI121   = 'SI S2 INTERVENTION STAFF TURNOVER RATE'
   SI122   = 'SI S2 OUTREACH WRKERS INVOLVD IN LOCATE'
   SI123   = 'SI S2 INTERVIEWERS INVOLVED IN LOCATE'
   SI124   = 'SI S2 HIV INTERVNTNSTS INVLVD IN LOCATE'
   SI125   = 'SI S2 CLERICAL STAFF INVOLVED IN LOCATE'
   SI126   = 'SI S2 OTHER STAFF INVOLVED IN LOCATE'
   SI127   = 'SI SESSION 2 WITHIN 42 DAYS OF S1'
   SI128   = 'SI SESSION 2 > 42 DAYS AFTER S1'
   SI129_1 = 'SI AVERAGE DAYS S1 TO S2'
   SI129_2 = 'SI RANGE OF DAYS S1 TO S2 (LOWER)'
   SI129_3 = 'SI RANGE OF DAYS S1 TO S2 (UPPER)'
   SI130   = 'SI S2 TRACK FOR HIV INDETERMINATES'
   SI131   = 'SI S2 TRACK FOR HIV TEST REFUSERS'
   SI132   = 'SI S2A INDIVIDUAL COUNSELING OFFERED'
   SI133   = 'SI S2A COUPLES/GROUP COUNSELING OFFERED'
   SI134_1 = 'SI AVERAGE TIME IN S2 TRACK A (MINS)'
   SI134_2 = 'SI RANGE OF TIME IN S2 TK A(MINS)(LOWER)'
   SI134_3 = 'SI RANGE OF TIME IN S2 TK A(MINS)(UPPER)'
   SI135   = 'SI S2A PROVIDE HIV TEST RESULTS'
   SI136   = 'SI S2A REVIEW OF ALL A CUE CARDS'
   SI137   = 'SI S2A REVIEW OF A.2_A.7 CUE CARDS'
   SI137A  = 'SI S2A HOW A.2_A.7 CUE CARDS USED'
   SI138   = 'SI S2A REVIEW OF B CUE CARDS'
   SI138A  = 'SI S2A HOW B CUE CARDS USED'
   SI139   = 'SI S2A REVIEW OF C CUE CARDS'
   SI139A  = 'SI S2A HOW C CUE CARDS USED'
   SI140   = 'SI S2A DEMONSTRATE NEEDLE CLEANING'
   SI141   = 'SI S2A REHEARSE NEEDLE CLEANING'
   SI141A  = 'SI S2A AVG TIMES REHEARSE CLEANING'
   SI142   = 'SI S2A DISTRIBUTE BLEACH'
   SI143   = 'SI S2A DISTRIBUTE RINSE WATER'
   SI144   = 'SI S2A DEMONSTRATE CONDOM USE'
   SI145   = 'SI S2A REHEARSE CONDOM USE'
   SI145A  = 'SI S2A AVG TIMES REHEARSE CONDOMS'
   SI146   = 'SI S2A DISTRIBUTE CONDOMS'
   SI147A  = 'SI S2A ADDED NEW BLEACH GUIDELINES'
   SI147B  = 'SI S2A ADDED TUBERCULOSIS'
   SI147C  = 'SI S2A ADDED HEPATITIS'
   SI147A_1= 'SI AVG TIME ADDED SESSION 2 (MINS)'
   SI147A_2= 'SI RANGE OF TIME ADD SESS 2(MIN)(LOWER)'
   SI147A_3= 'SI RANGE OF TIME ADD SESS 2(MIN)(UPPER)'
   SI148   = 'SI S2A DISTRIBUTE HIV LITERATURE'
   SI149   = 'SI S2A DISTRIBUTE OTHER LIT. ROUTINELY'
   SI150   = 'SI S2A DISTRIBUTE LIT. ON REQUEST'
   SI151_1 = 'SI S2A MONETARY REIMBURSEMENT'
   SI151_2 = 'SI S2A REIMBURSEMENT AMOUNT'
   SI153   = 'SI S2A OTHER INCENTIVES'
   SI154   = 'SI S2B INDIVIDUAL COUNSELING'
   SI155   = 'SI S2B COUPLES/GROUP COUNSELING'
   SI156_1 = 'SI AVERAGE TIME IN S2B (MINS)'
   SI156_2 = 'SI RANGE OF TIME IN S2B(MINS)(LOWER)'
   SI156_3 = 'SI RANGE OF TIME IN S2B(MINS)(UPPER)'
   SI157   = 'SI S2B CONFIRM SELF REPORTED HIV RESULTS'
   SI158   = 'SI S2B PROVIDE HIV RESULTS'
   SI159   = 'SI S2B ALLOW TIME FOR CLIENT RESPONSE'
   SI160   = 'SI S2B REVIEW OF A CUE CARDS'
   SI160A  = 'SI S2B HOW A CUE CARDS USED'
   SI161   = 'SI S2B REVIEW OF B CUE CARDS'
   SI161A  = 'SI S2B REVIEW B CUE CARDS USED'
   SI162   = 'SI S2B REVIEW OF C CUE CARDS'
   SI162A  = 'SI S2B HOW C CUE CARDS USED'
   SI163   = 'SI S2B DEMONSTRATE NEEDLE CLEANING'
   SI164   = 'SI S2B REHEARSE NEEDLE CLEANING'
   SI164A  = 'SI S28 AVG TIMES REHEARSE CLEANING'
   SI165   = 'SI S2B DISTRIBUTE BLEACH'
   SI166   = 'SI S2B DISTRIBUTE RINSE WATER'
   SI167   = 'SI S2B DEMONSTRATE CONDOM USE'
   SI168   = 'SI S2B REHEARSE CONDOM USE'
   SI168A  = 'SI S2B AVG TIMES REHEARSE CONDOMS'
   SI169   = 'SI S2B DISTRIBUTE CONDOMS'
   SI170A  = 'SI S2B ADDED NEW BLEACH GUIDELINES'
   SI170B  = 'SI S2B ADDED TUBERCULOSIS'
   SI170C  = 'SI S2B ADDED HEPATITIS'
   SI170A_1= 'SI AVG TIME ADDED S2B (MINS)'
   SI170A_2= 'SI RANGE OF TIME ADDED S2B (MIN)(LOWER)'
   SI170A_3= 'SI RANGE OF TIME ADDED S2B (MIN)(UPPER)'
   SI171   = 'SI S2B DISTRIBUTE HIV LITERATURE'
   SI172   = 'SI S2B DISTRIBUTE OTHER LIT ROUTINELY'
   SI173   = 'SI S2B DISTRIBUTE OTH LIT. ON REQUEST'
   SI174_1 = 'SI S2B MONETARY REIMBURSEMENT'
   SI174_2 = 'SI S2B REIMBURSEMENT AMOUNT'
   SI176   = 'SI S2B OTHER INCENTIVES'
   SI177   = 'SI S28 CHANNEL TO EI IF SPECIAL NEEDS'
   SI177A  = 'SI S2B % CHANNELED TO EI'
   SI178   = 'SI S28 WITHDRAW CLIENTS WITH SPEC NEED'
   SI178A  = 'SI S2B % SPECIAL NEED NOT INCL IN STUDY'
   SI179   = 'SI S3 MANDATED FOR TRACK A'
   SI180   = 'SI S3 OPTIONAL FOR TRACK A SERONEG'
   SI180A  = 'SI S3 TRACK A % WHO RETURNED FOR S3'
   SI181   = 'SI S3 MANDATED FOR TRACK B (SERO+)'
   SI182   = 'SI S3 OPTIONAL FOR TRACK B (SERO+)'
   SI182A  = 'S3 TRACK B % WHO RETURN FOR S3'
   SI183   = 'SI S3 OUTREACH WORKERS INVOLVED'
   SI184   = 'SI S3 INTERVIEWERS INVOLVED'
   SI185   = 'SI S3 HIV INTERVENTIONISTS INVOLVED'
   SI186   = 'SI S3 OTHER STAFF INVOLVED'
   SI187   = 'SI SESSION 3 WITHIN 60 DAYS OF S2'
   SI188   = 'SI SESSION 3 > 60 DAYS AFTER S2'
   SI189   = 'SI AVERAGE DAYS S2 TO S3'
   SI190   = 'SI S3 INDIVIDUAL COUNSELING OFFERED'
   SI191   = 'SI S3 COUPLES/GROUP COUNSELING OFFERED'
   SI192_1 = 'SI AVERAGE TIME IN S3 (MINS)'
   SI192_2 = 'SI RANGE OF TIME IN S3 (MIN)(LOWER)'
   SI192_3 = 'SI RANGE OF TIME IN S3 (MIN)(UPPER)'
   SI193   = 'SI S3 SPECIFIC AREAS/MATERIALS OFFERED'
   SI194   = 'SI S3 ACTIVE REFERRALS MADE'
   SI195   = 'SI S3 PASSIVE REFERRALS MADE'
   SI196   = 'SI S3 FOLLOW UP REFERRALS MADE'
   SI197   = 'SI ASSG ALL ELIGIBLE CLIENTS ACCEPTED'
   SI198   = 'SI ASSG ANY SPECIAL CRITERIA'
   SI199   = 'SI ASSG KEEP RECORDS OF REFUSERS'
   SI200_1 = 'SI ASSG ASSIGNED BEFORE RECRUITMENT'
   SI200A  = 'SI ASSG PRIOR TO RECRUITMENT: ASSG BASIS'
   SI201_1 = 'SI ASSG ASSIGNED BEFORE S1'
   SI202_1 = 'SI ASSG AFTER S1'
   SI203_1 = 'SI ASSG BEFORE S2'
   SI204_1 = 'SI ASSG AFTER S2'
   SI205_1 = 'SI ASSG INDIVIDUAL ASSIGNMENT'
   SI206_1 = 'SI ASSG COMMUNITY ASSIGNMENT'
   SI208   = 'SI OPERATING SIMILAR FEDERAL PROJECTS'
   SI209   = 'SI OPERATING SIMILAR STATE PROJECTS'
   SI210   = 'SI OPERATING SIMILAR LOCAL PROJECTS'
   SI211   = 'SI OTHER FEDERAL PROJECTS IN AREA'
   SI212   = 'SI OTHER STATE  PROJECTS IN AREA'
   SI213   = 'SI OTHER LOCAL PROJECTS IN AREA'
   SI215   = 'SI CA CLIENTS IN OTHER PROJS CAN BE ID_D'
   SI216   = 'SI USE GIS TO ID TARGET AREAS'
   SI217   = 'SI OTHER SI ACTIVITIES PLANNED BY RBFA'
   SI217A_1= 'SI AVG MINUTES OF OTHER ACTIVITIES'
   SI217A_2= 'SI RANGE OF TIME OTH ACT(MINS)(LOWER)'
   SI217A_3= 'SI RANGE OF TIME OTH ACT(MINS)(UPPER)'
   SI217B  = 'SI % WHO RETURN FOR OTHER ACTIVITIES'
   SI218   = 'SI OUTREACH CONTACT BTWN S2/S3  and  RBF'
   SI218A  = 'SI PLANNED CONTACT BTWN S2/S3  and  RBFA'
   SI218B  = 'SI DOCUMENTED CONTACT BTWN S2/S3  and  R'
   SI218C  = 'SI NUMBER CONTACTS BTWN S2/S3  and  RBFA'
   SI218D_1= 'SI AVG DUR CONTACTS BTWN S2/S3  and  RBF'
   SI218D_2= 'SI RANGMINS CONTCTS BTWN S2/S3 and RBFA('
   SI218D_3= 'SI RANGMINS CONTCTS BTWN S2/S3 and RBFA('
   SESADUR = 'SI A TOTL DURATION OF STD SES TRACK A'
   SESBDUR = 'SI B TOTL DURATION OF STD SES TRACK B'
   SESAODUR= 'TOTAL DURATION OF STD SES TRACK A +OR'
   SESBODUR= 'TOTAL DURATION OF STD SES TRACK B + OR'
   OUTDUR  = 'TOTAL DURATION OF OUTREACH MINUTES'
   DISTRIB1= 'SI # OF YESES TO DISTRIBUTED ITEMS'
   DISTINJ = 'SI # OF YESES TO INJECTION ITEMS DISTRD'
   DISTSEX = 'SI # OF YESES TO SEX ITEMS DISTRIBUTED'
   REHNDLA = 'SI A AVG TIMES REHRSE NDLE CLNING'
   REHCNDMA= 'SI A AVG TIMES REHRSE CONDOM USE'
   REHALLA = 'SI A AVG TIMES REHRSE NDLE OR CONDOM'
   REHNDLB = 'SI B AVG TIMES REHRSE NDLE CLNING'
   REHCNDMB= 'SI B AVG TIMES REHRSE CONDOM USE'
   REHALLB = 'SI B AVG TIMES REHRSE NDLE OR CONDOM'
   SIDEMOA = 'SI A # DEMOS CONDOM OR NEEDLE'
   SIDEMOB = 'SI B # DEMOS CONDOM OR NEEDLE'
   SIRHSLA = 'SIA RHSL CONDOM OR NEEDLE'
   SIRHSLB = 'SIB RHSL CONDOM OR NEEDLE'
   SIS1    = 'SIS MARKETING BEYOND STREET OUTREACH'
   SIS2A   = 'SIS OR RECRUIT CLIENTS AT HLTH FAIRS'
   SIS2B   = 'SIS OR RECRUIT CLIENTS AT JAILS'
   SIS2C   = 'SIS OR RECRUIT CLIENTS AT CLINICS'
   SIS2D   = 'SIS OR RECRUIT CLIENTS IN OTHER PLACES'
   SIS3    = 'SIS OR # OF MALE CONDOMS DISTRIBUTED'
   SIS4    = 'SIS OR # OF FEMALE CONDOMS DISTRIBUTED'
   SIS5    = 'SIS OR # OF BLEACH BOTTLES DISTRIBUTED'
   SIS6    = 'SIS OR # OF RINSE WATER BOTTLES DISTRD'
   SIS7    = 'SIS OR # OF ALCOHOL SWABS DISTRIBUTED'
   SIS8    = 'SIS OR HOW OFTEN MALE CONDOMS DISTRD'
   SIS9    = 'SIS OR HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS9A   = 'SIS OR HOW OFTEN BLEACH BOTTLES DISTRD'
   SIS10   = 'SIS OR HOW OFTEN RINSE WATER BOTLS DISTR'
   SIS11   = 'SIS OR HOW OFTEN ALCOHOL SWABS DISTRD'
   SIS12   = 'SIS DETERMINE CLIENT COMES FR CATCHMENT'
   SIS12A  = 'SIS IS CATCHMENT ELIGIBILITY REQUIRMENT'
   SIS13   = 'SIS S1 INDIVIDUAL COUNSELING OFFERED'
   SIS14   = 'SIS S1 COUPLES COUNSELING OFFERED'
   SIS15   = 'SIS S1 GROUP COUNSELING OFFERED'
   SIS16   = 'SIS S1 DEMONSTRATN OF FEMALE CONDOM USE'
   SIS17   = 'SIS S1 CLIENT REHEARSL FEMALE CONDOM USE'
   SIS17A  = 'SIS S1 AVG # OF FEMALE CONDOM REHEARSALS'
   SIS18   = 'SIS S1 DISTRIBUTION OF FEMALE CONDOMS'
   SIS19   = 'SIS S1 DISTR OF LIT ON FEMALE CONDOMS'
   SIS20   = 'SIS S1 # MALE CONDOMS DISTRIBUTED/YR'
   SIS21   = 'SIS S1 # FEMALE CONDOMS DISTRIBUTED/YR'
   SIS22   = 'SIS S1 # BLEACH BOTTLES DISTRIBUTED/YR'
   SIS23   = 'SIS S1 # RINSE WATER BOTTLES DISTR/YR'
   SIS24   = 'SIS S1 # ALCOHOL SWABS DISTRIBUTED/YR'
   SIS25   = 'SIS S1 # COOKERS DISTRIBUTED/YR'
   SIS26   = 'SIS S1 # HIV-RELATED LITERATURE DISTR/YR'
   SIS27   = 'SIS S1 # LIT/MATERIALS NOT HIV REL./YR'
   SIS28   = 'SIS S1 HOW OFTEN MALE CONDOMS DISTRD'
   SIS29   = 'SIS S1 HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS30   = 'SIS S1 HOW OFTEN BLEACH DISTRD'
   SIS31   = 'SIS S1 HOW OFTEN RINSE WATER DISTRD'
   SIS32   = 'SIS S1 HOW OFTEN ALCOHOL SWAB DISTRD'
   SIS33   = 'SIS S1 HOW OFTEN COOKERS DISTRD'
   SIS34   = 'SIS S1 HOW OFTEN HIV-RELATED LIT DISTRD'
   SIS35   = 'SIS S1 HOW OFTEN OTHER LIT/MATER DISTRD'
   SIS36A  = 'SIS S1 OFFER COUNSELING ON STDS'
   SIS36B  = 'SIS S1 OFFER COUNSELING ON TB'
   SIS36C  = 'SIS S1 OFFER COUNSELING ON HEPATITIS'
   SIS37A  = 'SIS S1 AVG # MINS ADDED TO SESSION I'
   SIS37B  = 'SIS S1 RANGE (LOWER) MINS ADD TO SES 1'
   SIS37C  = 'SIS S1 RANGE (UPPER) MINS ADD TO SES 1'
   SIS38   = 'SIS S1 OTHER CHG/ALTERATIONS SES I MINS'
   SIS39   = 'SIS S2A INDIVIDUAL COUNSELING OFFERED'
   SIS40   = 'SIS S2A COUPLES COUNSELING OFFERED'
   SIS41   = 'SIS S2A GROUP COUNSELING OFFERED'
   SIS42   = 'SIS S2A DEMONSTRATN OF FEMALE CONDOM USE'
   SIS43   = 'SIS S2A CLIENT REHRSL FEMALE CONDOM USE'
   SIS43A  = 'SIS S2A AVG # OF FEMALE CONDOM REHEARSLS'
   SIS44   = 'SIS S2A DISTRIBUTION OF FEMALE CONDOMS'
   SIS45   = 'SIS S2A DISTR OF LIT ON FEMALE CONDOMS'
   SIS46   = 'SIS S2A # MALE CONDOMS DISTRIBUTED/YR'
   SIS47   = 'SIS S2A # FEMALE CONDOMS DISTRIBUTED/YR'
   SIS48   = 'SIS S2A # BLEACH BOTTLES DISTRIBUTED/YR'
   SIS49   = 'SIS S2A # RINSE WATER BOTTLES DISTR/YR'
   SIS50   = 'SIS S2A # ALCOHOL SWABS DISTRIBUTED/YR'
   SIS51   = 'SIS S2A # COOKERS DISTRIBUTED/YR'
   SIS52   = 'SIS S2A # HIV-RELATD LITERATURE DISTR/YR'
   SIS53   = 'SIS S2A # LIT/MATERIALS NOT HIV REL./YR'
   SIS54   = 'SIS S2A HOW OFTEN MALE CONDOMS DISTRD'
   SIS55   = 'SIS S2A HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS56   = 'SIS S2A HOW OFTEN BLEACH DISTRD'
   SIS57   = 'SIS S2A HOW OFTEN RINSE WATER DISTRD'
   SIS58   = 'SIS S2A HOW OFTEN ALCOHOL SWAB DISTRD'
   SIS59   = 'SIS S2A HOW OFTEN COOKERS DISTRD'
   SIS60   = 'SIS S2A HOW OFTEN HIV-RELATED LIT DISTRD'
   SIS61   = 'SIS S2A HOW OFTEN OTHER LIT/MATER DISTRD'
   SIS62A  = 'SIS S2A OFFER COUNSELING ON STDS'
   SIS62B  = 'SIS S2A OFFER COUNSELING ON TB'
   SIS62C  = 'SIS S2A OFFER COUNSELING ON HEPATITIS'
   SIS63A  = 'SIS S2A AVG # MINS ADDED TO SESSION II'
   SIS63B  = 'SIS S2A RANGE (LOWER) MINS ADD TO SES II'
   SIS63C  = 'SIS S2A RANGE (UPPER) MINS ADD TO SES II'
   SIS64   = 'SIS S2A OTHR CHG/ALTERATIONS SES II MINS'
   SIS65   = 'SIS S2B INDIVIDUAL COUNSELING OFFERED'
   SIS66   = 'SIS S2B COUPLES COUNSELING OFFERED'
   SIS67   = 'SIS S2B GROUP COUNSELING OFFERED'
   SIS68   = 'SIS S2B DEMONSTRATN OF FEMALE CONDOM USE'
   SIS69   = 'SIS S2B CLIENT REHRSL FEMALE CONDOM USE'
   SIS69A  = 'SIS S2B AVG # FEMALE CONDOM REHEARSALS'
   SIS70   = 'SIS S2B DISTRIBUTION OF FEMALE CONDOMS'
   SIS71   = 'SIS S2B DISTR OF LIT ON FEMALE CONDOMS'
   SIS72   = 'SIS S2B # MALE CONDOMS DISTRIBUTED/YR'
   SIS73   = 'SIS S2B # FEMALE CONDOMS DISTRIBUTED/YR'
   SIS74   = 'SIS S2B # BLEACH BOTTLES DISTRIBUTED/YR'
   SIS75   = 'SIS S2B # RINSE WATER BOTTLES DISTR/YR'
   SIS76   = 'SIS S2B # ALCOHOL SWABS DISTRIBUTED/YR'
   SIS77   = 'SIS S2B # COOKERS DISTRIBUTED/YR'
   SIS78   = 'SIS S2B # HIV-RELATD LITERATURE DISTR/YR'
   SIS79   = 'SIS S2B # LIT/MATERIALS NOT HIV REL./YR'
   SIS80   = 'SIS S2B HOW OFTEN MALE CONDOMS DISTRD'
   SIS81   = 'SIS S2B HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS82   = 'SIS S2B HOW OFTEN BLEACH DISTRD'
   SIS83   = 'SIS S2B HOW OFTEN RINSE WATER DISTRD'
   SIS84   = 'SIS S2B HOW OFTEN ALCOHOL SWAB DISTRD'
   SIS85   = 'SIS S2B HOW OFTEN COOKERS DISTRD'
   SIS86   = 'SIS S2B HOW OFTEN HIV-RELATED LIT DISTRD'
   SIS87   = 'SIS S2B HOW OFTEN OTHER LIT/MATER DISTRD'
   SIS88A  = 'SIS S2B OFFER COUNSELING ON STDS'
   SIS88B  = 'SIS S2B OFFER COUNSELING ON TB'
   SIS88C  = 'SIS S2B OFFER COUNSELING ON HEPATITIS'
   SIS89A  = 'SIS S2B AVG # MINS ADDED TO SESSION II'
   SIS89B  = 'SIS S2B RANGE (LOWER) MINS ADD TO SES II'
   SIS89C  = 'SIS S2B RANGE (UPPER) MINS ADD TO SES II'
   SIS90   = 'SIS S2B OTHER CHG/ALTERATIONS SESII MINS'
   SIS91   = 'SIS OTHER ACTIVE PROJECT IN GEOG AREA'
   SIS92   = 'SIS P1 INDIVIDUAL COUNSELING OFFERED'
   SIS93   = 'SIS P1 COUPLES COUNSELING OFFERED'
   SIS94   = 'SIS P1 GROUP COUNSELING OFFERED'
   SIS95   = 'SIS P1 HOW OFTEN MALE CONDOMS DISTRD'
   SIS96   = 'SIS P1 HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS97   = 'SIS P1 HOW OFTEN BLEACH DISTRD'
   SIS98   = 'SIS P1 HOW OFTEN RINSE WATER DISTRD'
   SIS99   = 'SIS P1 HOW OFTEN ALCOHOL SWAB DISTRD'
   SIS100  = 'SIS P1 HOW OFTEN COOKERS DISTRD'
   SIS101  = 'SIS P1 HOW OFTEN HIV-RELATED LIT DISTRD'
   SIS102  = 'SIS P1 HOW OFTEN OTHER LIT/MAT DISTRD'
   SIS103A = 'SIS P1 OFFER COUNSELING ON STDS'
   SIS103B = 'SIS P1 OFFER COUNSELING ON TB'
   SIS103C = 'SIS P1 OFFER COUNSELING ON HEPATITIS'
   SIS106  = 'SIS P2 INDIVIDUAL COUNSELING OFFERED'
   SIS107  = 'SIS P2 COUPLES COUNSELING OFFERED'
   SIS108  = 'SIS P2 GROUP COUNSELING OFFERED'
   SIS109  = 'SIS P2 HOW OFTEN MALE CONDOMS DISTRD'
   SIS110  = 'SIS P2 HOW OFTEN FEMALE CONDOMS DISTRD'
   SIS111  = 'SIS P2 HOW OFTEN BLEACH DISTRD'
   SIS112  = 'SIS P2 HOW OFTEN RINSE WATER DISTRD'
   SIS113  = 'SIS P2 HOW OFTEN ALCOHOL SWAB DISTRD'
   SIS114  = 'SIS P2 HOW OFTEN COOKERS DISTRD'
   SIS115  = 'SIS P2 HOW OFTEN HIV-RELATED LIT DISTRD'
   SIS116  = 'SIS P2 HOW OFTEN OTHER LIT/MAT DISTRD'
   SIS117A = 'SIS P2 OFFER COUNSELING ON STDS'
   SIS117B = 'SIS P2 OFFER COUNSELING ON TB'
   SIS117C = 'SIS P2 OFFER COUNSELING ON HEPATITIS'
   SIS120  = 'SIS P3 INDIVIDUAL COUNSELNG SES OFFERD'
   SIS121  = 'SIS P3 COUPLES COUNSELING SES OFFERED'
   SIS122  = 'SIS P3 GROUP COUNSELING SES OFFERED'
   SIS123  = 'SIS P3 HOW OFTEN MALE CONDOMS DISTR'
   SIS124  = 'SIS P3 HOW OFTEN FEMALE CONDOMS DISTR'
   SIS125  = 'SIS P3 HOW OFTEN BLEACH DISTR'
   SIS126  = 'SIS P3 HOW OFTEN RINSE WATER DISTR'
   SIS127  = 'SIS P3 HOW OFTEN ALCOHOL SWAB DISTR'
   SIS128  = 'SIS P3 HOW OFTEN COOKERS DISTR'
   SIS129  = 'SIS P3 HOW OFTEN HIV-RELATED LIT DISTR'
   SIS130  = 'SIS P3 HOW OFTEN OTHER LIT/MAT DISTR'
   SIS131A = 'SIS P3 OFFER COUNSELING ON STDS'
   SIS131B = 'SIS P3 OFFER COUNSELING ON TB'
   SIS131C = 'SIS P3 OFFER COUNSELING ON HEPATITIS'
   SIS134  = 'SIS CLIENTS USED NEEDLE EXCHANGE'
   SIS135  = 'SIS CLIENTS USED SERVICES OF STD CLIN'
   SIS136  = 'SIS CLIENTS USED METHADONE MAINT'
   SIS137  = 'SIS CLIENTS USD DRG TX BEYOND METHADONE'
   SIS138  = 'SIS CLIENTS USED MEDICAL SVS FOR HIV'
   SIS139  = 'SIS CLIENTS USED OF HIV CASE MGRS'
   SIS140  = 'SIS CLIENTS USED OTHER TYPES OF CM'
   SIS141  = 'SIS CLIENTS USED HOMELESS PROGRAMS'
   SIS142  = 'OTHER RELATED PROGRAMS'
   EINUM   = 'EI ENHANCED INTERVENTION NUMBER'
   EI1     = 'EI  # OF PLANNED/EXPECTED ENHANCED SES'
   EI2_1   = 'EI % OF SESSIONS IN PROJECT OFFICE'
   EI2_2   = 'EI % OF SESSIONS IN COMMUNITY CENTER'
   EI2_3   = 'EI % OF SESSIONS IN CLIENTS HOME'
   EI2_4   = 'EI % OF SESSIONS ON STREET'
   EI2_5   = 'EI % OF SESSIONS IN VAN'
   EI2_6   = 'EI % OF SESSIONS IN OTHER SETTING'
   EI3A_1  = 'EI # OF SESSIONS IN AN INDIV SETTING'
   EI3A_2  = 'EI # OF SESSIONS FOR COUPLES'
   EI3A_3  = 'EI # OF PURPOSIVE GROUP SESSIONS'
   EI3A_4  = 'EI # OF CHANCE GROUP SESSION'
   EI3B    = 'EI ENHANCED SESSION STRUCTURE'
   EI4A_1  = 'EI EXPECTED MINUTES IN GROUP SESSIONS'
   EI4A_2  = 'EI EXPECTED MINUTES IN INDIV SESSIONS'
   EI4B_3  = 'EI EXPECT MINS OUTREACH INTERVENTIONIST'
   EI4B_4  = 'EI EXPECT MINS BY INTERVENTIONIST'
   EI4B_5  = 'EI EXPECT MINS BY PEER SUPPORT VOLUNTEER'
   EI4B_6  = 'EI EXPECT MINS WITH OTHER INTERVENTNIST'
   EI5_1   = 'EI EXPECTED INTERVAL(1ST-LAST SES)-DAYS'
   EI5_2   = 'EI EXPECTED INTERVAL(1ST-LAST SES)-WKS'
   EI6     = 'EI # DAYS AFTER STANDARD ENHANCED COMPL'
   EI7A_1  = 'EI IMPORTANCE OF FREQUENCY OF DRUG USE'
   EI7A_2  = 'EI IMPORTANCE OF DIRECT SHARING'
   EI7A_3  = 'EI IMPORTANCE OF INDIRECT SHARING'
   EI7A_4  = 'EI IMPORTANCE OF BLEACHING'
   EI7A_5  = 'EI IMPORTANCE OF SHARING COOKERS'
   EI7A_6  = 'EI IMPORTANCE OF SHARING RINSE WATER'
   EI7A_7  = 'EI IMPORTANCE OF DRUG TREATMENT'
   EI7A_8  = 'EI IMPORTANCE OF USE OF NEW NEEDLES'
   EI7A_9  = 'EI IMPORTANCE OF REDUCING # OF DRUGS'
   EI7A_10 = 'EI IMPORTANCE OF REDUCNG SHARING PARTNER'
   EI7A_11 = 'EI IMPORTANCE OF DRUG USE WITH STRANGERS'
   EI7A_12 = 'EI IMPORTANCE OF OTHER DRUG USE'
   EI7B_1  = 'EI IMPORTANCE OF NUMBER OF SEX PARTNERS'
   EI7B_2  = 'EI IMPORTANCE OF FREQUENCY OF SEX'
   EI7B_3  = 'EI IMP OF UNPROTECTED VAGINAL SEX'
   EI7B_4  = 'EI IMP OF UNPROTECTED ORAL SEX'
   EI7B_5  = 'EI IMP OF UNPROTECTED ANAL SEX'
   EI7B_6  = 'EI IMP OF NON-PENETRATIVE SEX'
   EI7B_7  = 'EI IMP OF REDUCING # SEX PARTNERS'
   EI7B_8  = 'EI IMP OF AVOIDING SEX W STRANGERS'
   EI7B_9  = 'EI IMP OF AVOIDING SEX W HIV UNKNOWN'
   EI7B_10 = 'EI IMPORTANCE OF OTHER SEX BEHAVIOR'
   EI8A_1  = 'EI IMP OF INTERVENTNIST DEMONSTR SKILLS'
   EI8A_2  = 'EI IMP OF REHEARSAL OF SKILLS BY CLIENTS'
   EI8A_3  = 'EI IMP OF ROLE PLAY'
   EI8A_4  = 'EI IMP OF ASSESSMENT OF HIV RISKS'
   EI8A_5  = 'EI IMP OF NEEDS ASSESSMENT'
   EI8A_6  = 'EI IMP OF GOAL SETTING'
   EI8A_7  = 'EI IMP OF AUDIO-VISUAL AIDS'
   EI8A_8  = 'EI IMP OF INFORMAL SOCIAL ACTIVITIES'
   EI8A_9  = 'EI IMP OF DISTRIBUTION OF CLOTHING, ETC'
   EI8A_10 = 'EI IMP OF COMMUNITY CONTACT FOR SUPPORT'
   EI8A_11 = 'EI IMP OF PROVIDING SUPPLIES'
   EI8A_12 = 'EI IMP OF DIDACTIC PRESENTATION OF INFO'
   EI8A_13 = 'EI IMP OF PREVENTION DISCUSSION'
   EI8A_14 = 'EI IMP OF OTHER GENERAL ACTIVITIES'
   EI8B_1  = 'EI IMP OF FACILITATING DRUG TREATMENT'
   EI8B_2  = 'EI IMP OF FACILITATING HEALTH/MED CARE'
   EI8B_3  = 'EI IMP OF FACILTATE VOC/ED,FD STMPS,HSNG'
   EI8B_4  = 'EI IMP OF FACILITATE OTHR COMM SVCS SPEC'
   EI9     = 'EI REMINDER CONTACTS BETWEEN SESSIONS'
   EI10    = 'EI INCENTIVES FOR ATTENDANCE'
   EI11_1  = 'EI IMPORTANCE OF TOPIC - DRUG ABUSE'
   EI11_2  = 'EI IMPORTANCE OF TOPIC - DRUG TREATMENT'
   EI11_3  = 'EI IMPORTANCE OF TOPIC - HIV/AIDS'
   EI11_4  = 'EI IMPORTANCE OF TOPIC - STDS'
   EI11_5  = 'EI IMPORTANCE OF TOPIC - SEXUALITY'
   EI11_6  = 'EI IMPORTANCE OF TOPIC - TUBERCULOSIS'
   EI11_7  = 'EI IMP OF TOPIC-OTHR COMMUNICBL DISEASES'
   EI11_8  = 'EI IMPORTANCE OF TOPIC - SOCIAL SERVICES'
   EI11_9  = 'EI IMPORTANCE OF TOPIC - MEDICAL CARE'
   EI11_10 = 'EI IMPORTANCE OF TOPIC - DEATH AND DYING'
   EI11_11 = 'EI IMP OF TOPIC - MENTAL HEALTH ISSUES'
   EI11_12 = 'EI IMP OF TOPIC - FAMILY/PARTNER ISSUES'
   EI11_13 = 'EI IMPORTANCE OF TOPIC - WELLNESS ISSUES'
   EI11_14 = 'EI IMP OF TOPIC - CULTURAL/ETHNIC ISSUES'
   EI11_15 = 'EI IMPORTANCE OF TOPIC - OTHER'
   EI12_2  = 'EI NUMBER OF CHANGE DATES'
   EI14_1  = 'EI GEOGRAPHIC AREA RECRUITMENT'
   EI14_2  = 'EI NETWORK RECRUITMENT'
   EI14_3  = 'EI INDIVIDUAL RECRUITMENT'
   EI14_4  = 'EI NEIGHBORHOOD RECRUITMENT'
   EI14_5  = 'EI OTHER RECRUITMENT'
   EIDEMO  = 'EI DEMO CONDOM OR NEEDLE'
   EIRHSL  = 'EI RHSL CONDOM OR NEEDLE'
   EIACTA  = 'EI # RHSL AND DEMO ACTIVITIES (0-3)'
   EIACTB  = 'EI # RHSL AND DEMO ACTIVITIES (0-9)'
   EIDISTA = 'EI # YESES TO DISTRIB ITEMS (0-2)'
   EIDISTB = 'EI # YESES TO DISTRIB ITEMS (0-9)'
   EIDUR   = 'EI DURATION IN MINS OF GRP AND IND SES'
   EIADUR  = 'EI MINS PLUS STD SES A MINS'
   EIBDUR  = 'EI MINS PLUS STD SES B MINS'
   EIAODUR = 'EI MINS + STD SES A + OR MINS'
   EIBODUR = 'EI MINS + STD SES B + OR MINS'
   EIIND   = 'EI IND COUNSELING SES OFFERED'
   EICOUPLE= 'EI COUPLE COUNSELING SES OFFERED'
   EIGROUP = 'EI GROUP COUNSELING SES OFFERED'
   XDAMC   = 'AMC DATE'
   AINTCOU = 'AMC Q1 COUNSELING-TYPE INTERVENTION'
   AINTEDU = 'AMC Q1 EDUCATIONAL-TYPE INTERVENTION'
   AINTBOTH= 'AMC Q1 BOTH (COUN/EDU)-TYPE INTERV'
   AINTOTH = 'AMC Q1 OTHER-TYPE INTERV'
   AINTSP  = 'AMC Q1 (SPECIFY:)-TYPE INTERV'
   AINTAV  = 'AMC Q1 USE OF AUDIOVIS FOR ENH INTERV'
   AAVVIDEO= 'AMC Q1A VIDEO TAPE USED'
   AAVHAND = 'AMC Q1B HANDOUTS USED'
   AAVOTHER= 'AMC Q1C OTHER AUDIO VISUALS USED'
   AAVSP   = 'AMC Q1C (SPECIFY:) AUDIO VISUALS USED'
   AINTDRUG= 'AMC Q2A IN DEPTH DRUG RISK INFO GIVEN'
   AINTSEX = 'AMC Q2A IN DEPTH SEX RISK INFO GIVEN'
   ABARRIER= 'AMC Q2A1 INFO ON BARRIERS TO RISK RED'
   ASUPPORT= 'AMC Q2A2 INFO ON SUPPORTS TO RISK RED'
   ACUES   = 'AMC Q2A3 INFO ON CUES (TRIGGERS)'
   ASETGOAL= 'AMC Q2A4 SETS GOALS FOR BEHAVIOR CHANGE'
   AINTPER = 'AMC Q2A5 PERSONALIZED TO CLIENTS RISK'
   ATB     = 'AMC Q2B TB ED  and  ISSUES'
   AANATOMY= 'AMC Q2B ANATOMY'
   AAPCLIEN= 'AMC Q2B ATT APPTS W/CLIENT TO COMM AGENC'
   ASELFHLP= 'AMC Q2B ATTEND SELF-HELP PROG W/CLIENT'
   ACOMMIT = 'AMC Q2B COMMITMENT ISSUES'
   ACOMPRTN= 'AMC Q2B IMP OF COMMUNICATION W/PARTNERS'
   ACOMPMED= 'AMC Q2B COMPLIANCE W/MED SCHEDULES'
   ALIFPAIN= 'AMC Q2B CURRENT LIFE PAIN'
   ABLDTRST= 'AMC Q2B BUILD TRUST AT BEGINNING'
   ADISCRIM= 'AMC Q2B IMP OF DISCRIMINATION ISSUES'
   ADOMVIOL= 'AMC Q2B IMP OF DOMESTIC VIOLENCE ISSUES'
   AFACACC = 'AMC Q2B FACLTATE ACCESS TO SOC/COMM/MED'
   AFAMISS = 'AMC Q2B FAMILY/PARENTING ISSUES'
   AFOODPRP= 'AMC Q2B FOOD PREPARATION'
   AHLTHTX = 'AMC Q2B HEALTH CARE TX ISSUES'
   AHLTHTOP= 'AMC Q2B HEALTH TOPICS'
   AHOMELES= 'AMC Q2B HOMELESSNESS ISSUES'
   APOSAT  = 'AMC Q2B INC + ATT TWD BEHAV CHNG'
   ALIFPATT= 'AMC Q2B IMP OF LIFE PATTRNS N/REL TO HIV'
   AMORDEMO= 'AMC Q2B MORE DEMO THAN STAND CARE INTERV'
   ANEGSKIL= 'AMC Q2B NEGOTIATION SKILL TRAINING'
   APEERSUP= 'AMC Q2B PEER SUPPORT'
   AROLES  = 'AMC Q2B PERCEIVED GENDER ROLES'
   AREDUBEH= 'AMC Q2B PLEDGE/CONTRACT TO RED RISK BEH'
   APOVERTY= 'AMC Q2B POVERTY ISSUES'
   APWRLES = 'AMC Q2B POWERLESSNESS'
   APROMSLF= 'AMC Q2B PROMOTING SELF-HELP'
   ATBTST  = 'AMC Q2B PROVIDE TB SKIN TEST'
   ADISCST = 'AMC Q2B REPEATED DISCUSSN ON STREET'
   ARESPECT= 'AMC Q2B IMP OF RESPECT'
   AROLPLAY= 'AMC Q2B ROLE PLAYING'
   ASLFEFF = 'AMC Q2B SELF-EFFICACY'
   ASLFENH = 'AMC Q2B SELF-ENHANCEMENT (HYGIENE, ETC)'
   ASLFEST = 'AMC Q2B SELF-ESTEEM'
   ASKLLTRA= 'AMC Q2B SKILL TRAINING'
   ASTRMAN = 'AMC Q2B STRESS MANAGEMENT'
   ASOCIALS= 'AMC Q2B PROVIDE SOCIALS'
   APHOTDEM= 'AMC Q2B PHOTO CLIENT DEMO NDL CLEANING'
   ATALID  = 'AMC Q2B TALENT IDENTIFICATION'
   ATRUST  = 'AMC Q2B IMP OF TRUST'
   AETHCUL = 'AMC Q2B SUPT BEHAV CHG W ETHN/CULTRL VAL'
   AWLLBNG = 'AMC Q2B WELL-BEING'
   AOTH    = 'AMC Q2B RISK ISSUES COVERED OTHER'
   AHIV    = 'AMC Q2C HIV ISSUES ONLY COVERED'
   AOTHISS = 'AMC Q2C ONLY NON-HIV ISSUES COVERED'
   ABOTH   = 'AMC Q2C BOTH HIV and OTHER ISSUES COVERE'
   AHIVFRST= 'AMC Q2C IF BOTH WHICH 1ST: HIV'
   AISSFRST= 'AMC Q2C IF BOTH WHICH 1ST: OTH ISS'
   AIND    = 'AMC Q3 # OF PEOPLE INCLD IN INTERV: IND'
   AGRP    = 'AMC Q3 # OF PEOPLE INCLD IN INTERV: GRP'
   AGRPSZ  = 'AMC Q3 SIZE OF GROUP IN INTERVENTION'
   AGRPCOMP= 'AMC Q3 COMPOSITION OF GROUP INTERV'
   AOTH_   = 'AMC Q3 # OF PEOPLE INCLD IN OTHER INTERV'
   AOTH_SP = 'AMC Q3 (SPECIFY)# OF PEOPLE INCLD IN INT'
   APROJOFF= 'AMC Q4 PROJ OFFICE WAS PLACE OF INTERV'
   ASTREET = 'AMC Q4 STREET WAS PLACE OF INTERV'
   AVAN    = 'AMC Q4 VAN WAS PLACE OF INTERVENTION'
   AOTHPLAC= 'AMC Q4 PLACE OF INTERVENTION WAS OTHER'
   AOTHSPPL= 'AMC Q4 (SPECIFY) PLACE OF INTERVENTION'
   APREF_  = 'AMC Q5 PREFERRED NUMBER OF SESSIONS'
   ASES1   = 'AMC Q6 # OF MINUTES IN SESSION 1'
   ASES2   = 'AMC Q6 # OF MINUTES IN SESSION 2'
   ASES3   = 'AMC Q6 # OF MINUTES IN SESSION 3'
   ASES4   = 'AMC Q6 # OF MINUTES IN SESSION 4'
   ASES5   = 'AMC Q6 # OF MINUTES IN SESSION 5'
   ASES6   = 'AMC Q6 # OF MINUTES IN SESSION 6'
   ANONE   = 'AMC Q7 TYPE OF INTERV REINFORCE: NONE'
   APHONE  = 'AMC Q7 TELEPHONE CALLS AS REINFORCE'
   APHONE_ = 'AMC Q7 # OF TELEPHONE CALLS (SPECIFY:)'
   AOUTWOR = 'AMC Q7 OUTREACH WORKER CONTACTS AS REINF'
   AOUTWOR_= 'AMC Q7 # OUTREACH WRKR CONTACTS AS REINF'
   ADROPSES= 'AMC Q7 DROP-IN SESSIONS AS REINF'
   ADROPSPE= 'AMC Q7 # OF DROP-IN SESSIONS AS REINF#'
   ASUPGRP = 'AMC Q7 SUPPORT GROUPS AS REINF'
   ALGTHSES= 'AMC Q7 DURATION OF DROP-IN SESSIONS'
   AOFTNGRP= 'AMC Q7 HOW OFTEN SUPPORT GROUPS'
   AOTHREIN= 'AMC Q7 OTH TYPE OF INTERV REINFORCE'
   AOTHSP  = 'AMC Q7 OTHER(SPECIFY) TYPE OF INTERV'
   AINCENT = 'AMC Q8 INCENTIVES'
   ADESC   = 'AMC Q8 DESCRIBE INCENTIVES'
   ASTART  = 'AMC Q9 START IMMEDIATELY AFTER SI#2'
   ACOMP   = 'AMC Q9 COMPLETED IMMEDIATELY AFTER SI#2'
   ATOT    = 'AMC Q9 OTH START IN RELATION TO SI#2'
   ATOTSP  = 'AMC Q9 OTH(SPECIFY) START IN REL TO SI#2'
   APAID   = 'AMC Q9 CLIENTS PAID INCENTIVE FOR SI#2'
   AGENDER = 'AMC Q10 COMPOSITION OF GROUPS'
   AHEDM   = 'AMC Q11 MA HEALTH ED INTERVENTIONIST'
   AHEDB   = 'AMC Q11 BA HEALTH ED INTERVENTIONIST'
   AHEDN   = 'AMC Q11 NON DEG HEALTH ED INTERVENTNIST'
   APEERCON= 'AMC Q11 PEER COUNSELOR INTERVENTIONIST'
   ANURSE  = 'AMC Q11 NURSE INTERVENTIONIST'
   ADRGCON = 'AMC Q11 DRUG TX COUNSELOR INTERVENTNIST'
   AOTHINT = 'AMC Q11 OTHER TYPE OF INTERVENTIONIST'
   AOTHSPIN= 'AMC Q11 OTHER(SPECIFY) INTERVENTIONIST'
   ATRANSP = 'AMC Q12 USE VAN FOR TRANS CLIENTS'
   AHIVTEST= 'AMC Q12 USE VAN FOR HIV TESTING'
   AHIVCOUN= 'AMC Q12 USE VAN FOR HIV COUNSELING'
   AURINTST= 'AMC Q12 USE VAN FOR URINE TESTING'
   AOTHIS2 = 'AMC Q2B (SPECIFY)OTH ISS REL TO RISK RED'
   AOTHIS1 = 'AMC Q2B (SPECIFY)OTH ISS REL TO RISK RED'
   AOTHIS3 = 'AMC Q2B (SPECIFY)OTH ISS REL TO RISK RED'
   AINDSZ  = 'AMC INDIVIDUAL SIZE'
   AINDCOMP= 'AMC INDIVIDUAL COMPOSITION'
   LD88HIVP= 'LD88 IDU POP HIV PREVALENCE ESTIMATE'
   LD90HIVP= 'LD90 IDU POP HIV PREVALENCE ESTIMATE'
   LD92HIVP= 'LD92 IDU POP HIV PREVALENCE ESTIMATE'
   LD94HIVP= 'LD94 IDU POP HIV PREVALENCE ESTIMATE'
   LD96HIVP= 'LD96 IDU POPT HIV PREVALENCE ESTIMATE'
   LD88ACCP= 'LD88 ACCURACY OF HIV PREVALENCE ESIMATE'
   LD90ACCP= 'LD90 ACCURACY OF HIV PREVALENCE ESIMATE'
   LD92ACCP= 'LD92 ACCURACY OF HIV PREVALENCE ESIMATE'
   LD94ACCP= 'LD94 ACCURACY OF HIV PREVALENCE ESIMATE'
   LD96ACCP= 'LD96 ACCURACY OF HIV PREVALENCE ESIMATE'
   LD88HIVI= 'LD88 IDU POPULAT HIV INCIDENCE ESTIMATE'
   LD90HIVI= 'LD90 IDU POPULAT HIV INCIDENCE ESTIMATE'
   LD92HIVI= 'LD92 IDU POPULAT HIV INCIDENCE ESTIMATE'
   LD94HIVI= 'LD94 IDU POPULAT HIV INCIDENCE ESTIMATE'
   LD96HIVI= 'LD96 IDU POPULAT HIV INCIDENCE ESTIMATE'
   LD88ACCI= 'LD88 ACCURACY OF HIV INCIDENCE ESTIMATE'
   LD90ACCI= 'LD90 ACCURACY OF HIV INCIDENCE ESTIMATE'
   LD92ACCI= 'LD92 ACCURACY OF HIV INCIDENCE ESTIMATE'
   LD94ACCI= 'LD94 ACCURACY OF HIV INCIDENCE ESTIMATE'
   LD96ACCI= 'LD96 ACCURACY OF HIV INCIDENCE ESTIMATE'
   LD88PHAV= 'LD88 AVAIL OF NEEDLES AT PHARMACIES'
   LD90PHAV= 'LD90 AVAIL OF NEEDLES AT PHARMACIES'
   LD92PHAV= 'LD92 AVAIL OF NEEDLES AT PHARMACIES'
   LD94PHAV= 'LD94 AVAIL OF NEEDLES AT PHARMACIES'
   LD96PHAV= 'LD96 AVAIL OF NEEDLES AT PHARMACIES'
   LD88PHUS= 'LD88 EXTENT PHARMACIES WERE USED BY IDUS'
   LD90PHUS= 'LD90 EXTENT PHARMACIES WERE USED BY IDUS'
   LD92PHUS= 'LD92 EXTENT PHARMACIES WERE USED BY IDUS'
   LD94PHUS= 'LD94 EXTENT PHARMACIES WERE USED BY IDUS'
   LD96PHUS= 'LD96 EXTENT PHARMACIES WERE USED BY IDUS'
   LD88PHAC= 'LD88 ACCURACY RATING FOR PHARMACY INFO'
   LD90PHAC= 'LD90 ACCURACY RATING FOR PHARMACY INFO'
   LD92PHAC= 'LD92 ACCURACY RATING FOR PHARMACY INFO'
   LD94PHAC= 'LD94 ACCURACY RATING FOR PHARMACY INFO'
   LD96PHAC= 'LD96 ACCURACY RATING FOR PHARMACY INFO'
   LD88NEAV= 'LD88 AVAIL OF NEEDLES AT NEEDLE EXCHANGE'
   LD90NEAV= 'LD90 AVAIL OF NEEDLES AT NEEDLE EXCHANGE'
   LD92NEAV= 'LD92 AVAIL OF NEEDLES AT NEEDLE EXCHANGE'
   LD94NEAV= 'LD94 AVAIL OF NEEDLES AT NEEDLE EXCHANGE'
   LD96NEAV= 'LD96 AVAIL OF NEEDLES AT NEEDLE EXCHANGE'
   LD88NEUS= 'LD88 EXT NEEDLE EXCH USED BY IDUS'
   LD90NEUS= 'LD90 EXT NEEDLE EXCH USED BY IDUS'
   LD92NEUS= 'LD92 EXT NEEDLE EXCH USED BY IDUS'
   LD94NEUS= 'LD94 EXT NEEDLE EXCH USED BY IDUS'
   LD96NEUS= 'LD96 EXT NEEDLE EXCH USED BY IDUS'
   LD88NEAC= 'LD88 ACCURACY RATING FOR NEEDLE EXUSE'
   LD90NEAC= 'LD90 ACCURACY RATING FOR NEEDLE EXUSE'
   LD92NEAC= 'LD92 ACCURACY RATING FOR NEEDLE EXUSE'
   LD94NEAC= 'LD94 ACCURACY RATING FOR NEEDLE EXUSE'
   LD96NEAC= 'LD96 ACCURACY RATING FOR NEEDLE EXUSE'
   LD88DBAV= 'LD88 AVAIL OF NEEDLES FROM DIABETICS'
   LD90DBAV= 'LD90 AVAIL OF NEEDLES FROM DIABETICS'
   LD92DBAV= 'LD92 AVAIL OF NEEDLES FROM DIABETICS'
   LD94DBAV= 'LD94 AVAIL OF NEEDLES FROM DIABETICS'
   LD96DBAV= 'LD96 AVAIL OF NEEDLES FROM DIABETICS'
   LD88DBUS= 'LD88 EXT DIABET NEEDLES USED BY IDUS'
   LD90DBUS= 'LD90 EXT DIABET NEEDLES USED BY IDUS'
   LD92DBUS= 'LD92 EXT DIABET NEEDLES USED BY IDUS'
   LD94DBUS= 'LD94 EXT DIABET NEEDLES USED BY IDUS'
   LD96DBUS= 'LD96 EXT DIABET NEEDLES USED BY IDUS'
   LD88DBAC= 'LD88 ACCURACY RATING FOR DIABETIC INFO'
   LD90DBAC= 'LD90 ACCURACY RATING FOR DIABETIC INFO'
   LD92DBAC= 'LD92 ACCURACY RATING FOR DIABETIC INFO'
   LD94DBAC= 'LD94 ACCURACY RATING FOR DIABETIC INFO'
   LD96DBAC= 'LD96 ACCURACY RATING FOR DIABETIC INFO'
   LD88SDAV= 'LD88 AVAIL OF NEEDLES FROM STREET DLRS'
   LD90SDAV= 'LD90 AVAIL OF NEEDLES FROM STREET DLRS'
   LD92SDAV= 'LD92 AVAIL OF NEEDLES FROM STREET DLRS'
   LD94SDAV= 'LD94 AVAIL OF NEEDLES FROM STREET DLRS'
   LD96SDAV= 'LD96 AVAIL OF NEEDLES FROM STREET DLRS'
   LD88SDUS= 'LD88 EXT ST DLRS NEEDLES USED BY IDUS'
   LD90SDUS= 'LD90 EXT ST DLRS NEEDLES USED BY IDUS'
   LD92SDUS= 'LD92 EXT ST DLRS NEEDLES USED BY IDUS'
   LD94SDUS= 'LD94 EXT ST DLRS NEEDLES USED BY IDUS'
   LD96SDUS= 'LD96 EXT ST DLRS NEEDLES USED BY IDUS'
   LD88SDAC= 'LD88 ACC RAT FOR STREET DLRS INFO'
   LD90SDAC= 'LD90 ACC RAT FOR STREET DLRS INFO'
   LD92SDAC= 'LD92 ACC RAT FOR STREET DLRS INFO'
   LD94SDAC= 'LD94 ACC RAT FOR STREET DLRS INFO'
   LD96SDAC= 'LD96 ACC RAT FOR STREET DLRS INFO'
   LD88SGAV= 'LD88 AVAIL OF NEEDLES AT SHOOTING LERY'
   LD90SGAV= 'LD90 AVAIL OF NEEDLES AT SHOOTING LERY'
   LD92SGAV= 'LD92 AVAIL OF NEEDLES AT SHOOTING LERY'
   LD94SGAV= 'LD94 AVAIL OF NEEDLES AT SHOOTING LERY'
   LD96SGAV= 'LD96 AVAIL OF NEEDLES AT SHOOTING LERY'
   LD88SGUS= 'LD88 EXT SHOOT GALS NEEDL USED BY IDUS'
   LD90SGUS= 'LD90 EXT SHOOT GALS NEEDL USED BY IDUS'
   LD92SGUS= 'LD92 EXT SHOOT GALS NEEDL USED BY IDUS'
   LD94SGUS= 'LD94 EXT SHOOT GALS NEEDL USED BY IDUS'
   LD96SGUS= 'LD96 EXT SHOOT GALS NEEDL USED BY IDUS'
   LD88SGAC= 'LD88 ACC RAT FOR SHOOTING GALS INFO'
   LD90SGAC= 'LD90 ACC RAT FOR SHOOTING GALS INFO'
   LD92SGAC= 'LD92 ACC RAT FOR SHOOTING GALS INFO'
   LD94SGAC= 'LD94 ACC RAT FOR SHOOTING GALS INFO'
   LD96SGAC= 'LD96 ACC RAT FOR SHOOTING GALS INFO'
   LD88NE01= 'LD88 PROG1 NEP IN OPERATION OR OPENED'
   LD90NE01= 'LD90 PROG1 NEP IN OPERATION OR OPENED'
   LD92NE01= 'LD92 PROG1 NEP IN OPERATION OR OPENED'
   LD94NE01= 'LD94 PROG1 NEP IN OPERATION OR OPENED'
   LD96NE01= 'LD96 PROG1 NEP IN OPERATION OR OPENED'
   LD88NE02= 'LD88 PROG2 NEP IN OPERATION OR OPENED'
   LD90NE02= 'LD90 PROG2 NEP IN OPERATION OR OPENED'
   LD92NE02= 'LD92 PROG2 NEP IN OPERATION OR OPENED'
   LD94NE02= 'LD94 PROG2 NEP IN OPERATION OR OPENED'
   LD96NE02= 'LD96 PROG2 NEP IN OPERATION OR OPENED'
   LD88NE03= 'LD88 PROG3 NEP IN OPERATION OR OPENED'
   LD90NE03= 'LD90 PROG3 NEP IN OPERATION OR OPENED'
   LD92NE03= 'LD92 PROG3 NEP IN OPERATION OR OPENED'
   LD94NE03= 'LD94 PROG3 NEP IN OPERATION OR OPENED'
   LD96NE03= 'LD96 PROG3 NEP IN OPERATION OR OPENED'
   LD88NEC1= 'LD88 PROG1 NEP CLOSED'
   LD90NEC1= 'LD90 PROG1 NEP CLOSED'
   LD92NEC1= 'LD92 PROG1 NEP CLOSED'
   LD94NEC1= 'LD94 PROG1 NEP CLOSED'
   LD96NEC1= 'LD96 PROG1 NEP CLOSED'
   LD88NEC2= 'LD88 PROG2 NEP CLOSED'
   LD90NEC2= 'LD90 PROG2 NEP CLOSED'
   LD92NEC2= 'LD92 PROG2 NEP CLOSED'
   LD94NEC2= 'LD94 PROG2 NEP CLOSED'
   LD96NEC2= 'LD96 PROG2 NEP CLOSED'
   LD90OP1 = 'LD90 DID NEP PROG1 HAVE 1 FOR 1 POLICY'
   LD92OP1 = 'LD92 DID NEP PROG1 HAVE 1 FOR 1 POLICY'
   LD94OP1 = 'LD94 DID NEP PROG1 HAVE 1 FOR 1 POLICY'
   LD96OP1 = 'LD96 DID NEP PROG1 HAVE 1 FOR 1 POLICY'
   LD92OP2 = 'LD92 DID NEP PROG2 HAVE 1 FOR 1 POLICY'
   LD94OP2 = 'LD94 DID NEP PROG2 HAVE 1 FOR 1 POLICY'
   LD96OP2 = 'LD96 DID NEP PROG2 HAVE 1 FOR 1 POLICY'
   LD94OP3 = 'LD94 DID NEP PROG3 HAVE 1 FOR 1 POLICY'
   LD96OP3 = 'LD96 DID NEP PROG3 HAVE 1 FOR 1 POLICY'
   LD90MAX1= 'LD90 PROG1 NEP MAX # NEEDLES PER VISIT'
   LD92MAX1= 'LD92 PROG1 NEP MAX # NEEDLES PER VISIT'
   LD94MAX1= 'LD94 PROG1 NEP MAX # NEEDLES PER VISIT'
   LD96MAX1= 'LD96 PROG1 NEP MAX # NEEDLES PER VISIT'
   LD94MAX2= 'LD94 PROG2 NEP MAX # NEEDLES PER VISIT'
   LD96MAX2= 'LD96 PROG2 NEP MAX # NEEDLES PER VISIT'
   LD94MAX3= 'LD94 PROG3 NEP MAX # NEEDLES PER VISIT'
   LD96MAX3= 'LD96 PROG3 NEP MAX # NEEDLES PER VISIT'
   LD90ANN1= 'LD90 PROG1 NED ANN VOL NEEDLES EXCH'
   LD92ANN1= 'LD92 PROG1 NED ANN VOL NEEDLES EXCH'
   LD94ANN1= 'LD94 PROG1 NED ANN VOL NEEDLES EXCH'
   LD96ANN1= 'LD96 PROG1 NED ANN VOL NEEDLES EXCH'
   LD96ANN2= 'LD96 PROG2 NED ANN VOL NEEDLES EXCH'
   LD88LAWS= 'LD88 STATE PRESCRIPTION LAWS IN EFFECT'
   LD90LAWS= 'LD90 STATE PRESCRIPTION LAWS IN EFFECT'
   LD92LAWS= 'LD92 STATE PRESCRIPTION LAWS IN EFFECT'
   LD94LAWS= 'LD94 STATE PRESCRIPTION LAWS IN EFFECT'
   LD96LAWS= 'LD96 STATE PRESCRIPTION LAWS IN EFFECT'
   LD88LAWL= 'LD88 LOCAL PRESCRIPTION LAWS IN EFFECT'
   LD90LAWL= 'LD90 LOCAL PRESCRIPTION LAWS IN EFFECT'
   LD92LAWL= 'LD92 LOCAL PRESCRIPTION LAWS IN EFFECT'
   LD94LAWL= 'LD94 LOCAL PRESCRIPTION LAWS IN EFFECT'
   LD96LAWL= 'LD96 LOCAL PRESCRIPTION LAWS IN EFFECT'
   LD88NORX= 'LD88 # NEEDLES SOLD WITHOUT RXS'
   LD90NORX= 'LD90 # NEEDLES SOLD WITHOUT RXS'
   LD92NORX= 'LD92 # NEEDLES SOLD WITHOUT RXS'
   LD94NORX= 'LD94 # NEEDLES SOLD WITHOUT RXS'
   LD96NORX= 'LD96 # NEEDLES SOLD WITHOUT RXS'
   LD88MINP= 'LD88 #NON-RX NDLS SLRS WHO HAD MIN REQ'
   LD90MINP= 'LD90 #NON-RX NDLS SLRS WHO HAD MIN REQ'
   LD92MINP= 'LD92 #NON-RX NDLS SLRS WHO HAD MIN REQ'
   LD94MINP= 'LD94 #NON-RX NDLS SLRS WHO HAD MIN REQ'
   LD96MINP= 'LD96 #NON-RX NDLS SLRS WHO HAD MIN REQ'
   LD88ID  = 'LD88 DID MOST NON-RX NEEDL SLR REQ ID'
   LD90ID  = 'LD90 DID MOST NON-RX NEEDL SLR REQ ID'
   LD92ID  = 'LD92 DID MOST NON-RX NEEDL SLR REQ ID'
   LD94ID  = 'LD94 DID MOST NON-RX NEEDL SLR REQ ID'
   LD96ID  = 'LD96 DID MOST NON-RX NEEDL SLR REQ ID'
   LD88SIG = 'LD88 DID MOST NON-RX NDL SLRS REQ SIG'
   LD90SIG = 'LD90 DID MOST NON-RX NDL SLRS REQ SIG'
   LD92SIG = 'LD92 DID MOST NON-RX NDL SLRS REQ SIG'
   LD94SIG = 'LD94 DID MOST NON-RX NDL SLRS REQ SIG'
   LD96SIG = 'LD96 DID MOST NON-RX NDL SLRS REQ SIG'
   LD88PRDB= 'LD88 DID NON-RX NDL SLRS REQ PRF DIAB'
   LD90PRDB= 'LD90 DID NON-RX NDL SLRS REQ PRF DIAB'
   LD92PRDB= 'LD92 DID NON-RX NDL SLRS REQ PRF DIAB'
   LD94PRDB= 'LD94 DID NON-RX NDL SLRS REQ PRF DIAB'
   LD96PRDB= 'LD96 DID NON-RX NDL SLRS REQ PRF DIAB'
   LD88DTPP= 'LD88 DRUG TX PROGS PRESENT'
   LD90DTPP= 'LD90 DRUG TX PROGS PRESENT'
   LD92DTPP= 'LD92 DRUG TX PROGS PRESENT'
   LD94DTPP= 'LD94 DRUG TX PROGS PRESENT'
   LD96DTPP= 'LD96 DRUG TX PROGS PRESENT'
   LD88DTPR= 'LD88 EXTENT DRUG TX RCHD  PART ICS'
   LD90DTPR= 'LD90 EXTENT DRUG TX RCHD  PART ICS'
   LD92DTPR= 'LD92 EXTENT DRUG TX RCHD  PART ICS'
   LD94DTPR= 'LD94 EXTENT DRUG TX RCHD  PART ICS'
   LD96DTPR= 'LD96 EXTENT DRUG TX RCHD  PART ICS'
   LD88HTCP= 'LD88 HIV TESTING PROGS PRESENT'
   LD90HTCP= 'LD90 HIV TESTING PROGS PRESENT'
   LD92HTCP= 'LD92 HIV TESTING PROGS PRESENT'
   LD94HTCP= 'LD94 HIV TESTING PROGS PRESENT'
   LD96HTCP= 'LD96 HIV TESTING PROGS PRESENT'
   LD88HTCR= 'LD88 EXTENT HIV TESTING RCHD PART ICS'
   LD90HTCR= 'LD90 EXTENT HIV TESTING RCHD PART ICS'
   LD92HTCR= 'LD92 EXTENT HIV TESTING RCHD PART ICS'
   LD94HTCR= 'LD94 EXTENT HIV TESTING RCHD PART ICS'
   LD96HTCR= 'LD96 EXTENT HIV TESTING RCHD PART ICS'
   LD88STDP= 'LD88 STD CLINICS PRESENT'
   LD90STDP= 'LD90 STD CLINICS PRESENT'
   LD92STDP= 'LD92 STD CLINICS PRESENT'
   LD94STDP= 'LD94 STD CLINICS PRESENT'
   LD96STDP= 'LD96 STD CLINICS PRESENT'
   LD88STDR= 'LD88 EXTENT STD CLINICS RCHD PART ICS'
   LD90STDR= 'LD90 EXTENT STD CLINICS RCHD PART ICS'
   LD92STDR= 'LD92 EXTENT STD CLINICS RCHD PART ICS'
   LD94STDR= 'LD94 EXTENT STD CLINICS RCHD PART ICS'
   LD96STDR= 'LD96 EXTENT STD CLINICS RCHD PART ICS'
   LD88HOPP= 'LD88 HIV OUTREACH PROGS PRESENT'
   LD90HOPP= 'LD90 HIV OUTREACH PROGS PRESENT'
   LD92HOPP= 'LD92 HIV OUTREACH PROGS PRESENT'
   LD94HOPP= 'LD94 HIV OUTREACH PROGS PRESENT'
   LD96HOPP= 'LD96 HIV OUTREACH PROGS PRESENT'
   LD88HOPR= 'LD88 EXT HIV OUTREACH RCHD PART ICS'
   LD90HOPR= 'LD90 EXT HIV OUTREACH RCHD PART ICS'
   LD92HOPR= 'LD92 EXT HIV OUTREACH RCHD PART ICS'
   LD94HOPR= 'LD94 EXT HIV OUTREACH RCHD PART ICS'
   LD96HOPR= 'LD96 EXT HIV OUTREACH RCHD PART ICS'
   LD88OOPP= 'LD88 OTHER OUTREACH PROGS PRESENT'
   LD90OOPP= 'LD90 OTHER OUTREACH PROGS PRESENT'
   LD92OOPP= 'LD92 OTHER OUTREACH PROGS PRESENT'
   LD94OOPP= 'LD94 OTHER OUTREACH PROGS PRESENT'
   LD96OOPP= 'LD96 OTHER OUTREACH PROGS PRESENT'
   LD88OOPR= 'LD88 EXT OTH OUTREACH RCHD PART ICS'
   LD90OOPR= 'LD90 EXT OTH OUTREACH RCHD PART ICS'
   LD92OOPR= 'LD92 EXT OTH OUTREACH RCHD PART ICS'
   LD94OOPR= 'LD94 EXT OTH OUTREACH RCHD PART ICS'
   LD96OOPR= 'LD96 EXT OTH OUTREACH RCHD PART ICS'
   LD88HCMP= 'LD88 HIV CASE MANAGEMENT PRESENT'
   LD90HCMP= 'LD90 HIV CASE MANAGEMENT PRESENT'
   LD92HCMP= 'LD92 HIV CASE MANAGEMENT PRESENT'
   LD94HCMP= 'LD94 HIV CASE MANAGEMENT PRESENT'
   LD96HCMP= 'LD96 HIV CASE MANAGEMENT PRESENT'
   LD88HCMR= 'LD88 EXT HIV CASE MAN RCHD PART ICS'
   LD90HCMR= 'LD90 EXT HIV CASE MAN RCHD PART ICS'
   LD92HCMR= 'LD92 EXT HIV CASE MAN RCHD PART ICS'
   LD94HCMR= 'LD94 EXT HIV CASE MAN RCHD PART ICS'
   LD96HCMR= 'LD96 EXT HIV CASE MAN RCHD PART ICS'
   LD88OCMP= 'LD88 OTHER CASE MANAGEMENT PRESENT'
   LD90OCMP= 'LD90 OTHER CASE MANAGEMENT PRESENT'
   LD92OCMP= 'LD92 OTHER CASE MANAGEMENT PRESENT'
   LD94OCMP= 'LD94 OTHER CASE MANAGEMENT PRESENT'
   LD96OCMP= 'LD96 OTHER CASE MANAGEMENT PRESENT'
   LD88OCMR= 'LD88 EXT OTH CASE MAN RCHD PART ICS'
   LD90OCMR= 'LD90 EXT OTH CASE MAN RCHD PART ICS'
   LD92OCMR= 'LD92 EXT OTH CASE MAN RCHD PART ICS'
   LD94OCMR= 'LD94 EXT OTH CASE MAN RCHD PART ICS'
   LD96OCMR= 'LD96 EXT OTH CASE MAN RCHD PART ICS'
   LD88MSP = 'LD88 MEDICAL SVCS FOR HIV + PRESENT'
   LD90MSP = 'LD90 MEDICAL SVCS FOR HIV + PRESENT'
   LD92MSP = 'LD92 MEDICAL SVCS FOR HIV + PRESENT'
   LD94MSP = 'LD94 MEDICAL SVCS FOR HIV + PRESENT'
   LD96MSP = 'LD96 MEDICAL SVCS FOR HIV + PRESENT'
   LD88MSR = 'LD88 EXTENT HIV+SVCS  RCHD PART ICS'
   LD90MSR = 'LD90 EXTENT HIV+SVCS  RCHD PART ICS'
   LD92MSR = 'LD92 EXTENT HIV+SVCS  RCHD PART ICS'
   LD94MSR = 'LD94 EXTENT HIV+SVCS  RCHD PART ICS'
   LD96MSR = 'LD96 EXTENT HIV+SVCS  RCHD PART ICS'
   LD88HLP = 'LD88 HOMELESS PROGRAMS PRESENT'
   LD90HLP = 'LD90 HOMELESS PROGRAMS PRESENT'
   LD92HLP = 'LD92 HOMELESS PROGRAMS PRESENT'
   LD94HLP = 'LD94 HOMELESS PROGRAMS PRESENT'
   LD96HLP = 'LD96 HOMELESS PROGRAMS PRESENT'
   LD88HLR = 'LD88 EXT HOMELESS PROGS RCHD PART ICS'
   LD90HLR = 'LD90 EXT HOMELESS PROGS RCHD PART ICS'
   LD92HLR = 'LD92 EXT HOMELESS PROGS RCHD PART ICS'
   LD94HLR = 'LD94 EXT HOMELESS PROGS RCHD PART ICS'
   LD96HLR = 'LD96 EXT HOMELESS PROGS RCHD PART ICS'
   LD88OIPP= 'LD88 OTHER INTERVENTION PROG PRESENT'
   LD90OIPP= 'LD90 OTHER INTERVENTION PROG PRESENT'
   LD92OIPP= 'LD92 OTHER INTERVENTION PROG PRESENT'
   LD94OIPP= 'LD94 OTHER INTERVENTION PROG PRESENT'
   LD96OIPP= 'LD96 OTHER INTERVENTION PROG PRESENT'
   LD88OIPR= 'LD88 EXTENT OTH INTERV RCHD PART ICS'
   LD90OIPR= 'LD90 EXTENT OTH INTERV RCHD PART ICS'
   LD92OIPR= 'LD92 EXTENT OTH INTERV RCHD PART ICS'
   LD94OIPR= 'LD94 EXTENT OTH INTERV RCHD PART ICS'
   LD96OIPR= 'LD96 EXTENT OTH INTERV RCHD PART ICS'
   LDPOPEST= 'LD EST OF CURRENT CITYS POPULATION'
   LD88IDU = 'LD88 ESTIMATE OF IDU POPULATION'
   LD88CONF= 'LD88 CONFIDENCE IN IDU ESTIMATE'
   LD88GEO = 'LD88 EXTENT IDU POP IN SPEC GEO AREA'
   LD88TRAN= 'LD88 QUALITY OF PUBLIC TRANSPORTATION'
   LD88IMM = 'LD88 EXTENT IDUS IMMIGRATED INTO AREA'
   LD88EMI = 'LD88 EXTENT IDUS EMIGRATED FROM AREA'
   LD90IDU = 'LD90 ESTIMATE OF IDU POPULATION'
   LD90CONF= 'LD90 CONFIDENCE IN IDU ESTIMATE'
   LD90GEO = 'LD90 EXTENT IDU POP IN SPEC GEO AREA'
   LD90TRAN= 'LD90 QUALITY OF PUBLIC TRANSPORTATION'
   LD90IMM = 'LD90 EXTENT IDUS IMMIGRATED INTO AREA'
   LD90EMI = 'LD90 EXTENT IDUS EMIGRATED FROM AREA'
   LD92IDU = 'LD92 ESTIMATE OF IDU POPULATION'
   LD92CONF= 'LD92 CONFIDENCE IN IDU ESTIMATE'
   LD92GEO = 'LD92 EXTENT IDU POP IN SPEC GEO AREA'
   LD92TRAN= 'LD92 QUALITY OF PUBLIC TRANSPORTATION'
   LD92IMM = 'LD92 EXTENT IDUS IMMIGRATED INTO AREA'
   LD92EMI = 'LD92 EXTENT IDUS EMIGRATED FROM AREA'
   LD94IDU = 'LD94 ESTIMATE OF IDU POPULATION'
   LD94CONF= 'LD94 CONFIDENCE IN IDU ESTIMATE'
   LD94GEO = 'LD94 EXTENT IDU POP IN SPEC GEO AREA'
   LD94TRAN= 'LD94 QUALITY OF PUBLIC TRANSPORTATION'
   LD94IMM = 'LD94 EXTENT IDUS IMMIGRATED INTO AREA'
   LD94EMI = 'LD94 EXTENT IDUS EMIGRATED FROM AREA'
   LD96IDU = 'LD96 ESTIMATE OF IDU POPULATION'
   LD96CONF= 'LD96 CONFIDENCE IN IDU ESTIMATE'
   LD96GEO = 'LD96 EXTENT IDU POP IN SPEC GEO AREA'
   LD96TRAN= 'LD96 QUALITY OF PUBLIC TRANSPORTATION'
   LD96IMM = 'LD96 EXTENT IDUS IMMIGRATED INTO AREA'
   LD96EMI = 'LD96 EXTENT IDUS EMIGRATED FROM AREA'
   LD88HL  = 'LD88 CHANGE IN NUMBER OF HOMELESS IDUS'
   LD88JAIL= 'LD88 CHANGE IN NUM OF INCARCERATED IDUS'
   LD88TRNS= 'LD88 CHANGE IN NUMBER OF TRANSIENT IDUS'
   LD88INST= 'LD88 CHANGE IN NUMBER OF INSTITUT IDUS'
   LD90HL  = 'LD90 CHANGE IN NUMBER OF HOMELESS IDUS'
   LD90JAIL= 'LD90 CHANGE IN NUM OF INCARCERATED IDUS'
   LD90TRNS= 'LD90 CHANGE IN NUMBER OF TRANSIENT IDUS'
   LD90INST= 'LD90 CHANGE IN NUMBER OF INSTITUT IDUS'
   LD92HL  = 'LD92 CHANGE IN NUMBER OF HOMELESS IDUS'
   LD92JAIL= 'LD92 CHANGE IN NUM OF INCARCERATED IDUS'
   LD92TRNS= 'LD92 CHANGE IN NUMBER OF TRANSIENT IDUS'
   LD92INST= 'LD92 CHANGE IN NUMBER OF INSTITUT IDUS'
   LD94HL  = 'LD94 CHANGE IN NUMBER OF HOMELESS IDUS'
   LD94JAIL= 'LD94 CHANGE IN NUM OF INCARCERATED IDUS'
   LD94TRNS= 'LD94 CHANGE IN NUMBER OF TRANSIENT IDUS'
   LD94INST= 'LD94 CHANGE IN NUMBER OF INSTITUT IDUS'
   LD96HL  = 'LD96 CHANGE IN NUMBER OF HOMELESS IDUS'
   LD96JAIL= 'LD96 CHANGE IN NUM OF INCARCERATED IDUS'
   LD96TRNS= 'LD96 CHANGE IN NUMBER OF TRANSIENT IDUS'
   LD96INST= 'LD96 CHANGE IN NUMBER OF INSTITUT IDUS'
   LD88MALE= 'LD88 CHANGE IN NUM OF MALE IDUS'
   LD90MALE= 'LD90 CHANGE IN NUM OF MALE IDUS'
   LD92MALE= 'LD92 CHANGE IN NUM OF MALE IDUS'
   LD94MALE= 'LD94 CHANGE IN NUM OF MALE IDUS'
   LD96MALE= 'LD96 CHANGE IN NUM OF MALE IDUS'
   LD88FEM = 'LD88 CHANGE IN NUM OF FEMALE IDUS'
   LD90FEM = 'LD90 CHANGE IN NUM OF FEMALE IDUS'
   LD92FEM = 'LD92 CHANGE IN NUM OF FEMALE IDUS'
   LD94FEM = 'LD94 CHANGE IN NUM OF FEMALE IDUS'
   LD96FEM = 'LD96 CHANGE IN NUM OF FEMALE IDUS'
   LD88U25 = 'LD88 CHANGE IN NUM OF IDUS UNDER 25'
   LD90U25 = 'LD90 CHANGE IN NUM OF IDUS UNDER 25'
   LD92U25 = 'LD92 CHANGE IN NUM OF IDUS UNDER 25'
   LD94U25 = 'LD94 CHANGE IN NUM OF IDUS UNDER 25'
   LD96U25 = 'LD96 CHANGE IN NUM OF IDUS UNDER 25'
   LD882535= 'LD88 CHANGE IN # OF IDUS FROM 25 TO 35'
   LD902535= 'LD90 CHANGE IN # OF IDUS FROM 25 TO 35'
   LD922535= 'LD92 CHANGE IN # OF IDUS FROM 25 TO 35'
   LD942535= 'LD94 CHANGE IN # OF IDUS FROM 25 TO 35'
   LD962535= 'LD96 CHANGE IN # OF IDUS FROM 25 TO 35'
   LD88G35 = 'LD88 CHANGE IN # OF IDUS FROM OVER 35'
   LD90G35 = 'LD90 CHANGE IN # OF IDUS FROM OVER 35'
   LD92G35 = 'LD92 CHANGE IN # OF IDUS FROM OVER 35'
   LD94G35 = 'LD94 CHANGE IN # OF IDUS FROM OVER 35'
   LD96G35 = 'LD96 CHANGE IN # OF IDUS FROM OVER 35'
   LD88BLA = 'LD88 CHANGE IN # OF BLACK IDUS'
   LD90BLA = 'LD90 CHANGE IN # OF BLACK IDUS'
   LD92BLA = 'LD92 CHANGE IN # OF BLACK IDUS'
   LD94BLA = 'LD94 CHANGE IN # OF BLACK IDUS'
   LD96BLA = 'LD96 CHANGE IN # OF BLACK IDUS'
   LD88WHIT= 'LD88 CHANGE IN # OF WHITE IDUS'
   LD90WHIT= 'LD90 CHANGE IN # OF WHITE IDUS'
   LD92WHIT= 'LD92 CHANGE IN # OF WHITE IDUS'
   LD94WHIT= 'LD94 CHANGE IN # OF WHITE IDUS'
   LD96WHIT= 'LD96 CHANGE IN # OF WHITE IDUS'
   LD88HISP= 'LD88 CHANGE IN # OF HISP IDUS'
   LD90HISP= 'LD90 CHANGE IN # OF HISP IDUS'
   LD92HISP= 'LD92 CHANGE IN # OF HISP IDUS'
   LD94HISP= 'LD94 CHANGE IN # OF HISP IDUS'
   LD96HISP= 'LD96 CHANGE IN # OF HISP IDUS'
   LD88OTHR= 'LD88 CHAN IN # OF OTH RACE IDUS'
   LD90OTHR= 'LD90 CHAN IN # OF OTH RACE IDUS'
   LD92OTHR= 'LD92 CHAN IN # OF OTH RACE IDUS'
   LD94OTHR= 'LD94 CHAN IN # OF OTH RACE IDUS'
   LD96OTHR= 'LD96 CHAN IN # OF OTH RACE IDUS'
   LD88OTH = 'LD88 OTHER CHANGES IN IDU POP'
   LD90OTH = 'LD90 OTHER CHANGES IN IDU POP'
   LD92OTH = 'LD92 OTHER CHANGES IN IDU POP'
   LD94OTH = 'LD94 OTHER CHANGES IN IDU POP'
   LD96OTH = 'LD96 OTHER CHANGES IN IDU POP'
   LD88HER = 'LD88 PROP OF IDUS USING HEROIN'
   LD90HER = 'LD90 PROP OF IDUS USING HEROIN'
   LD92HER = 'LD92 PROP OF IDUS USING HEROIN'
   LD94HER = 'LD94 PROP OF IDUS USING HEROIN'
   LD96HER = 'LD96 PROP OF IDUS USING HEROIN'
   LD88COC = 'LD88 PROP OF IDUS USING COCAINE'
   LD90COC = 'LD90 PROP OF IDUS USING COCAINE'
   LD92COC = 'LD92 PROP OF IDUS USING COCAINE'
   LD94COC = 'LD94 PROP OF IDUS USING COCAINE'
   LD96COC = 'LD96 PROP OF IDUS USING COCAINE'
   LD88SPED= 'LD88 PROP OF IDUS USING SPEEDBALL'
   LD90SPED= 'LD90 PROP OF IDUS USING SPEEDBALL'
   LD92SPED= 'LD92 PROP OF IDUS USING SPEEDBALL'
   LD94SPED= 'LD94 PROP OF IDUS USING SPEEDBALL'
   LD96SPED= 'LD96 PROP OF IDUS USING SPEEDBALL'
   LD88METH= 'LD88 PROP OF IDUS USING METH/AMPH'
   LD90METH= 'LD90 PROP OF IDUS USING METH/AMPH'
   LD92METH= 'LD92 PROP OF IDUS USING METH/AMPH'
   LD94METH= 'LD94 PROP OF IDUS USING METH/AMPH'
   LD96METH= 'LD96 PROP OF IDUS USING METH/AMPH'
   LD88OTDR= 'LD88 PROP OF IDUS USING OTH DRUGS'
   LD90OTDR= 'LD90 PROP OF IDUS USING OTH DRUGS'
   LD92OTDR= 'LD92 PROP OF IDUS USING OTH DRUGS'
   LD94OTDR= 'LD94 PROP OF IDUS USING OTH DRUGS'
   LD96OTDR= 'LD96 PROP OF IDUS USING OTH DRUGS'
   LD88CON1= 'LD88 CONF IN SOURCE OF DRUG EST'
   LD90CON1= 'LD90 CONF IN SOURCE OF DRUG EST'
   LD92CON1= 'LD92 CONF IN SOURCE OF DRUG EST'
   LD94CON1= 'LD94 CONF IN SOURCE OF DRUG EST'
   LD96CON1= 'LD96 CONF IN SOURCE OF DRUG EST'
   LD88HERA= 'LD88 CHANGE IN EXTENT HEROIN AVAIL'
   LD90HERA= 'LD90 CHANGE IN EXTENT HEROIN AVAIL'
   LD92HERA= 'LD92 CHANGE IN EXTENT HEROIN AVAIL'
   LD94HERA= 'LD94 CHANGE IN EXTENT HEROIN AVAIL'
   LD96HERA= 'LD96 CHANGE IN EXTENT HEROIN AVAIL'
   LD88COCA= 'LD88 CHANGE IN EXTENT COCAINE AVAIL'
   LD90COCA= 'LD90 CHANGE IN EXTENT COCAINE AVAIL'
   LD92COCA= 'LD92 CHANGE IN EXTENT COCAINE AVAIL'
   LD94COCA= 'LD94 CHANGE IN EXTENT COCAINE AVAIL'
   LD96COCA= 'LD96 CHANGE IN EXTENT COCAINE AVAIL'
   LD88SPDA= 'LD88 CHANGE IN EXTENT SPEED AVAIL'
   LD90SPDA= 'LD90 CHANGE IN EXTENT SPEED AVAIL'
   LD92SPDA= 'LD92 CHANGE IN EXTENT SPEED AVAIL'
   LD94SPDA= 'LD94 CHANGE IN EXTENT SPEED AVAIL'
   LD96SPDA= 'LD96 CHANGE IN EXTENT SPEED AVAIL'
   LD88META= 'LD88 CHANGE IN EXTENT METH AVAIL'
   LD90META= 'LD90 CHANGE IN EXTENT METH AVAIL'
   LD92META= 'LD92 CHANGE IN EXTENT METH AVAIL'
   LD94META= 'LD94 CHANGE IN EXTENT METH AVAIL'
   LD96META= 'LD96 CHANGE IN EXTENT METH AVAIL'
   LD88OTHA= 'LD88 CHANGE IN EXTENT OTH DRUGS AVAIL'
   LD90OTHA= 'LD90 CHANGE IN EXTENT OTH DRUGS AVAIL'
   LD92OTHA= 'LD92 CHANGE IN EXTENT OTH DRUGS AVAIL'
   LD94OTHA= 'LD94 CHANGE IN EXTENT OTH DRUGS AVAIL'
   LD96OTHA= 'LD96 CHANGE IN EXTENT OTH DRUGS AVAIL'
   LD88HERP= 'LD88 CHANGE IN HEROIN PRICE'
   LD90HERP= 'LD90 CHANGE IN HEROIN PRICE'
   LD92HERP= 'LD92 CHANGE IN HEROIN PRICE'
   LD94HERP= 'LD94 CHANGE IN HEROIN PRICE'
   LD96HERP= 'LD96 CHANGE IN HEROIN PRICE'
   LD88COCP= 'LD88 CHANGE IN COCAINE PRICE'
   LD90COCP= 'LD90 CHANGE IN COCAINE PRICE'
   LD92COCP= 'LD92 CHANGE IN COCAINE PRICE'
   LD94COCP= 'LD94 CHANGE IN COCAINE PRICE'
   LD96COCP= 'LD96 CHANGE IN COCAINE PRICE'
   LD88SPDP= 'LD88 CHAN IN SPEEDBALL PRICE'
   LD90SPDP= 'LD90 CHAN IN SPEEDBALL PRICE'
   LD92SPDP= 'LD92 CHAN IN SPEEDBALL PRICE'
   LD94SPDP= 'LD94 CHAN IN SPEEDBALL PRICE'
   LD96SPDP= 'LD96 CHAN IN SPEEDBALL PRICE'
   LD88METP= 'LD88 CHAN IN METH/AMPH PRICE'
   LD90METP= 'LD90 CHAN IN METH/AMPH PRICE'
   LD92METP= 'LD92 CHAN IN METH/AMPH PRICE'
   LD94METP= 'LD94 CHAN IN METH/AMPH PRICE'
   LD96METP= 'LD96 CHAN IN METH/AMPH PRICE'
   LD88OTHP= 'LD88 CHAN IN OTHER DRUGS PRICE'
   LD90OTHP= 'LD90 CHAN IN OTHER DRUGS PRICE'
   LD92OTHP= 'LD92 CHAN IN OTHER DRUGS PRICE'
   LD94OTHP= 'LD94 CHAN IN OTHER DRUGS PRICE'
   LD96OTHP= 'LD96 CHAN IN OTHER DRUGS PRICE'
   LD88POP = 'LD88 PROP IDUS WHO SHARE NEEDLES'
   LD90POP = 'LD90 PROP IDUS WHO SHARE NEEDLES'
   LD92POP = 'LD92 PROP IDUS WHO SHARE NEEDLES'
   LD94POP = 'LD94 PROP IDUS WHO SHARE NEEDLES'
   LD96POP = 'LD96 PROP IDUS WHO SHARE NEEDLES'
   LD88CON2= 'LD88 CONF IN SOURCE FOR IDU NDL SHAR'
   LD90CON2= 'LD90 CONF IN SOURCE FOR IDU NDL SHAR'
   LD92CON2= 'LD92 CONF IN SOURCE FOR IDU NDL SHAR'
   LD94CON2= 'LD94 CONF IN SOURCE FOR IDU NDL SHAR'
   LD96CON2= 'LD96 CONF IN SOURCE FOR IDU NDL SHAR'
   LD88GAL = 'LD88 EXTENT CHANG IN # SHOOT GAL'
   LD90GAL = 'LD90 EXTENT CHANG IN # SHOOT GAL'
   LD92GAL = 'LD92 EXTENT CHANG IN # SHOOT GAL'
   LD94GAL = 'LD94 EXTENT CHANG IN # SHOOT GAL'
   LD96GAL = 'LD96 EXTENT CHANG IN # SHOOT GAL'
   LD88NGAL= 'LD88 INC OR DEC IN #SHOOT GAL'
   LD90NGAL= 'LD90 INC OR DEC IN #SHOOT GAL'
   LD92NGAL= 'LD92 INC OR DEC IN #SHOOT GAL'
   LD94NGAL= 'LD94 INC OR DEC IN #SHOOT GAL'
   LD96NGAL= 'LD96 INC OR DEC IN #SHOOT GAL'
   LD88DISP= 'LD88 SAFE DISP OF USED NEEDLES'
   LD90DISP= 'LD90 SAFE DISP OF USED NEEDLES'
   LD92DISP= 'LD92 SAFE DISP OF USED NEEDLES'
   LD94DISP= 'LD94 SAFE DISP OF USED NEEDLES'
   LD96DISP= 'LD96 SAFE DISP OF USED NEEDLES'
   LD88HAR = 'LD88 EXT LAW ENF HARASSED IDUS'
   LD90HAR = 'LD90 EXT LAW ENF HARASSED IDUS'
   LD92HAR = 'LD92 EXT LAW ENF HARASSED IDUS'
   LD94HAR = 'LD94 EXT LAW ENF HARASSED IDUS'
   LD96HAR = 'LD96 EXT LAW ENF HARASSED IDUS'
   LD88INIT= 'LD88 EXT CHG IN NUM OFNEW IDUS'
   LD90INIT= 'LD90 EXT CHG IN NUM OFNEW IDUS'
   LD92INIT= 'LD92 EXT CHG IN NUM OFNEW IDUS'
   LD94INIT= 'LD94 EXT CHG IN NUM OFNEW IDUS'
   LD96INIT= 'LD96 EXT CHG IN NUM OFNEW IDUS'
   LD88NINI= 'LD88 CHANGE IN NUM OF NEW IDUS'
   LD90NINI= 'LD90 CHANGE IN NUM OF NEW IDUS'
   LD92NINI= 'LD92 CHANGE IN NUM OF NEW IDUS'
   LD94NINI= 'LD94 CHANGE IN NUM OF NEW IDUS'
   LD96NINI= 'LD96 CHANGE IN NUM OF NEW IDUS'
   LD88CON3= 'LD88 CHANGE IN HEROIN PRICE'
   LD90CON3= 'LD90 CHANGE IN HEROIN PRICE'
   LD92CON3= 'LD92 CHANGE IN HEROIN PRICE'
   LD94CON3= 'LD94 CHANGE IN HEROIN PRICE'
   LD96CON3= 'LD96 CHANGE IN HEROIN PRICE'
   LD88AVAI= 'LD88 EXT NEEDLES AVAIL TO IDUS'
   LD90AVAI= 'LD90 EXT NEEDLES AVAIL TO IDUS'
   LD92AVAI= 'LD92 EXT NEEDLES AVAIL TO IDUS'
   LD94AVAI= 'LD94 EXT NEEDLES AVAIL TO IDUS'
   LD96AVAI= 'LD96 EXT NEEDLES AVAIL TO IDUS'
   LD88BLCH= 'LD88 EXT IDUS USED SOURCES OF BLEACH'
   LD90BLCH= 'LD90 EXT IDUS USED SOURCES OF BLEACH'
   LD92BLCH= 'LD92 EXT IDUS USED SOURCES OF BLEACH'
   LD94BLCH= 'LD94 EXT IDUS USED SOURCES OF BLEACH'
   LD96BLCH= 'LD96 EXT IDUS USED SOURCES OF BLEACH'
   LDINTYR = 'LD YR HIV PREV PROGS IDUS INTROD'
   LDINTSVC= 'LD HIV PREV SVCS ACCESSED BY IDUS'
   LDINTNED= 'LD PREV SVCS ACCESS TO NDLS AVAIL'
   LDINTSRC= 'LD PREV SVCS ACCESS TO NDLS USED'
   LDINTTRT= 'LD PREV SVCS ACCESS TOTX DRUG AVAIL'
   LDINTACC= 'LD PREV SVCS PRNG TX USED'
   PHARMAVA= 'LD AVAIL OF NEEDLES IN PHARMACIES'
   NEEDLEAV= 'LD AVAIL OF NDLES AT NDLE EXCHANGES'
   DIABAVA = 'LD AVAIL OF NEEDLES AT DIABETICS'
   DEALERAV= 'LD AVAIL OF NEEDLES AT STREET DLRS'
   GALLERAV= 'LD AVAIL OF NEEDLES AT SHOOT GAL'
   AVAIL   = 'LD TOTAL AVAIL 88 TO 96 FROM ALL SRCS'
   AVAIL88 = 'LD AVAIL OF NEEDLES IN 88 ALL SRCS'
   AVAIL90 = 'LD AVAIL OF NEEDLES IN 90 ALL SRCS'
   AVAIL92 = 'LD AVAIL OF NEEDLES IN 92 ALL SRCS'
   AVAIL94 = 'LD AVAIL OF NEEDLES IN 94 ALL SRCS'
   AVAIL96 = 'LD AVAIL OF NEEDLES IN 96 ALL SRCS'
   PHARMUSE= 'LD USED NEEDLES IN PHARMACIES'
   NEEDLUSE= 'LD USED NEEDLES AT NEEDLE EXCHANGES'
   DIABUSE = 'LD USED NEEDLES AT DIABETICS'
   DLRUSE  = 'LD USED NEEDLES AT STREET DLRS'
   GALLERUS= 'LD USED NEEDLES AT SHOOT GAL'
   USED    = 'LD TOTAL USED 88 TO 96 FROM ALL SRCS'
   USED88  = 'LD USED NEEDLES IN 88 ALL SRCS'
   USED90  = 'LD USED NEEDLES IN 90 ALL SRCS'
   USED92  = 'LD USED NEEDLES IN 92 ALL SRCS'
   USED94  = 'LD USED NEEDLES IN 94 ALL SRCS'
   USED96  = 'LD USED NEEDLES IN 96 ALL SRCS'
   NEP     = 'LD TOTAL NEEDLES EXCHANGE PROGS'
   NEP88   = 'LD NEEDLE EXCHANGE PROG 88'
   NEP90   = 'LD NEEDLE EXCHANGE PROG 90'
   NEP92   = 'LD NEEDLE EXCHANGE PROG 92'
   NEP94   = 'LD NEEDLE EXCHANGE PROG 94'
   NEP96   = 'LD NEEDLE EXCHANGE PROG 96'
   INTPRO88= 'LD 88 INTERVENTION PROGRAM PRESENT'
   INTPRO90= 'LD 90 INTERVENTION PROGRAM PRESENT'
   INTPRO92= 'LD 92 INTERVENTION PROGRAM PRESENT'
   INTPRO94= 'LD 94 INTERVENTION PROGRAM PRESENT'
   INTPRO96= 'LD 96 INTERVENTION PROGRAM PRESENT'
   RCHD88  = 'LD 88 EXTENT RCHD NADR/CA PART'
   RCHD90  = 'LD 90 EXTENT RCHD NADR/CA PART'
   RCHD92  = 'LD 92 EXTENT RCHD NADR/CA PART'
   RCHD94  = 'LD 94 EXTENT RCHD NADR/CA PART'
   RCHD96  = 'LD 96 EXTENT RCHD NADR/CA PART'
   PROGTOT = 'LD 88-96 INTERVENTION PROG PRESENT'
   RCHDTOT = 'LD 88-96 EXTENT RCHD NADR/CA PART'
   NORX    = 'LD 88-96 PHARMACY SALES WITHOUT RX'
   DRUGTRTP= 'LD 88-96 DRUG TREATMENT PROG PRES'
   HIVTESTP= 'LD 88-96 HIV TEST AND COUNSEL PRES'
   STDPROG = 'LD 88-96 STD CLINICS PRESENT'
   HIVORPRG= 'LD 88-96 HIV OUTREACH PROG PRESENT'
   OTHORPRG= 'LD 88-96 OTHER OUTREACH PROG PRESENT'
   HIVCMPRG= 'LD 88-96 HIV CASE MANAGEMENT PRESENT'
   OTHCMPRG= 'LD 88-96 OTHER CASE MANAGEMENT PRESENT'
   MEDSVPRG= 'LD 88-96 MED SVCS FOR HIV POS IND PRES'
   HLPROG  = 'LD 88-96 HOMELESS PROGRAMS PRESENT'
   OTHINTPR= 'LD 88-96 OTHER INTERVENTION PROG PRES'
   DRUGTRTR= 'LD 88-96 EXTENT RCHD DRUG TREATMENT PROG'
   HIVTESTR= 'LD 88-96 EXT RCHD HIV TEST AND COUNSEL'
   STDRCHD = 'LD 88-96 EXTENT RCHD STD CLINICS'
   HIVORRCH= 'LD 88-96 EXTENT RCHD HIV OUTREACH PROG'
   OTHORRCH= 'LD 88-96 EXTENT RCHD OTHER OUTREACH PROG'
   HIVCMRCH= 'LD 88-96 EXTENT RCHD HIV CASE MANAGEMENT'
   OTHCMRCH= 'LD 88-96 EXTENT RCHD OTH CASE MANAGEMENT'
   MEDSVRCH= 'LD 88-96 EXT RCHD MED SVCS HIV POS IND'
   HLRCHD  = 'LD 88-96 EXTENT RCHD HOMELESS PROGRAMS'
   OTHINTR = 'LD 88-96 EXTENT RCHD OTHER INTERVEN PROG'
   EARLY   = 'LD EARLY HIV INTERVENTIONS'
   DESIGN  = 'ASSIGNMENT TO MONITORING GROUP'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -4) THEN CASEID = .;
   IF (SITECODE <= -4) THEN SITECODE = .;
   IF (SI1 <= -4) THEN SI1 = .;
   IF (SI2 <= -4) THEN SI2 = .;
   IF (SI3 <= -4) THEN SI3 = .;
   IF (SI4 <= -4) THEN SI4 = .;
   IF (SI5 <= -4) THEN SI5 = .;
   IF (SI6_1 <= -4) THEN SI6_1 = .;
   IF (SI6_2 <= -4) THEN SI6_2 = .;
   IF (SI7_1 <= -4) THEN SI7_1 = .;
   IF (SI7_2 <= -4) THEN SI7_2 = .;
   IF (SI7_3 <= -4) THEN SI7_3 = .;
   IF (SI7_4 <= -4) THEN SI7_4 = .;
   IF (SI7_5 <= -4) THEN SI7_5 = .;
   IF (SI8 <= -4) THEN SI8 = .;
   IF (SI9 <= -4.0) THEN SI9 = .;
   IF (SI10_1 <= -4) THEN SI10_1 = .;
   IF (SI10B_2 <= -4) THEN SI10B_2 = .;
   IF (SI11 <= -4) THEN SI11 = .;
   IF (SI12_1 <= -4) THEN SI12_1 = .;
   IF (SI12_2 <= -4) THEN SI12_2 = .;
   IF (SI13 <= -4) THEN SI13 = .;
   IF (SI14 <= -4) THEN SI14 = .;
   IF (SI15 <= -4) THEN SI15 = .;
   IF (SI16 <= -4) THEN SI16 = .;
   IF (SI17 <= -4) THEN SI17 = .;
   IF (SI18 <= -4) THEN SI18 = .;
   IF (SI19 <= -4) THEN SI19 = .;
   IF (SI20 <= -4) THEN SI20 = .;
   IF (SI21 <= -4) THEN SI21 = .;
   IF (SI22_1 <= -4) THEN SI22_1 = .;
   IF (SI22_2 <= -4) THEN SI22_2 = .;
   IF (SI23 <= -4) THEN SI23 = .;
   IF (SI24 <= -4) THEN SI24 = .;
   IF (SI25 <= -4) THEN SI25 = .;
   IF (SI26 <= -4) THEN SI26 = .;
   IF (SI27 <= -4) THEN SI27 = .;
   IF (SI28 <= -4) THEN SI28 = .;
   IF (SI29 <= -4) THEN SI29 = .;
   IF (SI30 <= -4) THEN SI30 = .;
   IF (SI31 <= -4) THEN SI31 = .;
   IF (SI32 <= -4) THEN SI32 = .;
   IF (SI32A <= -4) THEN SI32A = .;
   IF (SI33 <= -4) THEN SI33 = .;
   IF (SI34 <= -4) THEN SI34 = .;
   IF (SI35 <= -4) THEN SI35 = .;
   IF (SI36 <= -4) THEN SI36 = .;
   IF (SI37 <= -4) THEN SI37 = .;
   IF (SI38 <= -4) THEN SI38 = .;
   IF (SI39 <= -4) THEN SI39 = .;
   IF (SI40 <= -4) THEN SI40 = .;
   IF (SI40A <= -4) THEN SI40A = .;
   IF (SI40B <= -4) THEN SI40B = .;
   IF (SI40C <= -4) THEN SI40C = .;
   IF (SI40D <= -4) THEN SI40D = .;
   IF (SI41 <= -4) THEN SI41 = .;
   IF (SI42 <= -4) THEN SI42 = .;
   IF (SI43 <= -4) THEN SI43 = .;
   IF (SI43A <= -4) THEN SI43A = .;
   IF (SI43B <= -4) THEN SI43B = .;
   IF (SI43C <= -4) THEN SI43C = .;
   IF (SI43D <= -4) THEN SI43D = .;
   IF (SI43E <= -4) THEN SI43E = .;
   IF (SI43F <= -4) THEN SI43F = .;
   IF (SI44 <= -4) THEN SI44 = .;
   IF (SI45 <= -4) THEN SI45 = .;
   IF (SI46 <= -4) THEN SI46 = .;
   IF (SI47 <= -4) THEN SI47 = .;
   IF (SI48 <= -4) THEN SI48 = .;
   IF (SI48_1 <= -4) THEN SI48_1 = .;
   IF (SI48_2 <= -4) THEN SI48_2 = .;
   IF (SI49 <= -4) THEN SI49 = .;
   IF (SI49A <= -4) THEN SI49A = .;
   IF (SI49_1 <= -4) THEN SI49_1 = .;
   IF (SI49_2 <= -4) THEN SI49_2 = .;
   IF (SI50 <= -4) THEN SI50 = .;
   IF (SI50A <= -4) THEN SI50A = .;
   IF (SI50A_1 <= -4) THEN SI50A_1 = .;
   IF (SI50A_2 <= -4) THEN SI50A_2 = .;
   IF (SI51_1 <= -4) THEN SI51_1 = .;
   IF (SI51_2 <= -4) THEN SI51_2 = .;
   IF (SI52_1 <= -4) THEN SI52_1 = .;
   IF (SI52_2 <= -4) THEN SI52_2 = .;
   IF (SI54 <= -4) THEN SI54 = .;
   IF (SI55 <= -4) THEN SI55 = .;
   IF (SI55A <= -4) THEN SI55A = .;
   IF (SI55B <= -4) THEN SI55B = .;
   IF (SI55C <= -4) THEN SI55C = .;
   IF (SI55D <= -4) THEN SI55D = .;
   IF (SI56 <= -4) THEN SI56 = .;
   IF (SI57 <= -4) THEN SI57 = .;
   IF (SI58 <= -4) THEN SI58 = .;
   IF (SI59 <= -4) THEN SI59 = .;
   IF (SI60 <= -4) THEN SI60 = .;
   IF (SI61 <= -4) THEN SI61 = .;
   IF (SI62 <= -4) THEN SI62 = .;
   IF (SI62A <= -4) THEN SI62A = .;
   IF (SI62B <= -4) THEN SI62B = .;
   IF (SI62C <= -4) THEN SI62C = .;
   IF (SI62D <= -4) THEN SI62D = .;
   IF (SI63 <= -4) THEN SI63 = .;
   IF (SI64 <= -4) THEN SI64 = .;
   IF (SI65 <= -4) THEN SI65 = .;
   IF (SI65A <= -4) THEN SI65A = .;
   IF (SI66 <= -4) THEN SI66 = .;
   IF (SI67 <= -4) THEN SI67 = .;
   IF (SI68 <= -4) THEN SI68 = .;
   IF (SI68_1 <= -4) THEN SI68_1 = .;
   IF (SI68_2 <= -4) THEN SI68_2 = .;
   IF (SI69 <= -4) THEN SI69 = .;
   IF (SI69A <= -4) THEN SI69A = .;
   IF (SI70 <= -4) THEN SI70 = .;
   IF (SI71 <= -4) THEN SI71 = .;
   IF (SI72_1 <= -4) THEN SI72_1 = .;
   IF (SI72_2 <= -4) THEN SI72_2 = .;
   IF (SI73 <= -4) THEN SI73 = .;
   IF (SI74 <= -4) THEN SI74 = .;
   IF (SI75 <= -4) THEN SI75 = .;
   IF (SI76_1 <= -4) THEN SI76_1 = .;
   IF (SI76_2 <= -4) THEN SI76_2 = .;
   IF (SI77 <= -4) THEN SI77 = .;
   IF (SI78A <= -4) THEN SI78A = .;
   IF (SI78B <= -4) THEN SI78B = .;
   IF (SI78C <= -4) THEN SI78C = .;
   IF (SI78A_1 <= -4) THEN SI78A_1 = .;
   IF (SI78A_2 <= -4) THEN SI78A_2 = .;
   IF (SI78A_3 <= -4) THEN SI78A_3 = .;
   IF (SI79 <= -4) THEN SI79 = .;
   IF (SI80 <= -4) THEN SI80 = .;
   IF (SI81 <= -4) THEN SI81 = .;
   IF (SI82 <= -4) THEN SI82 = .;
   IF (SI83 <= -4) THEN SI83 = .;
   IF (SI84 <= -4) THEN SI84 = .;
   IF (SI85_1 <= -4) THEN SI85_1 = .;
   IF (SI85_2 <= -4) THEN SI85_2 = .;
   IF (SI87 <= -4) THEN SI87 = .;
   IF (SI88 <= -4) THEN SI88 = .;
   IF (SI89 <= -4) THEN SI89 = .;
   IF (SI90 <= -4) THEN SI90 = .;
   IF (SI91 <= -4) THEN SI91 = .;
   IF (SI92 <= -4) THEN SI92 = .;
   IF (SI93 <= -4) THEN SI93 = .;
   IF (SI94 <= -4) THEN SI94 = .;
   IF (SI94A <= -4) THEN SI94A = .;
   IF (SI94B <= -4) THEN SI94B = .;
   IF (SI94C <= -4) THEN SI94C = .;
   IF (SI94D <= -4) THEN SI94D = .;
   IF (SI95 <= -4) THEN SI95 = .;
   IF (SI96 <= -4) THEN SI96 = .;
   IF (SI97 <= -4) THEN SI97 = .;
   IF (SI98 <= -4) THEN SI98 = .;
   IF (SI100 <= -4) THEN SI100 = .;
   IF (SI100A <= -4) THEN SI100A = .;
   IF (SI100B <= -4) THEN SI100B = .;
   IF (SI101 <= -4) THEN SI101 = .;
   IF (SI102 <= -4) THEN SI102 = .;
   IF (SI102B <= -4) THEN SI102B = .;
   IF (SI102C <= -4) THEN SI102C = .;
   IF (SI103 <= -4) THEN SI103 = .;
   IF (SI104 <= -4) THEN SI104 = .;
   IF (SI105 <= -4) THEN SI105 = .;
   IF (SI105A <= -4) THEN SI105A = .;
   IF (SI105B <= -4) THEN SI105B = .;
   IF (SI105C <= -4) THEN SI105C = .;
   IF (SI106 <= -4) THEN SI106 = .;
   IF (SI107 <= -4) THEN SI107 = .;
   IF (SI108 <= -4) THEN SI108 = .;
   IF (SI109 <= -4) THEN SI109 = .;
   IF (SI109A <= -4) THEN SI109A = .;
   IF (SI110 <= -4) THEN SI110 = .;
   IF (SI111 <= -4) THEN SI111 = .;
   IF (SI111A <= -4) THEN SI111A = .;
   IF (SI112 <= -4) THEN SI112 = .;
   IF (SI113_1 <= -4) THEN SI113_1 = .;
   IF (SI113_2 <= -4) THEN SI113_2 = .;
   IF (SI114_1 <= -4) THEN SI114_1 = .;
   IF (SI114_2 <= -4) THEN SI114_2 = .;
   IF (SI115_1 <= -4) THEN SI115_1 = .;
   IF (SI115_2 <= -4) THEN SI115_2 = .;
   IF (SI116 <= -4) THEN SI116 = .;
   IF (SI117 <= -4) THEN SI117 = .;
   IF (SI118 <= -4) THEN SI118 = .;
   IF (SI119 <= -4) THEN SI119 = .;
   IF (SI120 <= -4) THEN SI120 = .;
   IF (SI120A <= -4) THEN SI120A = .;
   IF (SI120B <= -4) THEN SI120B = .;
   IF (SI120C <= -4) THEN SI120C = .;
   IF (SI120D <= -4) THEN SI120D = .;
   IF (SI121 <= -4) THEN SI121 = .;
   IF (SI122 <= -4) THEN SI122 = .;
   IF (SI123 <= -4) THEN SI123 = .;
   IF (SI124 <= -4) THEN SI124 = .;
   IF (SI125 <= -4) THEN SI125 = .;
   IF (SI126 <= -4) THEN SI126 = .;
   IF (SI127 <= -4) THEN SI127 = .;
   IF (SI128 <= -4) THEN SI128 = .;
   IF (SI129_1 <= -4) THEN SI129_1 = .;
   IF (SI129_2 <= -4) THEN SI129_2 = .;
   IF (SI129_3 <= -4) THEN SI129_3 = .;
   IF (SI130 <= -4) THEN SI130 = .;
   IF (SI131 <= -4) THEN SI131 = .;
   IF (SI132 <= -4) THEN SI132 = .;
   IF (SI133 <= -4) THEN SI133 = .;
   IF (SI134_1 <= -4) THEN SI134_1 = .;
   IF (SI134_2 <= -4) THEN SI134_2 = .;
   IF (SI134_3 <= -4) THEN SI134_3 = .;
   IF (SI135 <= -4) THEN SI135 = .;
   IF (SI136 <= -4) THEN SI136 = .;
   IF (SI137 <= -4) THEN SI137 = .;
   IF (SI137A <= -4) THEN SI137A = .;
   IF (SI138 <= -4) THEN SI138 = .;
   IF (SI138A <= -4) THEN SI138A = .;
   IF (SI139 <= -4) THEN SI139 = .;
   IF (SI139A <= -4) THEN SI139A = .;
   IF (SI140 <= -4) THEN SI140 = .;
   IF (SI141 <= -4) THEN SI141 = .;
   IF (SI141A <= -4) THEN SI141A = .;
   IF (SI142 <= -4) THEN SI142 = .;
   IF (SI143 <= -4) THEN SI143 = .;
   IF (SI144 <= -4) THEN SI144 = .;
   IF (SI145 <= -4) THEN SI145 = .;
   IF (SI145A <= -4) THEN SI145A = .;
   IF (SI146 <= -4) THEN SI146 = .;
   IF (SI147A <= -4) THEN SI147A = .;
   IF (SI147B <= -4) THEN SI147B = .;
   IF (SI147C <= -4) THEN SI147C = .;
   IF (SI147A_1 <= -4) THEN SI147A_1 = .;
   IF (SI147A_2 <= -4) THEN SI147A_2 = .;
   IF (SI147A_3 <= -4) THEN SI147A_3 = .;
   IF (SI148 <= -4) THEN SI148 = .;
   IF (SI149 <= -4) THEN SI149 = .;
   IF (SI150 <= -4) THEN SI150 = .;
   IF (SI151_1 <= -4) THEN SI151_1 = .;
   IF (SI151_2 <= -4) THEN SI151_2 = .;
   IF (SI153 <= -4) THEN SI153 = .;
   IF (SI154 <= -4) THEN SI154 = .;
   IF (SI155 <= -4) THEN SI155 = .;
   IF (SI156_1 <= -4) THEN SI156_1 = .;
   IF (SI156_2 <= -4) THEN SI156_2 = .;
   IF (SI156_3 <= -4) THEN SI156_3 = .;
   IF (SI157 <= -4) THEN SI157 = .;
   IF (SI158 <= -4) THEN SI158 = .;
   IF (SI159 <= -4) THEN SI159 = .;
   IF (SI160 <= -4) THEN SI160 = .;
   IF (SI160A <= -4) THEN SI160A = .;
   IF (SI161 <= -4) THEN SI161 = .;
   IF (SI161A <= -4) THEN SI161A = .;
   IF (SI162 <= -4) THEN SI162 = .;
   IF (SI162A <= -4) THEN SI162A = .;
   IF (SI163 <= -4) THEN SI163 = .;
   IF (SI164 <= -4) THEN SI164 = .;
   IF (SI164A <= -4) THEN SI164A = .;
   IF (SI165 <= -4) THEN SI165 = .;
   IF (SI166 <= -4) THEN SI166 = .;
   IF (SI167 <= -4) THEN SI167 = .;
   IF (SI168 <= -4) THEN SI168 = .;
   IF (SI168A <= -4) THEN SI168A = .;
   IF (SI169 <= -4) THEN SI169 = .;
   IF (SI170A <= -4) THEN SI170A = .;
   IF (SI170B <= -4) THEN SI170B = .;
   IF (SI170C <= -4) THEN SI170C = .;
   IF (SI170A_1 <= -4) THEN SI170A_1 = .;
   IF (SI170A_2 <= -4) THEN SI170A_2 = .;
   IF (SI170A_3 <= -4) THEN SI170A_3 = .;
   IF (SI171 <= -4) THEN SI171 = .;
   IF (SI172 <= -4) THEN SI172 = .;
   IF (SI173 <= -4) THEN SI173 = .;
   IF (SI174_1 <= -4) THEN SI174_1 = .;
   IF (SI174_2 <= -4) THEN SI174_2 = .;
   IF (SI176 <= -4) THEN SI176 = .;
   IF (SI177 <= -4) THEN SI177 = .;
   IF (SI177A <= -4) THEN SI177A = .;
   IF (SI178 <= -4) THEN SI178 = .;
   IF (SI178A <= -4) THEN SI178A = .;
   IF (SI179 <= -4) THEN SI179 = .;
   IF (SI180 <= -4) THEN SI180 = .;
   IF (SI180A <= -4) THEN SI180A = .;
   IF (SI181 <= -4) THEN SI181 = .;
   IF (SI182 <= -4) THEN SI182 = .;
   IF (SI182A <= -4.0) THEN SI182A = .;
   IF (SI183 <= -4) THEN SI183 = .;
   IF (SI184 <= -4) THEN SI184 = .;
   IF (SI185 <= -4) THEN SI185 = .;
   IF (SI186 <= -4) THEN SI186 = .;
   IF (SI187 <= -4) THEN SI187 = .;
   IF (SI188 <= -4) THEN SI188 = .;
   IF (SI189 <= -4) THEN SI189 = .;
   IF (SI190 <= -4) THEN SI190 = .;
   IF (SI191 <= -4) THEN SI191 = .;
   IF (SI192_1 <= -4) THEN SI192_1 = .;
   IF (SI192_2 <= -4) THEN SI192_2 = .;
   IF (SI192_3 <= -4) THEN SI192_3 = .;
   IF (SI193 <= -4) THEN SI193 = .;
   IF (SI194 <= -4) THEN SI194 = .;
   IF (SI195 <= -4) THEN SI195 = .;
   IF (SI196 <= -4) THEN SI196 = .;
   IF (SI197 <= -4) THEN SI197 = .;
   IF (SI198 <= -4) THEN SI198 = .;
   IF (SI199 <= -4) THEN SI199 = .;
   IF (SI200_1 <= -4) THEN SI200_1 = .;
   IF (SI200A <= -4) THEN SI200A = .;
   IF (SI201_1 <= -4) THEN SI201_1 = .;
   IF (SI202_1 <= -4) THEN SI202_1 = .;
   IF (SI203_1 <= -4) THEN SI203_1 = .;
   IF (SI204_1 <= -4) THEN SI204_1 = .;
   IF (SI205_1 <= -4) THEN SI205_1 = .;
   IF (SI206_1 <= -4) THEN SI206_1 = .;
   IF (SI208 <= -4) THEN SI208 = .;
   IF (SI209 <= -4) THEN SI209 = .;
   IF (SI210 <= -4) THEN SI210 = .;
   IF (SI211 <= -4) THEN SI211 = .;
   IF (SI212 <= -4) THEN SI212 = .;
   IF (SI213 <= -4) THEN SI213 = .;
   IF (SI215 <= -4) THEN SI215 = .;
   IF (SI216 <= -4) THEN SI216 = .;
   IF (SI217 <= -4) THEN SI217 = .;
   IF (SI217A_1 <= -4) THEN SI217A_1 = .;
   IF (SI217A_2 <= -4) THEN SI217A_2 = .;
   IF (SI217A_3 <= -4) THEN SI217A_3 = .;
   IF (SI217B <= -4) THEN SI217B = .;
   IF (SI218 <= -4) THEN SI218 = .;
   IF (SI218A <= -4) THEN SI218A = .;
   IF (SI218B <= -4) THEN SI218B = .;
   IF (SI218C <= -4) THEN SI218C = .;
   IF (SI218D_1 <= -4) THEN SI218D_1 = .;
   IF (SI218D_2 <= -4) THEN SI218D_2 = .;
   IF (SI218D_3 <= -4) THEN SI218D_3 = .;
   IF (SESADUR <= -4) THEN SESADUR = .;
   IF (SESBDUR <= -4) THEN SESBDUR = .;
   IF (SESAODUR <= -4) THEN SESAODUR = .;
   IF (SESBODUR <= -4) THEN SESBODUR = .;
   IF (OUTDUR <= -4) THEN OUTDUR = .;
   IF (DISTRIB1 <= -4) THEN DISTRIB1 = .;
   IF (DISTINJ <= -4) THEN DISTINJ = .;
   IF (DISTSEX <= -4) THEN DISTSEX = .;
   IF (REHNDLA <= -4) THEN REHNDLA = .;
   IF (REHCNDMA <= -4) THEN REHCNDMA = .;
   IF (REHALLA <= -4) THEN REHALLA = .;
   IF (REHNDLB <= -4) THEN REHNDLB = .;
   IF (REHCNDMB <= -4) THEN REHCNDMB = .;
   IF (REHALLB <= -4) THEN REHALLB = .;
   IF (SIDEMOA <= -4) THEN SIDEMOA = .;
   IF (SIDEMOB <= -4) THEN SIDEMOB = .;
   IF (SIRHSLA <= -4) THEN SIRHSLA = .;
   IF (SIRHSLB <= -4) THEN SIRHSLB = .;
   IF (SIS1 <= -4) THEN SIS1 = .;
   IF (SIS2A <= -4) THEN SIS2A = .;
   IF (SIS2B <= -4) THEN SIS2B = .;
   IF (SIS2C <= -4) THEN SIS2C = .;
   IF (SIS2D <= -4) THEN SIS2D = .;
   IF (SIS3 <= -4) THEN SIS3 = .;
   IF (SIS4 <= -4) THEN SIS4 = .;
   IF (SIS5 <= -4) THEN SIS5 = .;
   IF (SIS6 <= -4) THEN SIS6 = .;
   IF (SIS7 <= -4) THEN SIS7 = .;
   IF (SIS8 <= -4) THEN SIS8 = .;
   IF (SIS9 <= -4) THEN SIS9 = .;
   IF (SIS9A <= -4) THEN SIS9A = .;
   IF (SIS10 <= -4) THEN SIS10 = .;
   IF (SIS11 <= -4) THEN SIS11 = .;
   IF (SIS12 <= -4) THEN SIS12 = .;
   IF (SIS12A <= -4) THEN SIS12A = .;
   IF (SIS13 <= -4) THEN SIS13 = .;
   IF (SIS14 <= -4) THEN SIS14 = .;
   IF (SIS15 <= -4) THEN SIS15 = .;
   IF (SIS16 <= -4) THEN SIS16 = .;
   IF (SIS17 <= -4) THEN SIS17 = .;
   IF (SIS17A <= -4) THEN SIS17A = .;
   IF (SIS18 <= -4) THEN SIS18 = .;
   IF (SIS19 <= -4) THEN SIS19 = .;
   IF (SIS20 <= -4) THEN SIS20 = .;
   IF (SIS21 <= -4) THEN SIS21 = .;
   IF (SIS22 <= -4) THEN SIS22 = .;
   IF (SIS23 <= -4) THEN SIS23 = .;
   IF (SIS24 <= -4) THEN SIS24 = .;
   IF (SIS25 <= -4) THEN SIS25 = .;
   IF (SIS26 <= -4) THEN SIS26 = .;
   IF (SIS27 <= -4) THEN SIS27 = .;
   IF (SIS28 <= -4) THEN SIS28 = .;
   IF (SIS29 <= -4) THEN SIS29 = .;
   IF (SIS30 <= -4) THEN SIS30 = .;
   IF (SIS31 <= -4) THEN SIS31 = .;
   IF (SIS32 <= -4) THEN SIS32 = .;
   IF (SIS33 <= -4) THEN SIS33 = .;
   IF (SIS34 <= -4) THEN SIS34 = .;
   IF (SIS35 <= -4) THEN SIS35 = .;
   IF (SIS36A <= -4) THEN SIS36A = .;
   IF (SIS36B <= -4) THEN SIS36B = .;
   IF (SIS36C <= -4) THEN SIS36C = .;
   IF (SIS37A <= -4) THEN SIS37A = .;
   IF (SIS37B <= -4) THEN SIS37B = .;
   IF (SIS37C <= -4) THEN SIS37C = .;
   IF (SIS38 <= -4) THEN SIS38 = .;
   IF (SIS39 <= -4) THEN SIS39 = .;
   IF (SIS40 <= -4) THEN SIS40 = .;
   IF (SIS41 <= -4) THEN SIS41 = .;
   IF (SIS42 <= -4) THEN SIS42 = .;
   IF (SIS43 <= -4) THEN SIS43 = .;
   IF (SIS43A <= -4) THEN SIS43A = .;
   IF (SIS44 <= -4) THEN SIS44 = .;
   IF (SIS45 <= -4) THEN SIS45 = .;
   IF (SIS46 <= -4) THEN SIS46 = .;
   IF (SIS47 <= -4) THEN SIS47 = .;
   IF (SIS48 <= -4) THEN SIS48 = .;
   IF (SIS49 <= -4) THEN SIS49 = .;
   IF (SIS50 <= -4) THEN SIS50 = .;
   IF (SIS51 <= -4) THEN SIS51 = .;
   IF (SIS52 <= -4) THEN SIS52 = .;
   IF (SIS53 <= -4) THEN SIS53 = .;
   IF (SIS54 <= -4) THEN SIS54 = .;
   IF (SIS55 <= -4) THEN SIS55 = .;
   IF (SIS56 <= -4) THEN SIS56 = .;
   IF (SIS57 <= -4) THEN SIS57 = .;
   IF (SIS58 <= -4) THEN SIS58 = .;
   IF (SIS59 <= -4) THEN SIS59 = .;
   IF (SIS60 <= -4) THEN SIS60 = .;
   IF (SIS61 <= -4) THEN SIS61 = .;
   IF (SIS62A <= -4) THEN SIS62A = .;
   IF (SIS62B <= -4) THEN SIS62B = .;
   IF (SIS62C <= -4) THEN SIS62C = .;
   IF (SIS63A <= -4) THEN SIS63A = .;
   IF (SIS63B <= -4) THEN SIS63B = .;
   IF (SIS63C <= -4) THEN SIS63C = .;
   IF (SIS64 <= -4) THEN SIS64 = .;
   IF (SIS65 <= -4) THEN SIS65 = .;
   IF (SIS66 <= -4) THEN SIS66 = .;
   IF (SIS67 <= -4) THEN SIS67 = .;
   IF (SIS68 <= -4) THEN SIS68 = .;
   IF (SIS69 <= -4) THEN SIS69 = .;
   IF (SIS69A <= -4) THEN SIS69A = .;
   IF (SIS70 <= -4) THEN SIS70 = .;
   IF (SIS71 <= -4) THEN SIS71 = .;
   IF (SIS72 <= -4) THEN SIS72 = .;
   IF (SIS73 <= -4) THEN SIS73 = .;
   IF (SIS74 <= -4) THEN SIS74 = .;
   IF (SIS75 <= -4) THEN SIS75 = .;
   IF (SIS76 <= -4) THEN SIS76 = .;
   IF (SIS77 <= -4) THEN SIS77 = .;
   IF (SIS78 <= -4) THEN SIS78 = .;
   IF (SIS79 <= -4) THEN SIS79 = .;
   IF (SIS80 <= -4) THEN SIS80 = .;
   IF (SIS81 <= -4) THEN SIS81 = .;
   IF (SIS82 <= -4) THEN SIS82 = .;
   IF (SIS83 <= -4) THEN SIS83 = .;
   IF (SIS84 <= -4) THEN SIS84 = .;
   IF (SIS85 <= -4) THEN SIS85 = .;
   IF (SIS86 <= -4) THEN SIS86 = .;
   IF (SIS87 <= -4) THEN SIS87 = .;
   IF (SIS88A <= -4) THEN SIS88A = .;
   IF (SIS88B <= -4) THEN SIS88B = .;
   IF (SIS88C <= -4) THEN SIS88C = .;
   IF (SIS89A <= -4) THEN SIS89A = .;
   IF (SIS89B <= -4) THEN SIS89B = .;
   IF (SIS89C <= -4) THEN SIS89C = .;
   IF (SIS90 <= -4) THEN SIS90 = .;
   IF (SIS91 <= -4) THEN SIS91 = .;
   IF (SIS92 <= -4) THEN SIS92 = .;
   IF (SIS93 <= -4) THEN SIS93 = .;
   IF (SIS94 <= -4) THEN SIS94 = .;
   IF (SIS95 <= -4) THEN SIS95 = .;
   IF (SIS96 <= -4) THEN SIS96 = .;
   IF (SIS97 <= -4) THEN SIS97 = .;
   IF (SIS98 <= -4) THEN SIS98 = .;
   IF (SIS99 <= -4) THEN SIS99 = .;
   IF (SIS100 <= -4) THEN SIS100 = .;
   IF (SIS101 <= -4) THEN SIS101 = .;
   IF (SIS102 <= -4) THEN SIS102 = .;
   IF (SIS103A <= -4) THEN SIS103A = .;
   IF (SIS103B <= -4) THEN SIS103B = .;
   IF (SIS103C <= -4) THEN SIS103C = .;
   IF (SIS106 <= -4) THEN SIS106 = .;
   IF (SIS107 <= -4) THEN SIS107 = .;
   IF (SIS108 <= -4) THEN SIS108 = .;
   IF (SIS109 <= -4) THEN SIS109 = .;
   IF (SIS110 <= -4) THEN SIS110 = .;
   IF (SIS111 <= -4) THEN SIS111 = .;
   IF (SIS112 <= -4) THEN SIS112 = .;
   IF (SIS113 <= -4) THEN SIS113 = .;
   IF (SIS114 <= -4) THEN SIS114 = .;
   IF (SIS115 <= -4) THEN SIS115 = .;
   IF (SIS116 <= -4) THEN SIS116 = .;
   IF (SIS117A <= -4) THEN SIS117A = .;
   IF (SIS117B <= -4) THEN SIS117B = .;
   IF (SIS117C <= -4) THEN SIS117C = .;
   IF (SIS120 <= -4) THEN SIS120 = .;
   IF (SIS121 <= -4) THEN SIS121 = .;
   IF (SIS122 <= -4) THEN SIS122 = .;
   IF (SIS123 <= -4) THEN SIS123 = .;
   IF (SIS124 <= -4) THEN SIS124 = .;
   IF (SIS125 <= -4) THEN SIS125 = .;
   IF (SIS126 <= -4) THEN SIS126 = .;
   IF (SIS127 <= -4) THEN SIS127 = .;
   IF (SIS128 <= -4) THEN SIS128 = .;
   IF (SIS129 <= -4) THEN SIS129 = .;
   IF (SIS130 <= -4) THEN SIS130 = .;
   IF (SIS131A <= -4) THEN SIS131A = .;
   IF (SIS131B <= -4) THEN SIS131B = .;
   IF (SIS131C <= -4) THEN SIS131C = .;
   IF (SIS134 <= -4) THEN SIS134 = .;
   IF (SIS135 <= -4) THEN SIS135 = .;
   IF (SIS136 <= -4) THEN SIS136 = .;
   IF (SIS137 <= -4) THEN SIS137 = .;
   IF (SIS138 <= -4) THEN SIS138 = .;
   IF (SIS139 <= -4) THEN SIS139 = .;
   IF (SIS140 <= -4) THEN SIS140 = .;
   IF (SIS141 <= -4) THEN SIS141 = .;
   IF (SIS142 <= -4) THEN SIS142 = .;
   IF (EINUM <= -4) THEN EINUM = .;
   IF (EI1 <= -4) THEN EI1 = .;
   IF (EI2_1 <= -4.00) THEN EI2_1 = .;
   IF (EI2_2 <= -4.0) THEN EI2_2 = .;
   IF (EI2_3 <= -4.00) THEN EI2_3 = .;
   IF (EI2_4 <= -4.00) THEN EI2_4 = .;
   IF (EI2_5 <= -4.00) THEN EI2_5 = .;
   IF (EI2_6 <= -4.00) THEN EI2_6 = .;
   IF (EI3A_1 <= -4) THEN EI3A_1 = .;
   IF (EI3A_2 <= -4) THEN EI3A_2 = .;
   IF (EI3A_3 <= -4) THEN EI3A_3 = .;
   IF (EI3A_4 <= -4) THEN EI3A_4 = .;
   IF (EI3B <= -4) THEN EI3B = .;
   IF (EI4A_1 <= -4) THEN EI4A_1 = .;
   IF (EI4A_2 <= -4) THEN EI4A_2 = .;
   IF (EI4B_3 <= -4) THEN EI4B_3 = .;
   IF (EI4B_4 <= -4) THEN EI4B_4 = .;
   IF (EI4B_5 <= -4) THEN EI4B_5 = .;
   IF (EI4B_6 <= -4) THEN EI4B_6 = .;
   IF (EI5_1 <= -4) THEN EI5_1 = .;
   IF (EI5_2 <= -4) THEN EI5_2 = .;
   IF (EI6 <= -4) THEN EI6 = .;
   IF (EI7A_1 <= -4) THEN EI7A_1 = .;
   IF (EI7A_2 <= -4) THEN EI7A_2 = .;
   IF (EI7A_3 <= -4) THEN EI7A_3 = .;
   IF (EI7A_4 <= -4) THEN EI7A_4 = .;
   IF (EI7A_5 <= -4) THEN EI7A_5 = .;
   IF (EI7A_6 <= -4) THEN EI7A_6 = .;
   IF (EI7A_7 <= -4) THEN EI7A_7 = .;
   IF (EI7A_8 <= -4) THEN EI7A_8 = .;
   IF (EI7A_9 <= -4) THEN EI7A_9 = .;
   IF (EI7A_10 <= -4) THEN EI7A_10 = .;
   IF (EI7A_11 <= -4) THEN EI7A_11 = .;
   IF (EI7A_12 <= -4) THEN EI7A_12 = .;
   IF (EI7B_1 <= -4) THEN EI7B_1 = .;
   IF (EI7B_2 <= -4) THEN EI7B_2 = .;
   IF (EI7B_3 <= -4) THEN EI7B_3 = .;
   IF (EI7B_4 <= -4) THEN EI7B_4 = .;
   IF (EI7B_5 <= -4) THEN EI7B_5 = .;
   IF (EI7B_6 <= -4) THEN EI7B_6 = .;
   IF (EI7B_7 <= -4) THEN EI7B_7 = .;
   IF (EI7B_8 <= -4) THEN EI7B_8 = .;
   IF (EI7B_9 <= -4) THEN EI7B_9 = .;
   IF (EI7B_10 <= -4) THEN EI7B_10 = .;
   IF (EI8A_1 <= -4) THEN EI8A_1 = .;
   IF (EI8A_2 <= -4) THEN EI8A_2 = .;
   IF (EI8A_3 <= -4) THEN EI8A_3 = .;
   IF (EI8A_4 <= -4) THEN EI8A_4 = .;
   IF (EI8A_5 <= -4) THEN EI8A_5 = .;
   IF (EI8A_6 <= -4) THEN EI8A_6 = .;
   IF (EI8A_7 <= -4) THEN EI8A_7 = .;
   IF (EI8A_8 <= -4) THEN EI8A_8 = .;
   IF (EI8A_9 <= -4) THEN EI8A_9 = .;
   IF (EI8A_10 <= -4) THEN EI8A_10 = .;
   IF (EI8A_11 <= -4) THEN EI8A_11 = .;
   IF (EI8A_12 <= -4) THEN EI8A_12 = .;
   IF (EI8A_13 <= -4) THEN EI8A_13 = .;
   IF (EI8A_14 <= -4) THEN EI8A_14 = .;
   IF (EI8B_1 <= -4) THEN EI8B_1 = .;
   IF (EI8B_2 <= -4) THEN EI8B_2 = .;
   IF (EI8B_3 <= -4) THEN EI8B_3 = .;
   IF (EI8B_4 <= -4) THEN EI8B_4 = .;
   IF (EI9 <= -4) THEN EI9 = .;
   IF (EI10 <= -4) THEN EI10 = .;
   IF (EI11_1 <= -4) THEN EI11_1 = .;
   IF (EI11_2 <= -4) THEN EI11_2 = .;
   IF (EI11_3 <= -4) THEN EI11_3 = .;
   IF (EI11_4 <= -4) THEN EI11_4 = .;
   IF (EI11_5 <= -4) THEN EI11_5 = .;
   IF (EI11_6 <= -4) THEN EI11_6 = .;
   IF (EI11_7 <= -4) THEN EI11_7 = .;
   IF (EI11_8 <= -4) THEN EI11_8 = .;
   IF (EI11_9 <= -4) THEN EI11_9 = .;
   IF (EI11_10 <= -4) THEN EI11_10 = .;
   IF (EI11_11 <= -4) THEN EI11_11 = .;
   IF (EI11_12 <= -4) THEN EI11_12 = .;
   IF (EI11_13 <= -4) THEN EI11_13 = .;
   IF (EI11_14 <= -4) THEN EI11_14 = .;
   IF (EI11_15 <= -4) THEN EI11_15 = .;
   IF (EI12_2 <= -4) THEN EI12_2 = .;
   IF (EI14_1 <= -4) THEN EI14_1 = .;
   IF (EI14_2 <= -4) THEN EI14_2 = .;
   IF (EI14_3 <= -4) THEN EI14_3 = .;
   IF (EI14_4 <= -4) THEN EI14_4 = .;
   IF (EI14_5 <= -4) THEN EI14_5 = .;
   IF (EIDEMO <= -4) THEN EIDEMO = .;
   IF (EIRHSL <= -4) THEN EIRHSL = .;
   IF (EIACTA <= -4) THEN EIACTA = .;
   IF (EIACTB <= -4) THEN EIACTB = .;
   IF (EIDISTA <= -4) THEN EIDISTA = .;
   IF (EIDISTB <= -4) THEN EIDISTB = .;
   IF (EIDUR <= -4) THEN EIDUR = .;
   IF (EIADUR <= -4) THEN EIADUR = .;
   IF (EIBDUR <= -4) THEN EIBDUR = .;
   IF (EIAODUR <= -4) THEN EIAODUR = .;
   IF (EIBODUR <= -4) THEN EIBODUR = .;
   IF (EIIND <= -4) THEN EIIND = .;
   IF (EICOUPLE <= -4) THEN EICOUPLE = .;
   IF (EIGROUP <= -4) THEN EIGROUP = .;
   IF (XDAMC <= -4) THEN XDAMC = .;
   IF (AINTCOU <= -4) THEN AINTCOU = .;
   IF (AINTEDU <= -4) THEN AINTEDU = .;
   IF (AINTBOTH <= -4) THEN AINTBOTH = .;
   IF (AINTOTH <= -4) THEN AINTOTH = .;
   IF (AINTSP <= -4) THEN AINTSP = .;
   IF (AINTAV <= -4) THEN AINTAV = .;
   IF (AAVVIDEO <= -4) THEN AAVVIDEO = .;
   IF (AAVHAND <= -4) THEN AAVHAND = .;
   IF (AAVOTHER <= -4) THEN AAVOTHER = .;
   IF (AAVSP <= -4) THEN AAVSP = .;
   IF (AINTDRUG <= -4) THEN AINTDRUG = .;
   IF (AINTSEX <= -4) THEN AINTSEX = .;
   IF (ABARRIER <= -4) THEN ABARRIER = .;
   IF (ASUPPORT <= -4) THEN ASUPPORT = .;
   IF (ACUES <= -4) THEN ACUES = .;
   IF (ASETGOAL <= -4) THEN ASETGOAL = .;
   IF (AINTPER <= -4) THEN AINTPER = .;
   IF (ATB <= -4) THEN ATB = .;
   IF (AANATOMY <= -4) THEN AANATOMY = .;
   IF (AAPCLIEN <= -4) THEN AAPCLIEN = .;
   IF (ASELFHLP <= -4) THEN ASELFHLP = .;
   IF (ACOMMIT <= -4) THEN ACOMMIT = .;
   IF (ACOMPRTN <= -4) THEN ACOMPRTN = .;
   IF (ACOMPMED <= -4) THEN ACOMPMED = .;
   IF (ALIFPAIN <= -4) THEN ALIFPAIN = .;
   IF (ABLDTRST <= -4) THEN ABLDTRST = .;
   IF (ADISCRIM <= -4) THEN ADISCRIM = .;
   IF (ADOMVIOL <= -4) THEN ADOMVIOL = .;
   IF (AFACACC <= -4) THEN AFACACC = .;
   IF (AFAMISS <= -4) THEN AFAMISS = .;
   IF (AFOODPRP <= -4) THEN AFOODPRP = .;
   IF (AHLTHTX <= -4) THEN AHLTHTX = .;
   IF (AHLTHTOP <= -4) THEN AHLTHTOP = .;
   IF (AHOMELES <= -4) THEN AHOMELES = .;
   IF (APOSAT <= -4) THEN APOSAT = .;
   IF (ALIFPATT <= -4) THEN ALIFPATT = .;
   IF (AMORDEMO <= -4) THEN AMORDEMO = .;
   IF (ANEGSKIL <= -4) THEN ANEGSKIL = .;
   IF (APEERSUP <= -4) THEN APEERSUP = .;
   IF (AROLES <= -4) THEN AROLES = .;
   IF (AREDUBEH <= -4) THEN AREDUBEH = .;
   IF (APOVERTY <= -4) THEN APOVERTY = .;
   IF (APWRLES <= -4) THEN APWRLES = .;
   IF (APROMSLF <= -4) THEN APROMSLF = .;
   IF (ATBTST <= -4) THEN ATBTST = .;
   IF (ADISCST <= -4) THEN ADISCST = .;
   IF (ARESPECT <= -4) THEN ARESPECT = .;
   IF (AROLPLAY <= -4) THEN AROLPLAY = .;
   IF (ASLFEFF <= -4) THEN ASLFEFF = .;
   IF (ASLFENH <= -4) THEN ASLFENH = .;
   IF (ASLFEST <= -4) THEN ASLFEST = .;
   IF (ASKLLTRA <= -4) THEN ASKLLTRA = .;
   IF (ASTRMAN <= -4) THEN ASTRMAN = .;
   IF (ASOCIALS <= -4) THEN ASOCIALS = .;
   IF (APHOTDEM <= -4) THEN APHOTDEM = .;
   IF (ATALID <= -4) THEN ATALID = .;
   IF (ATRUST <= -4) THEN ATRUST = .;
   IF (AETHCUL <= -4) THEN AETHCUL = .;
   IF (AWLLBNG <= -4) THEN AWLLBNG = .;
   IF (AOTH <= -4) THEN AOTH = .;
   IF (AHIV <= -4) THEN AHIV = .;
   IF (AOTHISS <= -4) THEN AOTHISS = .;
   IF (ABOTH <= -4) THEN ABOTH = .;
   IF (AHIVFRST <= -4) THEN AHIVFRST = .;
   IF (AISSFRST <= -4) THEN AISSFRST = .;
   IF (AIND <= -4) THEN AIND = .;
   IF (AGRP <= -4) THEN AGRP = .;
   IF (AGRPSZ <= -4) THEN AGRPSZ = .;
   IF (AGRPCOMP <= -4) THEN AGRPCOMP = .;
   IF (AOTH_ <= -4) THEN AOTH_ = .;
   IF (AOTH_SP <= -4) THEN AOTH_SP = .;
   IF (APROJOFF <= -4) THEN APROJOFF = .;
   IF (ASTREET <= -4) THEN ASTREET = .;
   IF (AVAN <= -4) THEN AVAN = .;
   IF (AOTHPLAC <= -4) THEN AOTHPLAC = .;
   IF (AOTHSPPL <= -4) THEN AOTHSPPL = .;
   IF (APREF_ <= -4) THEN APREF_ = .;
   IF (ASES1 <= -4) THEN ASES1 = .;
   IF (ASES2 <= -4) THEN ASES2 = .;
   IF (ASES3 <= -4) THEN ASES3 = .;
   IF (ASES4 <= -4) THEN ASES4 = .;
   IF (ASES5 <= -4) THEN ASES5 = .;
   IF (ASES6 <= -4) THEN ASES6 = .;
   IF (ANONE <= -4) THEN ANONE = .;
   IF (APHONE <= -4) THEN APHONE = .;
   IF (APHONE_ <= -4) THEN APHONE_ = .;
   IF (AOUTWOR <= -4) THEN AOUTWOR = .;
   IF (AOUTWOR_ <= -4) THEN AOUTWOR_ = .;
   IF (ADROPSES <= -4) THEN ADROPSES = .;
   IF (ADROPSPE <= -4) THEN ADROPSPE = .;
   IF (ASUPGRP <= -4) THEN ASUPGRP = .;
   IF (ALGTHSES <= -4) THEN ALGTHSES = .;
   IF (AOFTNGRP <= -4) THEN AOFTNGRP = .;
   IF (AOTHREIN <= -4) THEN AOTHREIN = .;
   IF (AOTHSP <= -4) THEN AOTHSP = .;
   IF (AINCENT <= -4) THEN AINCENT = .;
   IF (ADESC <= -4) THEN ADESC = .;
   IF (ASTART <= -4) THEN ASTART = .;
   IF (ACOMP <= -4) THEN ACOMP = .;
   IF (ATOT <= -4) THEN ATOT = .;
   IF (ATOTSP <= -4) THEN ATOTSP = .;
   IF (APAID <= -4) THEN APAID = .;
   IF (AGENDER <= -4) THEN AGENDER = .;
   IF (AHEDM <= -4) THEN AHEDM = .;
   IF (AHEDB <= -4) THEN AHEDB = .;
   IF (AHEDN <= -4) THEN AHEDN = .;
   IF (APEERCON <= -4) THEN APEERCON = .;
   IF (ANURSE <= -4) THEN ANURSE = .;
   IF (ADRGCON <= -4) THEN ADRGCON = .;
   IF (AOTHINT <= -4) THEN AOTHINT = .;
   IF (AOTHSPIN <= -4) THEN AOTHSPIN = .;
   IF (ATRANSP <= -4) THEN ATRANSP = .;
   IF (AHIVTEST <= -4) THEN AHIVTEST = .;
   IF (AHIVCOUN <= -4) THEN AHIVCOUN = .;
   IF (AURINTST <= -4) THEN AURINTST = .;
   IF (AOTHIS2 <= -4) THEN AOTHIS2 = .;
   IF (AOTHIS1 <= -4) THEN AOTHIS1 = .;
   IF (AOTHIS3 <= -4) THEN AOTHIS3 = .;
   IF (AINDSZ <= -4) THEN AINDSZ = .;
   IF (AINDCOMP <= -4) THEN AINDCOMP = .;
   IF (LD88HIVP <= -4.000) THEN LD88HIVP = .;
   IF (LD90HIVP <= -4.000) THEN LD90HIVP = .;
   IF (LD92HIVP <= -4.00) THEN LD92HIVP = .;
   IF (LD94HIVP <= -4.00) THEN LD94HIVP = .;
   IF (LD96HIVP <= -4.00) THEN LD96HIVP = .;
   IF (LD88ACCP <= -4) THEN LD88ACCP = .;
   IF (LD90ACCP <= -4) THEN LD90ACCP = .;
   IF (LD92ACCP <= -4) THEN LD92ACCP = .;
   IF (LD94ACCP <= -4) THEN LD94ACCP = .;
   IF (LD96ACCP <= -4) THEN LD96ACCP = .;
   IF (LD88HIVI <= -4.000) THEN LD88HIVI = .;
   IF (LD90HIVI <= -4.000) THEN LD90HIVI = .;
   IF (LD92HIVI <= -4.000) THEN LD92HIVI = .;
   IF (LD94HIVI <= -4.000) THEN LD94HIVI = .;
   IF (LD96HIVI <= -4.000) THEN LD96HIVI = .;
   IF (LD88ACCI <= -4) THEN LD88ACCI = .;
   IF (LD90ACCI <= -4) THEN LD90ACCI = .;
   IF (LD92ACCI <= -4) THEN LD92ACCI = .;
   IF (LD94ACCI <= -4) THEN LD94ACCI = .;
   IF (LD96ACCI <= -4) THEN LD96ACCI = .;
   IF (LD88PHAV <= -4) THEN LD88PHAV = .;
   IF (LD90PHAV <= -4) THEN LD90PHAV = .;
   IF (LD92PHAV <= -4) THEN LD92PHAV = .;
   IF (LD94PHAV <= -4) THEN LD94PHAV = .;
   IF (LD96PHAV <= -4) THEN LD96PHAV = .;
   IF (LD88PHUS <= -4) THEN LD88PHUS = .;
   IF (LD90PHUS <= -4) THEN LD90PHUS = .;
   IF (LD92PHUS <= -4) THEN LD92PHUS = .;
   IF (LD94PHUS <= -4) THEN LD94PHUS = .;
   IF (LD96PHUS <= -4) THEN LD96PHUS = .;
   IF (LD88PHAC <= -4) THEN LD88PHAC = .;
   IF (LD90PHAC <= -4) THEN LD90PHAC = .;
   IF (LD92PHAC <= -4) THEN LD92PHAC = .;
   IF (LD94PHAC <= -4) THEN LD94PHAC = .;
   IF (LD96PHAC <= -4) THEN LD96PHAC = .;
   IF (LD88NEAV <= -4) THEN LD88NEAV = .;
   IF (LD90NEAV <= -4) THEN LD90NEAV = .;
   IF (LD92NEAV <= -4) THEN LD92NEAV = .;
   IF (LD94NEAV <= -4) THEN LD94NEAV = .;
   IF (LD96NEAV <= -4) THEN LD96NEAV = .;
   IF (LD88NEUS <= -4) THEN LD88NEUS = .;
   IF (LD90NEUS <= -4) THEN LD90NEUS = .;
   IF (LD92NEUS <= -4) THEN LD92NEUS = .;
   IF (LD94NEUS <= -4) THEN LD94NEUS = .;
   IF (LD96NEUS <= -4) THEN LD96NEUS = .;
   IF (LD88NEAC <= -4) THEN LD88NEAC = .;
   IF (LD90NEAC <= -4) THEN LD90NEAC = .;
   IF (LD92NEAC <= -4) THEN LD92NEAC = .;
   IF (LD94NEAC <= -4) THEN LD94NEAC = .;
   IF (LD96NEAC <= -4) THEN LD96NEAC = .;
   IF (LD88DBAV <= -4) THEN LD88DBAV = .;
   IF (LD90DBAV <= -4) THEN LD90DBAV = .;
   IF (LD92DBAV <= -4) THEN LD92DBAV = .;
   IF (LD94DBAV <= -4) THEN LD94DBAV = .;
   IF (LD96DBAV <= -4) THEN LD96DBAV = .;
   IF (LD88DBUS <= -4) THEN LD88DBUS = .;
   IF (LD90DBUS <= -4) THEN LD90DBUS = .;
   IF (LD92DBUS <= -4) THEN LD92DBUS = .;
   IF (LD94DBUS <= -4) THEN LD94DBUS = .;
   IF (LD96DBUS <= -4) THEN LD96DBUS = .;
   IF (LD88DBAC <= -4) THEN LD88DBAC = .;
   IF (LD90DBAC <= -4) THEN LD90DBAC = .;
   IF (LD92DBAC <= -4) THEN LD92DBAC = .;
   IF (LD94DBAC <= -4) THEN LD94DBAC = .;
   IF (LD96DBAC <= -4) THEN LD96DBAC = .;
   IF (LD88SDAV <= -4) THEN LD88SDAV = .;
   IF (LD90SDAV <= -4) THEN LD90SDAV = .;
   IF (LD92SDAV <= -4) THEN LD92SDAV = .;
   IF (LD94SDAV <= -4) THEN LD94SDAV = .;
   IF (LD96SDAV <= -4) THEN LD96SDAV = .;
   IF (LD88SDUS <= -4) THEN LD88SDUS = .;
   IF (LD90SDUS <= -4) THEN LD90SDUS = .;
   IF (LD92SDUS <= -4) THEN LD92SDUS = .;
   IF (LD94SDUS <= -4) THEN LD94SDUS = .;
   IF (LD96SDUS <= -4) THEN LD96SDUS = .;
   IF (LD88SDAC <= -4) THEN LD88SDAC = .;
   IF (LD90SDAC <= -4) THEN LD90SDAC = .;
   IF (LD92SDAC <= -4) THEN LD92SDAC = .;
   IF (LD94SDAC <= -4) THEN LD94SDAC = .;
   IF (LD96SDAC <= -4) THEN LD96SDAC = .;
   IF (LD88SGAV <= -4) THEN LD88SGAV = .;
   IF (LD90SGAV <= -4) THEN LD90SGAV = .;
   IF (LD92SGAV <= -4) THEN LD92SGAV = .;
   IF (LD94SGAV <= -4) THEN LD94SGAV = .;
   IF (LD96SGAV <= -4) THEN LD96SGAV = .;
   IF (LD88SGUS <= -4) THEN LD88SGUS = .;
   IF (LD90SGUS <= -4) THEN LD90SGUS = .;
   IF (LD92SGUS <= -4) THEN LD92SGUS = .;
   IF (LD94SGUS <= -4) THEN LD94SGUS = .;
   IF (LD96SGUS <= -4) THEN LD96SGUS = .;
   IF (LD88SGAC <= -4) THEN LD88SGAC = .;
   IF (LD90SGAC <= -4) THEN LD90SGAC = .;
   IF (LD92SGAC <= -4) THEN LD92SGAC = .;
   IF (LD94SGAC <= -4) THEN LD94SGAC = .;
   IF (LD96SGAC <= -4) THEN LD96SGAC = .;
   IF (LD88NE01 <= -4) THEN LD88NE01 = .;
   IF (LD90NE01 <= -4) THEN LD90NE01 = .;
   IF (LD92NE01 <= -4) THEN LD92NE01 = .;
   IF (LD94NE01 <= -4) THEN LD94NE01 = .;
   IF (LD96NE01 <= -4) THEN LD96NE01 = .;
   IF (LD88NE02 <= -4) THEN LD88NE02 = .;
   IF (LD90NE02 <= -4) THEN LD90NE02 = .;
   IF (LD92NE02 <= -4) THEN LD92NE02 = .;
   IF (LD94NE02 <= -4) THEN LD94NE02 = .;
   IF (LD96NE02 <= -4) THEN LD96NE02 = .;
   IF (LD88NE03 <= -4) THEN LD88NE03 = .;
   IF (LD90NE03 <= -4) THEN LD90NE03 = .;
   IF (LD92NE03 <= -4) THEN LD92NE03 = .;
   IF (LD94NE03 <= -4) THEN LD94NE03 = .;
   IF (LD96NE03 <= -4) THEN LD96NE03 = .;
   IF (LD88NEC1 <= -4) THEN LD88NEC1 = .;
   IF (LD90NEC1 <= -4) THEN LD90NEC1 = .;
   IF (LD92NEC1 <= -4) THEN LD92NEC1 = .;
   IF (LD94NEC1 <= -4) THEN LD94NEC1 = .;
   IF (LD96NEC1 <= -4) THEN LD96NEC1 = .;
   IF (LD88NEC2 <= -4) THEN LD88NEC2 = .;
   IF (LD90NEC2 <= -4) THEN LD90NEC2 = .;
   IF (LD92NEC2 <= -4) THEN LD92NEC2 = .;
   IF (LD94NEC2 <= -4) THEN LD94NEC2 = .;
   IF (LD96NEC2 <= -4) THEN LD96NEC2 = .;
   IF (LD90OP1 <= -4) THEN LD90OP1 = .;
   IF (LD92OP1 <= -4) THEN LD92OP1 = .;
   IF (LD94OP1 <= -4) THEN LD94OP1 = .;
   IF (LD96OP1 <= -4) THEN LD96OP1 = .;
   IF (LD92OP2 <= -4) THEN LD92OP2 = .;
   IF (LD94OP2 <= -4) THEN LD94OP2 = .;
   IF (LD96OP2 <= -4) THEN LD96OP2 = .;
   IF (LD94OP3 <= -4) THEN LD94OP3 = .;
   IF (LD96OP3 <= -4) THEN LD96OP3 = .;
   IF (LD90MAX1 <= -4) THEN LD90MAX1 = .;
   IF (LD92MAX1 <= -4) THEN LD92MAX1 = .;
   IF (LD94MAX1 <= -4) THEN LD94MAX1 = .;
   IF (LD96MAX1 <= -4) THEN LD96MAX1 = .;
   IF (LD94MAX2 <= -4) THEN LD94MAX2 = .;
   IF (LD96MAX2 <= -4) THEN LD96MAX2 = .;
   IF (LD94MAX3 <= -4) THEN LD94MAX3 = .;
   IF (LD96MAX3 <= -4) THEN LD96MAX3 = .;
   IF (LD90ANN1 <= -4) THEN LD90ANN1 = .;
   IF (LD92ANN1 <= -4) THEN LD92ANN1 = .;
   IF (LD94ANN1 <= -4) THEN LD94ANN1 = .;
   IF (LD96ANN1 <= -4) THEN LD96ANN1 = .;
   IF (LD96ANN2 <= -4) THEN LD96ANN2 = .;
   IF (LD88LAWS <= -4) THEN LD88LAWS = .;
   IF (LD90LAWS <= -4) THEN LD90LAWS = .;
   IF (LD92LAWS <= -4) THEN LD92LAWS = .;
   IF (LD94LAWS <= -4) THEN LD94LAWS = .;
   IF (LD96LAWS <= -4) THEN LD96LAWS = .;
   IF (LD88LAWL <= -4) THEN LD88LAWL = .;
   IF (LD90LAWL <= -4) THEN LD90LAWL = .;
   IF (LD92LAWL <= -4) THEN LD92LAWL = .;
   IF (LD94LAWL <= -4) THEN LD94LAWL = .;
   IF (LD96LAWL <= -4) THEN LD96LAWL = .;
   IF (LD88NORX <= -4) THEN LD88NORX = .;
   IF (LD90NORX <= -4) THEN LD90NORX = .;
   IF (LD92NORX <= -4) THEN LD92NORX = .;
   IF (LD94NORX <= -4) THEN LD94NORX = .;
   IF (LD96NORX <= -4) THEN LD96NORX = .;
   IF (LD88MINP <= -4) THEN LD88MINP = .;
   IF (LD90MINP <= -4) THEN LD90MINP = .;
   IF (LD92MINP <= -4) THEN LD92MINP = .;
   IF (LD94MINP <= -4) THEN LD94MINP = .;
   IF (LD96MINP <= -4) THEN LD96MINP = .;
   IF (LD88ID <= -4) THEN LD88ID = .;
   IF (LD90ID <= -4) THEN LD90ID = .;
   IF (LD92ID <= -4) THEN LD92ID = .;
   IF (LD94ID <= -4) THEN LD94ID = .;
   IF (LD96ID <= -4) THEN LD96ID = .;
   IF (LD88SIG <= -4) THEN LD88SIG = .;
   IF (LD90SIG <= -4) THEN LD90SIG = .;
   IF (LD92SIG <= -4) THEN LD92SIG = .;
   IF (LD94SIG <= -4) THEN LD94SIG = .;
   IF (LD96SIG <= -4) THEN LD96SIG = .;
   IF (LD88PRDB <= -4) THEN LD88PRDB = .;
   IF (LD90PRDB <= -4) THEN LD90PRDB = .;
   IF (LD92PRDB <= -4) THEN LD92PRDB = .;
   IF (LD94PRDB <= -4) THEN LD94PRDB = .;
   IF (LD96PRDB <= -4) THEN LD96PRDB = .;
   IF (LD88DTPP <= -4) THEN LD88DTPP = .;
   IF (LD90DTPP <= -4) THEN LD90DTPP = .;
   IF (LD92DTPP <= -4) THEN LD92DTPP = .;
   IF (LD94DTPP <= -4) THEN LD94DTPP = .;
   IF (LD96DTPP <= -4) THEN LD96DTPP = .;
   IF (LD88DTPR <= -4) THEN LD88DTPR = .;
   IF (LD90DTPR <= -4) THEN LD90DTPR = .;
   IF (LD92DTPR <= -4) THEN LD92DTPR = .;
   IF (LD94DTPR <= -4) THEN LD94DTPR = .;
   IF (LD96DTPR <= -4) THEN LD96DTPR = .;
   IF (LD88HTCP <= -4) THEN LD88HTCP = .;
   IF (LD90HTCP <= -4) THEN LD90HTCP = .;
   IF (LD92HTCP <= -4) THEN LD92HTCP = .;
   IF (LD94HTCP <= -4) THEN LD94HTCP = .;
   IF (LD96HTCP <= -4) THEN LD96HTCP = .;
   IF (LD88HTCR <= -4) THEN LD88HTCR = .;
   IF (LD90HTCR <= -4) THEN LD90HTCR = .;
   IF (LD92HTCR <= -4) THEN LD92HTCR = .;
   IF (LD94HTCR <= -4) THEN LD94HTCR = .;
   IF (LD96HTCR <= -4) THEN LD96HTCR = .;
   IF (LD88STDP <= -4) THEN LD88STDP = .;
   IF (LD90STDP <= -4) THEN LD90STDP = .;
   IF (LD92STDP <= -4) THEN LD92STDP = .;
   IF (LD94STDP <= -4) THEN LD94STDP = .;
   IF (LD96STDP <= -4) THEN LD96STDP = .;
   IF (LD88STDR <= -4) THEN LD88STDR = .;
   IF (LD90STDR <= -4) THEN LD90STDR = .;
   IF (LD92STDR <= -4) THEN LD92STDR = .;
   IF (LD94STDR <= -4) THEN LD94STDR = .;
   IF (LD96STDR <= -4) THEN LD96STDR = .;
   IF (LD88HOPP <= -4) THEN LD88HOPP = .;
   IF (LD90HOPP <= -4) THEN LD90HOPP = .;
   IF (LD92HOPP <= -4) THEN LD92HOPP = .;
   IF (LD94HOPP <= -4) THEN LD94HOPP = .;
   IF (LD96HOPP <= -4) THEN LD96HOPP = .;
   IF (LD88HOPR <= -4) THEN LD88HOPR = .;
   IF (LD90HOPR <= -4) THEN LD90HOPR = .;
   IF (LD92HOPR <= -4) THEN LD92HOPR = .;
   IF (LD94HOPR <= -4) THEN LD94HOPR = .;
   IF (LD96HOPR <= -4) THEN LD96HOPR = .;
   IF (LD88OOPP <= -4) THEN LD88OOPP = .;
   IF (LD90OOPP <= -4) THEN LD90OOPP = .;
   IF (LD92OOPP <= -4) THEN LD92OOPP = .;
   IF (LD94OOPP <= -4) THEN LD94OOPP = .;
   IF (LD96OOPP <= -4) THEN LD96OOPP = .;
   IF (LD88OOPR <= -4) THEN LD88OOPR = .;
   IF (LD90OOPR <= -4) THEN LD90OOPR = .;
   IF (LD92OOPR <= -4) THEN LD92OOPR = .;
   IF (LD94OOPR <= -4) THEN LD94OOPR = .;
   IF (LD96OOPR <= -4) THEN LD96OOPR = .;
   IF (LD88HCMP <= -4) THEN LD88HCMP = .;
   IF (LD90HCMP <= -4) THEN LD90HCMP = .;
   IF (LD92HCMP <= -4) THEN LD92HCMP = .;
   IF (LD94HCMP <= -4) THEN LD94HCMP = .;
   IF (LD96HCMP <= -4) THEN LD96HCMP = .;
   IF (LD88HCMR <= -4) THEN LD88HCMR = .;
   IF (LD90HCMR <= -4) THEN LD90HCMR = .;
   IF (LD92HCMR <= -4) THEN LD92HCMR = .;
   IF (LD94HCMR <= -4) THEN LD94HCMR = .;
   IF (LD96HCMR <= -4) THEN LD96HCMR = .;
   IF (LD88OCMP <= -4) THEN LD88OCMP = .;
   IF (LD90OCMP <= -4) THEN LD90OCMP = .;
   IF (LD92OCMP <= -4) THEN LD92OCMP = .;
   IF (LD94OCMP <= -4) THEN LD94OCMP = .;
   IF (LD96OCMP <= -4) THEN LD96OCMP = .;
   IF (LD88OCMR <= -4) THEN LD88OCMR = .;
   IF (LD90OCMR <= -4) THEN LD90OCMR = .;
   IF (LD92OCMR <= -4) THEN LD92OCMR = .;
   IF (LD94OCMR <= -4) THEN LD94OCMR = .;
   IF (LD96OCMR <= -4) THEN LD96OCMR = .;
   IF (LD88MSP <= -4) THEN LD88MSP = .;
   IF (LD90MSP <= -4) THEN LD90MSP = .;
   IF (LD92MSP <= -4) THEN LD92MSP = .;
   IF (LD94MSP <= -4) THEN LD94MSP = .;
   IF (LD96MSP <= -4) THEN LD96MSP = .;
   IF (LD88MSR <= -4) THEN LD88MSR = .;
   IF (LD90MSR <= -4) THEN LD90MSR = .;
   IF (LD92MSR <= -4) THEN LD92MSR = .;
   IF (LD94MSR <= -4) THEN LD94MSR = .;
   IF (LD96MSR <= -4) THEN LD96MSR = .;
   IF (LD88HLP <= -4) THEN LD88HLP = .;
   IF (LD90HLP <= -4) THEN LD90HLP = .;
   IF (LD92HLP <= -4) THEN LD92HLP = .;
   IF (LD94HLP <= -4) THEN LD94HLP = .;
   IF (LD96HLP <= -4) THEN LD96HLP = .;
   IF (LD88HLR <= -4) THEN LD88HLR = .;
   IF (LD90HLR <= -4) THEN LD90HLR = .;
   IF (LD92HLR <= -4) THEN LD92HLR = .;
   IF (LD94HLR <= -4) THEN LD94HLR = .;
   IF (LD96HLR <= -4) THEN LD96HLR = .;
   IF (LD88OIPP <= -4) THEN LD88OIPP = .;
   IF (LD90OIPP <= -4) THEN LD90OIPP = .;
   IF (LD92OIPP <= -4) THEN LD92OIPP = .;
   IF (LD94OIPP <= -4) THEN LD94OIPP = .;
   IF (LD96OIPP <= -4) THEN LD96OIPP = .;
   IF (LD88OIPR <= -4) THEN LD88OIPR = .;
   IF (LD90OIPR <= -4) THEN LD90OIPR = .;
   IF (LD92OIPR <= -4) THEN LD92OIPR = .;
   IF (LD94OIPR <= -4) THEN LD94OIPR = .;
   IF (LD96OIPR <= -4) THEN LD96OIPR = .;
   IF (LDPOPEST <= -4) THEN LDPOPEST = .;
   IF (LD88IDU <= -4) THEN LD88IDU = .;
   IF (LD88CONF <= -4) THEN LD88CONF = .;
   IF (LD88GEO <= -4) THEN LD88GEO = .;
   IF (LD88TRAN <= -4) THEN LD88TRAN = .;
   IF (LD88IMM <= -4) THEN LD88IMM = .;
   IF (LD88EMI <= -4) THEN LD88EMI = .;
   IF (LD90IDU <= -4) THEN LD90IDU = .;
   IF (LD90CONF <= -4) THEN LD90CONF = .;
   IF (LD90GEO <= -4) THEN LD90GEO = .;
   IF (LD90TRAN <= -4) THEN LD90TRAN = .;
   IF (LD90IMM <= -4) THEN LD90IMM = .;
   IF (LD90EMI <= -4) THEN LD90EMI = .;
   IF (LD92IDU <= -4) THEN LD92IDU = .;
   IF (LD92CONF <= -4) THEN LD92CONF = .;
   IF (LD92GEO <= -4) THEN LD92GEO = .;
   IF (LD92TRAN <= -4) THEN LD92TRAN = .;
   IF (LD92IMM <= -4) THEN LD92IMM = .;
   IF (LD92EMI <= -4) THEN LD92EMI = .;
   IF (LD94IDU <= -4) THEN LD94IDU = .;
   IF (LD94CONF <= -4) THEN LD94CONF = .;
   IF (LD94GEO <= -4) THEN LD94GEO = .;
   IF (LD94TRAN <= -4) THEN LD94TRAN = .;
   IF (LD94IMM <= -4) THEN LD94IMM = .;
   IF (LD94EMI <= -4) THEN LD94EMI = .;
   IF (LD96IDU <= -4) THEN LD96IDU = .;
   IF (LD96CONF <= -4) THEN LD96CONF = .;
   IF (LD96GEO <= -4) THEN LD96GEO = .;
   IF (LD96TRAN <= -4) THEN LD96TRAN = .;
   IF (LD96IMM <= -4) THEN LD96IMM = .;
   IF (LD96EMI <= -4) THEN LD96EMI = .;
   IF (LD88HL <= -4) THEN LD88HL = .;
   IF (LD88JAIL <= -4) THEN LD88JAIL = .;
   IF (LD88TRNS <= -4) THEN LD88TRNS = .;
   IF (LD88INST <= -4) THEN LD88INST = .;
   IF (LD90HL <= -4) THEN LD90HL = .;
   IF (LD90JAIL <= -4) THEN LD90JAIL = .;
   IF (LD90TRNS <= -4) THEN LD90TRNS = .;
   IF (LD90INST <= -4) THEN LD90INST = .;
   IF (LD92HL <= -4) THEN LD92HL = .;
   IF (LD92JAIL <= -4) THEN LD92JAIL = .;
   IF (LD92TRNS <= -4) THEN LD92TRNS = .;
   IF (LD92INST <= -4) THEN LD92INST = .;
   IF (LD94HL <= -4) THEN LD94HL = .;
   IF (LD94JAIL <= -4) THEN LD94JAIL = .;
   IF (LD94TRNS <= -4) THEN LD94TRNS = .;
   IF (LD94INST <= -4) THEN LD94INST = .;
   IF (LD96HL <= -4) THEN LD96HL = .;
   IF (LD96JAIL <= -4) THEN LD96JAIL = .;
   IF (LD96TRNS <= -4) THEN LD96TRNS = .;
   IF (LD96INST <= -4) THEN LD96INST = .;
   IF (LD88MALE <= -4) THEN LD88MALE = .;
   IF (LD90MALE <= -4) THEN LD90MALE = .;
   IF (LD92MALE <= -4) THEN LD92MALE = .;
   IF (LD94MALE <= -4) THEN LD94MALE = .;
   IF (LD96MALE <= -4) THEN LD96MALE = .;
   IF (LD88FEM <= -4) THEN LD88FEM = .;
   IF (LD90FEM <= -4) THEN LD90FEM = .;
   IF (LD92FEM <= -4) THEN LD92FEM = .;
   IF (LD94FEM <= -4) THEN LD94FEM = .;
   IF (LD96FEM <= -4) THEN LD96FEM = .;
   IF (LD88U25 <= -4) THEN LD88U25 = .;
   IF (LD90U25 <= -4) THEN LD90U25 = .;
   IF (LD92U25 <= -4) THEN LD92U25 = .;
   IF (LD94U25 <= -4) THEN LD94U25 = .;
   IF (LD96U25 <= -4) THEN LD96U25 = .;
   IF (LD882535 <= -4) THEN LD882535 = .;
   IF (LD902535 <= -4) THEN LD902535 = .;
   IF (LD922535 <= -4) THEN LD922535 = .;
   IF (LD942535 <= -4) THEN LD942535 = .;
   IF (LD962535 <= -4) THEN LD962535 = .;
   IF (LD88G35 <= -4) THEN LD88G35 = .;
   IF (LD90G35 <= -4) THEN LD90G35 = .;
   IF (LD92G35 <= -4) THEN LD92G35 = .;
   IF (LD94G35 <= -4) THEN LD94G35 = .;
   IF (LD96G35 <= -4) THEN LD96G35 = .;
   IF (LD88BLA <= -4) THEN LD88BLA = .;
   IF (LD90BLA <= -4) THEN LD90BLA = .;
   IF (LD92BLA <= -4) THEN LD92BLA = .;
   IF (LD94BLA <= -4) THEN LD94BLA = .;
   IF (LD96BLA <= -4) THEN LD96BLA = .;
   IF (LD88WHIT <= -4) THEN LD88WHIT = .;
   IF (LD90WHIT <= -4) THEN LD90WHIT = .;
   IF (LD92WHIT <= -4) THEN LD92WHIT = .;
   IF (LD94WHIT <= -4) THEN LD94WHIT = .;
   IF (LD96WHIT <= -4) THEN LD96WHIT = .;
   IF (LD88HISP <= -4) THEN LD88HISP = .;
   IF (LD90HISP <= -4) THEN LD90HISP = .;
   IF (LD92HISP <= -4) THEN LD92HISP = .;
   IF (LD94HISP <= -4) THEN LD94HISP = .;
   IF (LD96HISP <= -4) THEN LD96HISP = .;
   IF (LD88OTHR <= -4) THEN LD88OTHR = .;
   IF (LD90OTHR <= -4) THEN LD90OTHR = .;
   IF (LD92OTHR <= -4) THEN LD92OTHR = .;
   IF (LD94OTHR <= -4) THEN LD94OTHR = .;
   IF (LD96OTHR <= -4) THEN LD96OTHR = .;
   IF (LD88OTH <= -4) THEN LD88OTH = .;
   IF (LD90OTH <= -4) THEN LD90OTH = .;
   IF (LD92OTH <= -4) THEN LD92OTH = .;
   IF (LD94OTH <= -4) THEN LD94OTH = .;
   IF (LD96OTH <= -4) THEN LD96OTH = .;
   IF (LD88HER <= -4) THEN LD88HER = .;
   IF (LD90HER <= -4.0) THEN LD90HER = .;
   IF (LD92HER <= -4.0) THEN LD92HER = .;
   IF (LD94HER <= -4.0) THEN LD94HER = .;
   IF (LD96HER <= -4.0) THEN LD96HER = .;
   IF (LD88COC <= -4) THEN LD88COC = .;
   IF (LD90COC <= -4.0) THEN LD90COC = .;
   IF (LD92COC <= -4.0) THEN LD92COC = .;
   IF (LD94COC <= -4.0) THEN LD94COC = .;
   IF (LD96COC <= -4.0) THEN LD96COC = .;
   IF (LD88SPED <= -4) THEN LD88SPED = .;
   IF (LD90SPED <= -4.0) THEN LD90SPED = .;
   IF (LD92SPED <= -4.0) THEN LD92SPED = .;
   IF (LD94SPED <= -4.0) THEN LD94SPED = .;
   IF (LD96SPED <= -4.0) THEN LD96SPED = .;
   IF (LD88METH <= -4) THEN LD88METH = .;
   IF (LD90METH <= -4) THEN LD90METH = .;
   IF (LD92METH <= -4) THEN LD92METH = .;
   IF (LD94METH <= -4.0) THEN LD94METH = .;
   IF (LD96METH <= -4) THEN LD96METH = .;
   IF (LD88OTDR <= -4) THEN LD88OTDR = .;
   IF (LD90OTDR <= -4) THEN LD90OTDR = .;
   IF (LD92OTDR <= -4) THEN LD92OTDR = .;
   IF (LD94OTDR <= -4) THEN LD94OTDR = .;
   IF (LD96OTDR <= -4) THEN LD96OTDR = .;
   IF (LD88CON1 <= -4) THEN LD88CON1 = .;
   IF (LD90CON1 <= -4) THEN LD90CON1 = .;
   IF (LD92CON1 <= -4) THEN LD92CON1 = .;
   IF (LD94CON1 <= -4) THEN LD94CON1 = .;
   IF (LD96CON1 <= -4) THEN LD96CON1 = .;
   IF (LD88HERA <= -4) THEN LD88HERA = .;
   IF (LD90HERA <= -4) THEN LD90HERA = .;
   IF (LD92HERA <= -4) THEN LD92HERA = .;
   IF (LD94HERA <= -4) THEN LD94HERA = .;
   IF (LD96HERA <= -4) THEN LD96HERA = .;
   IF (LD88COCA <= -4) THEN LD88COCA = .;
   IF (LD90COCA <= -4) THEN LD90COCA = .;
   IF (LD92COCA <= -4) THEN LD92COCA = .;
   IF (LD94COCA <= -4) THEN LD94COCA = .;
   IF (LD96COCA <= -4) THEN LD96COCA = .;
   IF (LD88SPDA <= -4) THEN LD88SPDA = .;
   IF (LD90SPDA <= -4) THEN LD90SPDA = .;
   IF (LD92SPDA <= -4) THEN LD92SPDA = .;
   IF (LD94SPDA <= -4) THEN LD94SPDA = .;
   IF (LD96SPDA <= -4) THEN LD96SPDA = .;
   IF (LD88META <= -4) THEN LD88META = .;
   IF (LD90META <= -4) THEN LD90META = .;
   IF (LD92META <= -4) THEN LD92META = .;
   IF (LD94META <= -4) THEN LD94META = .;
   IF (LD96META <= -4) THEN LD96META = .;
   IF (LD88OTHA <= -4) THEN LD88OTHA = .;
   IF (LD90OTHA <= -4) THEN LD90OTHA = .;
   IF (LD92OTHA <= -4) THEN LD92OTHA = .;
   IF (LD94OTHA <= -4) THEN LD94OTHA = .;
   IF (LD96OTHA <= -4) THEN LD96OTHA = .;
   IF (LD88HERP <= -4) THEN LD88HERP = .;
   IF (LD90HERP <= -4) THEN LD90HERP = .;
   IF (LD92HERP <= -4) THEN LD92HERP = .;
   IF (LD94HERP <= -4) THEN LD94HERP = .;
   IF (LD96HERP <= -4) THEN LD96HERP = .;
   IF (LD88COCP <= -4) THEN LD88COCP = .;
   IF (LD90COCP <= -4) THEN LD90COCP = .;
   IF (LD92COCP <= -4) THEN LD92COCP = .;
   IF (LD94COCP <= -4) THEN LD94COCP = .;
   IF (LD96COCP <= -4) THEN LD96COCP = .;
   IF (LD88SPDP <= -4) THEN LD88SPDP = .;
   IF (LD90SPDP <= -4) THEN LD90SPDP = .;
   IF (LD92SPDP <= -4) THEN LD92SPDP = .;
   IF (LD94SPDP <= -4) THEN LD94SPDP = .;
   IF (LD96SPDP <= -4) THEN LD96SPDP = .;
   IF (LD88METP <= -4) THEN LD88METP = .;
   IF (LD90METP <= -4) THEN LD90METP = .;
   IF (LD92METP <= -4) THEN LD92METP = .;
   IF (LD94METP <= -4) THEN LD94METP = .;
   IF (LD96METP <= -4) THEN LD96METP = .;
   IF (LD88OTHP <= -4) THEN LD88OTHP = .;
   IF (LD90OTHP <= -4) THEN LD90OTHP = .;
   IF (LD92OTHP <= -4) THEN LD92OTHP = .;
   IF (LD94OTHP <= -4) THEN LD94OTHP = .;
   IF (LD96OTHP <= -4) THEN LD96OTHP = .;
   IF (LD88POP <= -4) THEN LD88POP = .;
   IF (LD90POP <= -4.0) THEN LD90POP = .;
   IF (LD92POP <= -4.0) THEN LD92POP = .;
   IF (LD94POP <= -4.0) THEN LD94POP = .;
   IF (LD96POP <= -4.0) THEN LD96POP = .;
   IF (LD88CON2 <= -4) THEN LD88CON2 = .;
   IF (LD90CON2 <= -4) THEN LD90CON2 = .;
   IF (LD92CON2 <= -4) THEN LD92CON2 = .;
   IF (LD94CON2 <= -4) THEN LD94CON2 = .;
   IF (LD96CON2 <= -4) THEN LD96CON2 = .;
   IF (LD88GAL <= -4) THEN LD88GAL = .;
   IF (LD90GAL <= -4) THEN LD90GAL = .;
   IF (LD92GAL <= -4) THEN LD92GAL = .;
   IF (LD94GAL <= -4) THEN LD94GAL = .;
   IF (LD96GAL <= -4) THEN LD96GAL = .;
   IF (LD88NGAL <= -4) THEN LD88NGAL = .;
   IF (LD90NGAL <= -4) THEN LD90NGAL = .;
   IF (LD92NGAL <= -4) THEN LD92NGAL = .;
   IF (LD94NGAL <= -4) THEN LD94NGAL = .;
   IF (LD96NGAL <= -4) THEN LD96NGAL = .;
   IF (LD88DISP <= -4) THEN LD88DISP = .;
   IF (LD90DISP <= -4) THEN LD90DISP = .;
   IF (LD92DISP <= -4) THEN LD92DISP = .;
   IF (LD94DISP <= -4) THEN LD94DISP = .;
   IF (LD96DISP <= -4) THEN LD96DISP = .;
   IF (LD88HAR <= -4) THEN LD88HAR = .;
   IF (LD90HAR <= -4) THEN LD90HAR = .;
   IF (LD92HAR <= -4) THEN LD92HAR = .;
   IF (LD94HAR <= -4) THEN LD94HAR = .;
   IF (LD96HAR <= -4) THEN LD96HAR = .;
   IF (LD88INIT <= -4) THEN LD88INIT = .;
   IF (LD90INIT <= -4) THEN LD90INIT = .;
   IF (LD92INIT <= -4) THEN LD92INIT = .;
   IF (LD94INIT <= -4) THEN LD94INIT = .;
   IF (LD96INIT <= -4) THEN LD96INIT = .;
   IF (LD88NINI <= -4) THEN LD88NINI = .;
   IF (LD90NINI <= -4) THEN LD90NINI = .;
   IF (LD92NINI <= -4) THEN LD92NINI = .;
   IF (LD94NINI <= -4) THEN LD94NINI = .;
   IF (LD96NINI <= -4) THEN LD96NINI = .;
   IF (LD88CON3 <= -4) THEN LD88CON3 = .;
   IF (LD90CON3 <= -4) THEN LD90CON3 = .;
   IF (LD92CON3 <= -4) THEN LD92CON3 = .;
   IF (LD94CON3 <= -4) THEN LD94CON3 = .;
   IF (LD96CON3 <= -4) THEN LD96CON3 = .;
   IF (LD88AVAI <= -4) THEN LD88AVAI = .;
   IF (LD90AVAI <= -4) THEN LD90AVAI = .;
   IF (LD92AVAI <= -4) THEN LD92AVAI = .;
   IF (LD94AVAI <= -4) THEN LD94AVAI = .;
   IF (LD96AVAI <= -4) THEN LD96AVAI = .;
   IF (LD88BLCH <= -4) THEN LD88BLCH = .;
   IF (LD90BLCH <= -4) THEN LD90BLCH = .;
   IF (LD92BLCH <= -4) THEN LD92BLCH = .;
   IF (LD94BLCH <= -4) THEN LD94BLCH = .;
   IF (LD96BLCH <= -4) THEN LD96BLCH = .;
   IF (LDINTYR <= -4) THEN LDINTYR = .;
   IF (LDINTSVC <= -4) THEN LDINTSVC = .;
   IF (LDINTNED <= -4) THEN LDINTNED = .;
   IF (LDINTSRC <= -4) THEN LDINTSRC = .;
   IF (LDINTTRT <= -4) THEN LDINTTRT = .;
   IF (LDINTACC <= -4) THEN LDINTACC = .;
   IF (PHARMAVA <= -4) THEN PHARMAVA = .;
   IF (NEEDLEAV <= -4) THEN NEEDLEAV = .;
   IF (DIABAVA <= -4) THEN DIABAVA = .;
   IF (DEALERAV <= -4) THEN DEALERAV = .;
   IF (GALLERAV <= -4) THEN GALLERAV = .;
   IF (AVAIL <= -4) THEN AVAIL = .;
   IF (AVAIL88 <= -4) THEN AVAIL88 = .;
   IF (AVAIL90 <= -4) THEN AVAIL90 = .;
   IF (AVAIL92 <= -4) THEN AVAIL92 = .;
   IF (AVAIL94 <= -4) THEN AVAIL94 = .;
   IF (AVAIL96 <= -4) THEN AVAIL96 = .;
   IF (PHARMUSE <= -4) THEN PHARMUSE = .;
   IF (NEEDLUSE <= -4) THEN NEEDLUSE = .;
   IF (DIABUSE <= -4) THEN DIABUSE = .;
   IF (DLRUSE <= -4) THEN DLRUSE = .;
   IF (GALLERUS <= -4) THEN GALLERUS = .;
   IF (USED <= -4) THEN USED = .;
   IF (USED88 <= -4) THEN USED88 = .;
   IF (USED90 <= -4) THEN USED90 = .;
   IF (USED92 <= -4) THEN USED92 = .;
   IF (USED94 <= -4) THEN USED94 = .;
   IF (USED96 <= -4) THEN USED96 = .;
   IF (NEP <= -4) THEN NEP = .;
   IF (NEP88 <= -4) THEN NEP88 = .;
   IF (NEP90 <= -4) THEN NEP90 = .;
   IF (NEP92 <= -4) THEN NEP92 = .;
   IF (NEP94 <= -4) THEN NEP94 = .;
   IF (NEP96 <= -4) THEN NEP96 = .;
   IF (INTPRO88 <= -4) THEN INTPRO88 = .;
   IF (INTPRO90 <= -4) THEN INTPRO90 = .;
   IF (INTPRO92 <= -4) THEN INTPRO92 = .;
   IF (INTPRO94 <= -4) THEN INTPRO94 = .;
   IF (INTPRO96 <= -4) THEN INTPRO96 = .;
   IF (RCHD88 <= -4) THEN RCHD88 = .;
   IF (RCHD90 <= -4) THEN RCHD90 = .;
   IF (RCHD92 <= -4) THEN RCHD92 = .;
   IF (RCHD94 <= -4) THEN RCHD94 = .;
   IF (RCHD96 <= -4) THEN RCHD96 = .;
   IF (PROGTOT <= -4) THEN PROGTOT = .;
   IF (RCHDTOT <= -4) THEN RCHDTOT = .;
   IF (NORX <= -4) THEN NORX = .;
   IF (DRUGTRTP <= -4) THEN DRUGTRTP = .;
   IF (HIVTESTP <= -4) THEN HIVTESTP = .;
   IF (STDPROG <= -4) THEN STDPROG = .;
   IF (HIVORPRG <= -4) THEN HIVORPRG = .;
   IF (OTHORPRG <= -4) THEN OTHORPRG = .;
   IF (HIVCMPRG <= -4) THEN HIVCMPRG = .;
   IF (OTHCMPRG <= -4) THEN OTHCMPRG = .;
   IF (MEDSVPRG <= -4) THEN MEDSVPRG = .;
   IF (HLPROG <= -4) THEN HLPROG = .;
   IF (OTHINTPR <= -4) THEN OTHINTPR = .;
   IF (DRUGTRTR <= -4) THEN DRUGTRTR = .;
   IF (HIVTESTR <= -4) THEN HIVTESTR = .;
   IF (STDRCHD <= -4) THEN STDRCHD = .;
   IF (HIVORRCH <= -4) THEN HIVORRCH = .;
   IF (OTHORRCH <= -4) THEN OTHORRCH = .;
   IF (HIVCMRCH <= -4) THEN HIVCMRCH = .;
   IF (OTHCMRCH <= -4) THEN OTHCMRCH = .;
   IF (MEDSVRCH <= -4) THEN MEDSVRCH = .;
   IF (HLRCHD <= -4) THEN HLRCHD = .;
   IF (OTHINTR <= -4) THEN OTHINTR = .;
   IF (EARLY <= -4) THEN EARLY = .;
   IF (DESIGN <= -4) THEN DESIGN = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT SITECODE sitecode. SI1 si1fffff. SI2 si2fffff.
         SI3 si3fffff. SI4 si4fffff. SI5 si5fffff.
         SI6_1 si6_1fff. SI6_2 si6_2fff. SI7_1 si7_1fff.
         SI7_2 si7_2fff. SI7_3 si7_3fff. SI7_4 si7_4fff.
         SI7_5 si7_5fff. SI8 si8fffff. SI9 si9fffff.
         SI10_1 si10_1ff. SI10B_2 si10b_2f. SI11 si11ffff.
         SI12_1 si12_1ff. SI12_2 si12_2ff. SI13 si13ffff.
         SI14 si14ffff. SI15 si15ffff. SI16 si16ffff.
         SI17 si17ffff. SI18 si18ffff. SI19 si19ffff.
         SI20 si20ffff. SI21 si21ffff. SI22_1 si22_1ff.
         SI22_2 si22_2ff. SI23 si23ffff. SI24 si24ffff.
         SI25 si25ffff. SI26 si26ffff. SI27 si27ffff.
         SI28 si28ffff. SI29 si29ffff. SI30 si30ffff.
         SI31 si31ffff. SI32 si32ffff. SI32A si32a.
         SI33 si33ffff. SI34 si34ffff. SI35 si35ffff.
         SI36 si36ffff. SI37 si37ffff. SI38 si38ffff.
         SI39 si39ffff. SI40 si40ffff. SI40A si40a.
         SI40B si40b. SI40C si40c. SI40D si40d.
         SI41 si41ffff. SI42 si42ffff. SI43 si43ffff.
         SI43A si43a. SI43B si43b. SI43C si43c.
         SI43D si43d. SI43E si43e. SI43F si43f.
         SI44 si44ffff. SI45 si45ffff. SI46 si46ffff.
         SI47 si47ffff. SI48 si48ffff. SI48_1 si48_1ff.
         SI48_2 si48_2ff. SI49 si49ffff. SI49A si49a.
         SI49_1 si49_1ff. SI49_2 si49_2ff. SI50 si50ffff.
         SI50A si50a. SI50A_1 si50a_1f. SI50A_2 si50a_2f.
         SI51_1 si51_1ff. SI51_2 si51_2ff. SI52_1 si52_1ff.
         SI52_2 si52_2ff. SI54 si54ffff. SI55 si55ffff.
         SI55A si55a. SI55B si55b. SI55C si55c.
         SI55D si55d. SI56 si56ffff. SI57 si57ffff.
         SI58 si58ffff. SI59 si59ffff. SI60 si60ffff.
         SI61 si61ffff. SI62 si62ffff. SI62A si62a.
         SI62B si62b. SI62C si62c. SI62D si62d.
         SI63 si63ffff. SI64 si64ffff. SI65 si65ffff.
         SI65A si65a. SI66 si66ffff. SI67 si67ffff.
         SI68 si68ffff. SI68_1 si68_1ff. SI68_2 si68_2ff.
         SI69 si69ffff. SI69A si69a. SI70 si70ffff.
         SI71 si71ffff. SI72_1 si72_1ff. SI72_2 si72_2ff.
         SI73 si73ffff. SI74 si74ffff. SI75 si75ffff.
         SI76_1 si76_1ff. SI76_2 si76_2ff. SI77 si77ffff.
         SI78A si78a. SI78B si78b. SI78C si78c.
         SI78A_1 si78a_1f. SI78A_2 si78a_2f. SI78A_3 si78a_3f.
         SI79 si79ffff. SI80 si80ffff. SI81 si81ffff.
         SI82 si82ffff. SI83 si83ffff. SI84 si84ffff.
         SI85_1 si85_1ff. SI85_2 si85_2ff. SI87 si87ffff.
         SI88 si88ffff. SI89 si89ffff. SI90 si90ffff.
         SI91 si91ffff. SI92 si92ffff. SI93 si93ffff.
         SI94 si94ffff. SI94A si94a. SI94B si94b.
         SI94C si94c. SI94D si94d. SI95 si95ffff.
         SI96 si96ffff. SI97 si97ffff. SI98 si98ffff.
         SI100 si100fff. SI100A si100a. SI100B si100b.
         SI101 si101fff. SI102 si102fff. SI102B si102b.
         SI102C si102c. SI103 si103fff. SI104 si104fff.
         SI105 si105fff. SI105A si105a. SI105B si105b.
         SI105C si105c. SI106 si106fff. SI107 si107fff.
         SI108 si108fff. SI109 si109fff. SI109A si109a.
         SI110 si110fff. SI111 si111fff. SI111A si111a.
         SI112 si112fff. SI113_1 si113_1f. SI113_2 si113_2f.
         SI114_1 si114_1f. SI114_2 si114_2f. SI115_1 si115_1f.
         SI115_2 si115_2f. SI116 si116fff. SI117 si117fff.
         SI118 si118fff. SI119 si119fff. SI120 si120fff.
         SI120A si120a. SI120B si120b. SI120C si120c.
         SI120D si120d. SI121 si121fff. SI122 si122fff.
         SI123 si123fff. SI124 si124fff. SI125 si125fff.
         SI126 si126fff. SI127 si127fff. SI128 si128fff.
         SI129_1 si129_1f. SI129_2 si129_2f. SI129_3 si129_3f.
         SI130 si130fff. SI131 si131fff. SI132 si132fff.
         SI133 si133fff. SI134_1 si134_1f. SI134_2 si134_2f.
         SI134_3 si134_3f. SI135 si135fff. SI136 si136fff.
         SI137 si137fff. SI137A si137a. SI138 si138fff.
         SI138A si138a. SI139 si139fff. SI139A si139a.
         SI140 si140fff. SI141 si141fff. SI141A si141a.
         SI142 si142fff. SI143 si143fff. SI144 si144fff.
         SI145 si145fff. SI145A si145a. SI146 si146fff.
         SI147A si147a. SI147B si147b. SI147C si147c.
         SI147A_1 si147a_f. SI147A_2 si147a0f. SI147A_3 si147a1f.
         SI148 si148fff. SI149 si149fff. SI150 si150fff.
         SI151_1 si151_1f. SI151_2 si151_2f. SI153 si153fff.
         SI154 si154fff. SI155 si155fff. SI156_1 si156_1f.
         SI156_2 si156_2f. SI156_3 si156_3f. SI157 si157fff.
         SI158 si158fff. SI159 si159fff. SI160 si160fff.
         SI160A si160a. SI161 si161fff. SI161A si161a.
         SI162 si162fff. SI162A si162a. SI163 si163fff.
         SI164 si164fff. SI164A si164a. SI165 si165fff.
         SI166 si166fff. SI167 si167fff. SI168 si168fff.
         SI168A si168a. SI169 si169fff. SI170A si170a.
         SI170B si170b. SI170C si170c. SI170A_1 si170a_f.
         SI170A_2 si170a0f. SI170A_3 si170a1f. SI171 si171fff.
         SI172 si172fff. SI173 si173fff. SI174_1 si174_1f.
         SI174_2 si174_2f. SI176 si176fff. SI177 si177fff.
         SI177A si177a. SI178 si178fff. SI178A si178a.
         SI179 si179fff. SI180 si180fff. SI180A si180a.
         SI181 si181fff. SI182 si182fff. SI182A si182a.
         SI183 si183fff. SI184 si184fff. SI185 si185fff.
         SI186 si186fff. SI187 si187fff. SI188 si188fff.
         SI189 si189fff. SI190 si190fff. SI191 si191fff.
         SI192_1 si192_1f. SI192_2 si192_2f. SI192_3 si192_3f.
         SI193 si193fff. SI194 si194fff. SI195 si195fff.
         SI196 si196fff. SI197 si197fff. SI198 si198fff.
         SI199 si199fff. SI200_1 si200_1f. SI200A si200a.
         SI201_1 si201_1f. SI202_1 si202_1f. SI203_1 si203_1f.
         SI204_1 si204_1f. SI205_1 si205_1f. SI206_1 si206_1f.
         SI208 si208fff. SI209 si209fff. SI210 si210fff.
         SI211 si211fff. SI212 si212fff. SI213 si213fff.
         SI215 si215fff. SI216 si216fff. SI217 si217fff.
         SI217A_1 si217a_f. SI217A_2 si217a0f. SI217A_3 si217a1f.
         SI217B si217b. SI218 si218fff. SI218A si218a.
         SI218B si218b. SI218C si218c. SI218D_1 si218d_f.
         SI218D_2 si218d0f. SI218D_3 si218d1f. SESADUR sesadur.
         SESBDUR sesbdur. SESAODUR sesaodur. SESBODUR sesbodur.
         OUTDUR outdur. DISTRIB1 distribf. DISTINJ distinj.
         DISTSEX distsex. REHNDLA rehndla. REHCNDMA rehcndma.
         REHALLA rehalla. REHNDLB rehndlb. REHCNDMB rehcndmb.
         REHALLB rehallb. SIDEMOA sidemoa. SIDEMOB sidemob.
         SIRHSLA sirhsla. SIRHSLB sirhslb. SIS1 sis1ffff.
         SIS2A sis2a. SIS2B sis2b. SIS2C sis2c.
         SIS2D sis2d. SIS3 sis3ffff. SIS4 sis4ffff.
         SIS5 sis5ffff. SIS6 sis6ffff. SIS7 sis7ffff.
         SIS8 sis8ffff. SIS9 sis9ffff. SIS9A sis9a.
         SIS10 sis10fff. SIS11 sis11fff. SIS12 sis12fff.
         SIS12A sis12a. SIS13 sis13fff. SIS14 sis14fff.
         SIS15 sis15fff. SIS16 sis16fff. SIS17 sis17fff.
         SIS17A sis17a. SIS18 sis18fff. SIS19 sis19fff.
         SIS20 sis20fff. SIS21 sis21fff. SIS22 sis22fff.
         SIS23 sis23fff. SIS24 sis24fff. SIS25 sis25fff.
         SIS26 sis26fff. SIS27 sis27fff. SIS28 sis28fff.
         SIS29 sis29fff. SIS30 sis30fff. SIS31 sis31fff.
         SIS32 sis32fff. SIS33 sis33fff. SIS34 sis34fff.
         SIS35 sis35fff. SIS36A sis36a. SIS36B sis36b.
         SIS36C sis36c. SIS37A sis37a. SIS37B sis37b.
         SIS37C sis37c. SIS38 sis38fff. SIS39 sis39fff.
         SIS40 sis40fff. SIS41 sis41fff. SIS42 sis42fff.
         SIS43 sis43fff. SIS43A sis43a. SIS44 sis44fff.
         SIS45 sis45fff. SIS46 sis46fff. SIS47 sis47fff.
         SIS48 sis48fff. SIS49 sis49fff. SIS50 sis50fff.
         SIS51 sis51fff. SIS52 sis52fff. SIS53 sis53fff.
         SIS54 sis54fff. SIS55 sis55fff. SIS56 sis56fff.
         SIS57 sis57fff. SIS58 sis58fff. SIS59 sis59fff.
         SIS60 sis60fff. SIS61 sis61fff. SIS62A sis62a.
         SIS62B sis62b. SIS62C sis62c. SIS63A sis63a.
         SIS63B sis63b. SIS63C sis63c. SIS64 sis64fff.
         SIS65 sis65fff. SIS66 sis66fff. SIS67 sis67fff.
         SIS68 sis68fff. SIS69 sis69fff. SIS69A sis69a.
         SIS70 sis70fff. SIS71 sis71fff. SIS72 sis72fff.
         SIS73 sis73fff. SIS74 sis74fff. SIS75 sis75fff.
         SIS76 sis76fff. SIS77 sis77fff. SIS78 sis78fff.
         SIS79 sis79fff. SIS80 sis80fff. SIS81 sis81fff.
         SIS82 sis82fff. SIS83 sis83fff. SIS84 sis84fff.
         SIS85 sis85fff. SIS86 sis86fff. SIS87 sis87fff.
         SIS88A sis88a. SIS88B sis88b. SIS88C sis88c.
         SIS89A sis89a. SIS89B sis89b. SIS89C sis89c.
         SIS90 sis90fff. SIS91 sis91fff. SIS92 sis92fff.
         SIS93 sis93fff. SIS94 sis94fff. SIS95 sis95fff.
         SIS96 sis96fff. SIS97 sis97fff. SIS98 sis98fff.
         SIS99 sis99fff. SIS100 sis100ff. SIS101 sis101ff.
         SIS102 sis102ff. SIS103A sis103a. SIS103B sis103b.
         SIS103C sis103c. SIS106 sis106ff. SIS107 sis107ff.
         SIS108 sis108ff. SIS109 sis109ff. SIS110 sis110ff.
         SIS111 sis111ff. SIS112 sis112ff. SIS113 sis113ff.
         SIS114 sis114ff. SIS115 sis115ff. SIS116 sis116ff.
         SIS117A sis117a. SIS117B sis117b. SIS117C sis117c.
         SIS120 sis120ff. SIS121 sis121ff. SIS122 sis122ff.
         SIS123 sis123ff. SIS124 sis124ff. SIS125 sis125ff.
         SIS126 sis126ff. SIS127 sis127ff. SIS128 sis128ff.
         SIS129 sis129ff. SIS130 sis130ff. SIS131A sis131a.
         SIS131B sis131b. SIS131C sis131c. SIS134 sis134ff.
         SIS135 sis135ff. SIS136 sis136ff. SIS137 sis137ff.
         SIS138 sis138ff. SIS139 sis139ff. SIS140 sis140ff.
         SIS141 sis141ff. SIS142 sis142ff. EINUM einum.
         EI1 ei1fffff. EI2_1 ei2_1fff. EI2_2 ei2_2fff.
         EI2_3 ei2_3fff. EI2_4 ei2_4fff. EI2_5 ei2_5fff.
         EI2_6 ei2_6fff. EI3A_1 ei3a_1ff. EI3A_2 ei3a_2ff.
         EI3A_3 ei3a_3ff. EI3A_4 ei3a_4ff. EI3B ei3b.
         EI4A_1 ei4a_1ff. EI4A_2 ei4a_2ff. EI4B_3 ei4b_3ff.
         EI4B_4 ei4b_4ff. EI4B_5 ei4b_5ff. EI4B_6 ei4b_6ff.
         EI5_1 ei5_1fff. EI5_2 ei5_2fff. EI6 ei6fffff.
         EI7A_1 ei7a_1ff. EI7A_2 ei7a_2ff. EI7A_3 ei7a_3ff.
         EI7A_4 ei7a_4ff. EI7A_5 ei7a_5ff. EI7A_6 ei7a_6ff.
         EI7A_7 ei7a_7ff. EI7A_8 ei7a_8ff. EI7A_9 ei7a_9ff.
         EI7A_10 ei7a_10f. EI7A_11 ei7a_11f. EI7A_12 ei7a_12f.
         EI7B_1 ei7b_1ff. EI7B_2 ei7b_2ff. EI7B_3 ei7b_3ff.
         EI7B_4 ei7b_4ff. EI7B_5 ei7b_5ff. EI7B_6 ei7b_6ff.
         EI7B_7 ei7b_7ff. EI7B_8 ei7b_8ff. EI7B_9 ei7b_9ff.
         EI7B_10 ei7b_10f. EI8A_1 ei8a_1ff. EI8A_2 ei8a_2ff.
         EI8A_3 ei8a_3ff. EI8A_4 ei8a_4ff. EI8A_5 ei8a_5ff.
         EI8A_6 ei8a_6ff. EI8A_7 ei8a_7ff. EI8A_8 ei8a_8ff.
         EI8A_9 ei8a_9ff. EI8A_10 ei8a_10f. EI8A_11 ei8a_11f.
         EI8A_12 ei8a_12f. EI8A_13 ei8a_13f. EI8A_14 ei8a_14f.
         EI8B_1 ei8b_1ff. EI8B_2 ei8b_2ff. EI8B_3 ei8b_3ff.
         EI8B_4 ei8b_4ff. EI9 ei9fffff. EI10 ei10ffff.
         EI11_1 ei11_1ff. EI11_2 ei11_2ff. EI11_3 ei11_3ff.
         EI11_4 ei11_4ff. EI11_5 ei11_5ff. EI11_6 ei11_6ff.
         EI11_7 ei11_7ff. EI11_8 ei11_8ff. EI11_9 ei11_9ff.
         EI11_10 ei11_10f. EI11_11 ei11_11f. EI11_12 ei11_12f.
         EI11_13 ei11_13f. EI11_14 ei11_14f. EI11_15 ei11_15f.
         EI12_2 ei12_2ff. EI14_1 ei14_1ff. EI14_2 ei14_2ff.
         EI14_3 ei14_3ff. EI14_4 ei14_4ff. EI14_5 ei14_5ff.
         EIDEMO eidemo. EIRHSL eirhsl. EIACTA eiacta.
         EIACTB eiactb. EIDISTA eidista. EIDISTB eidistb.
         EIDUR eidur. EIADUR eiadur. EIBDUR eibdur.
         EIAODUR eiaodur. EIBODUR eibodur. EIIND eiind.
         EICOUPLE eicouple. EIGROUP eigroup. XDAMC xdamc.
         AINTCOU aintcou. AINTEDU aintedu. AINTBOTH aintboth.
         AINTOTH aintoth. AINTSP aintsp. AINTAV aintav.
         AAVVIDEO aavvideo. AAVHAND aavhand. AAVOTHER aavother.
         AAVSP aavsp. AINTDRUG aintdrug. AINTSEX aintsex.
         ABARRIER abarrier. ASUPPORT asupport. ACUES acues.
         ASETGOAL asetgoal. AINTPER aintper. ATB atb.
         AANATOMY aanatomy. AAPCLIEN aapclien. ASELFHLP aselfhlp.
         ACOMMIT acommit. ACOMPRTN acomprtn. ACOMPMED acompmed.
         ALIFPAIN alifpain. ABLDTRST abldtrst. ADISCRIM adiscrim.
         ADOMVIOL adomviol. AFACACC afacacc. AFAMISS afamiss.
         AFOODPRP afoodprp. AHLTHTX ahlthtx. AHLTHTOP ahlthtop.
         AHOMELES ahomeles. APOSAT aposat. ALIFPATT alifpatt.
         AMORDEMO amordemo. ANEGSKIL anegskil. APEERSUP apeersup.
         AROLES aroles. AREDUBEH aredubeh. APOVERTY apoverty.
         APWRLES apwrles. APROMSLF apromslf. ATBTST atbtst.
         ADISCST adiscst. ARESPECT arespect. AROLPLAY arolplay.
         ASLFEFF aslfeff. ASLFENH aslfenh. ASLFEST aslfest.
         ASKLLTRA asklltra. ASTRMAN astrman. ASOCIALS asocials.
         APHOTDEM aphotdem. ATALID atalid. ATRUST atrust.
         AETHCUL aethcul. AWLLBNG awllbng. AOTH aoth.
         AHIV ahiv. AOTHISS aothiss. ABOTH aboth.
         AHIVFRST ahivfrst. AISSFRST aissfrst. AIND aind.
         AGRP agrp. AGRPSZ agrpsz. AGRPCOMP agrpcomp.
         AOTH_ aoth_. AOTH_SP aoth_sp. APROJOFF aprojoff.
         ASTREET astreet. AVAN avan. AOTHPLAC aothplac.
         AOTHSPPL aothsppl. APREF_ apref_. ASES1 ases1fff.
         ASES2 ases2fff. ASES3 ases3fff. ASES4 ases4fff.
         ASES5 ases5fff. ASES6 ases6fff. ANONE anone.
         APHONE aphone. APHONE_ aphone_. AOUTWOR aoutwor.
         AOUTWOR_ aoutwor_. ADROPSES adropses. ADROPSPE adropspe.
         ASUPGRP asupgrp. ALGTHSES algthses. AOFTNGRP aoftngrp.
         AOTHREIN aothrein. AOTHSP aothsp. AINCENT aincent.
         ADESC adesc. ASTART astart. ACOMP acomp.
         ATOT atot. ATOTSP atotsp. APAID apaid.
         AGENDER agender. AHEDM ahedm. AHEDB ahedb.
         AHEDN ahedn. APEERCON apeercon. ANURSE anurse.
         ADRGCON adrgcon. AOTHINT aothint. AOTHSPIN aothspin.
         ATRANSP atransp. AHIVTEST ahivtest. AHIVCOUN ahivcoun.
         AURINTST aurintst. AOTHIS2 aothis2f. AOTHIS1 aothis1f.
         AOTHIS3 aothis3f. AINDSZ aindsz. AINDCOMP aindcomp.
         LD88HIVP ld88hivp. LD90HIVP ld90hivp. LD92HIVP ld92hivp.
         LD94HIVP ld94hivp. LD96HIVP ld96hivp. LD88ACCP ld88accp.
         LD90ACCP ld90accp. LD92ACCP ld92accp. LD94ACCP ld94accp.
         LD96ACCP ld96accp. LD88HIVI ld88hivi. LD90HIVI ld90hivi.
         LD92HIVI ld92hivi. LD94HIVI ld94hivi. LD96HIVI ld96hivi.
         LD88ACCI ld88acci. LD90ACCI ld90acci. LD92ACCI ld92acci.
         LD94ACCI ld94acci. LD96ACCI ld96acci. LD88PHAV ld88phav.
         LD90PHAV ld90phav. LD92PHAV ld92phav. LD94PHAV ld94phav.
         LD96PHAV ld96phav. LD88PHUS ld88phus. LD90PHUS ld90phus.
         LD92PHUS ld92phus. LD94PHUS ld94phus. LD96PHUS ld96phus.
         LD88PHAC ld88phac. LD90PHAC ld90phac. LD92PHAC ld92phac.
         LD94PHAC ld94phac. LD96PHAC ld96phac. LD88NEAV ld88neav.
         LD90NEAV ld90neav. LD92NEAV ld92neav. LD94NEAV ld94neav.
         LD96NEAV ld96neav. LD88NEUS ld88neus. LD90NEUS ld90neus.
         LD92NEUS ld92neus. LD94NEUS ld94neus. LD96NEUS ld96neus.
         LD88NEAC ld88neac. LD90NEAC ld90neac. LD92NEAC ld92neac.
         LD94NEAC ld94neac. LD96NEAC ld96neac. LD88DBAV ld88dbav.
         LD90DBAV ld90dbav. LD92DBAV ld92dbav. LD94DBAV ld94dbav.
         LD96DBAV ld96dbav. LD88DBUS ld88dbus. LD90DBUS ld90dbus.
         LD92DBUS ld92dbus. LD94DBUS ld94dbus. LD96DBUS ld96dbus.
         LD88DBAC ld88dbac. LD90DBAC ld90dbac. LD92DBAC ld92dbac.
         LD94DBAC ld94dbac. LD96DBAC ld96dbac. LD88SDAV ld88sdav.
         LD90SDAV ld90sdav. LD92SDAV ld92sdav. LD94SDAV ld94sdav.
         LD96SDAV ld96sdav. LD88SDUS ld88sdus. LD90SDUS ld90sdus.
         LD92SDUS ld92sdus. LD94SDUS ld94sdus. LD96SDUS ld96sdus.
         LD88SDAC ld88sdac. LD90SDAC ld90sdac. LD92SDAC ld92sdac.
         LD94SDAC ld94sdac. LD96SDAC ld96sdac. LD88SGAV ld88sgav.
         LD90SGAV ld90sgav. LD92SGAV ld92sgav. LD94SGAV ld94sgav.
         LD96SGAV ld96sgav. LD88SGUS ld88sgus. LD90SGUS ld90sgus.
         LD92SGUS ld92sgus. LD94SGUS ld94sgus. LD96SGUS ld96sgus.
         LD88SGAC ld88sgac. LD90SGAC ld90sgac. LD92SGAC ld92sgac.
         LD94SGAC ld94sgac. LD96SGAC ld96sgac. LD88NE01 ld88ne0f.
         LD90NE01 ld90ne0f. LD92NE01 ld92ne0f. LD94NE01 ld94ne0f.
         LD96NE01 ld96ne0f. LD88NE02 ld88ne1f. LD90NE02 ld90ne1f.
         LD92NE02 ld92ne1f. LD94NE02 ld94ne1f. LD96NE02 ld96ne1f.
         LD88NE03 ld88ne2f. LD90NE03 ld90ne2f. LD92NE03 ld92ne2f.
         LD94NE03 ld94ne2f. LD96NE03 ld96ne2f. LD88NEC1 ld88necf.
         LD90NEC1 ld90necf. LD92NEC1 ld92necf. LD94NEC1 ld94necf.
         LD96NEC1 ld96necf. LD88NEC2 ld88ne3f. LD90NEC2 ld90ne3f.
         LD92NEC2 ld92ne3f. LD94NEC2 ld94ne3f. LD96NEC2 ld96ne3f.
         LD90OP1 ld90op1f. LD92OP1 ld92op1f. LD94OP1 ld94op1f.
         LD96OP1 ld96op1f. LD92OP2 ld92op2f. LD94OP2 ld94op2f.
         LD96OP2 ld96op2f. LD94OP3 ld94op3f. LD96OP3 ld96op3f.
         LD90MAX1 ld90maxf. LD92MAX1 ld92maxf. LD94MAX1 ld94maxf.
         LD96MAX1 ld96maxf. LD94MAX2 ld94ma0f. LD96MAX2 ld96ma0f.
         LD94MAX3 ld94ma1f. LD96MAX3 ld96ma1f. LD90ANN1 ld90annf.
         LD92ANN1 ld92annf. LD94ANN1 ld94annf. LD96ANN1 ld96annf.
         LD96ANN2 ld96an0f. LD88LAWS ld88laws. LD90LAWS ld90laws.
         LD92LAWS ld92laws. LD94LAWS ld94laws. LD96LAWS ld96laws.
         LD88LAWL ld88lawl. LD90LAWL ld90lawl. LD92LAWL ld92lawl.
         LD94LAWL ld94lawl. LD96LAWL ld96lawl. LD88NORX ld88norx.
         LD90NORX ld90norx. LD92NORX ld92norx. LD94NORX ld94norx.
         LD96NORX ld96norx. LD88MINP ld88minp. LD90MINP ld90minp.
         LD92MINP ld92minp. LD94MINP ld94minp. LD96MINP ld96minp.
         LD88ID ld88id. LD90ID ld90id. LD92ID ld92id.
         LD94ID ld94id. LD96ID ld96id. LD88SIG ld88sig.
         LD90SIG ld90sig. LD92SIG ld92sig. LD94SIG ld94sig.
         LD96SIG ld96sig. LD88PRDB ld88prdb. LD90PRDB ld90prdb.
         LD92PRDB ld92prdb. LD94PRDB ld94prdb. LD96PRDB ld96prdb.
         LD88DTPP ld88dtpp. LD90DTPP ld90dtpp. LD92DTPP ld92dtpp.
         LD94DTPP ld94dtpp. LD96DTPP ld96dtpp. LD88DTPR ld88dtpr.
         LD90DTPR ld90dtpr. LD92DTPR ld92dtpr. LD94DTPR ld94dtpr.
         LD96DTPR ld96dtpr. LD88HTCP ld88htcp. LD90HTCP ld90htcp.
         LD92HTCP ld92htcp. LD94HTCP ld94htcp. LD96HTCP ld96htcp.
         LD88HTCR ld88htcr. LD90HTCR ld90htcr. LD92HTCR ld92htcr.
         LD94HTCR ld94htcr. LD96HTCR ld96htcr. LD88STDP ld88stdp.
         LD90STDP ld90stdp. LD92STDP ld92stdp. LD94STDP ld94stdp.
         LD96STDP ld96stdp. LD88STDR ld88stdr. LD90STDR ld90stdr.
         LD92STDR ld92stdr. LD94STDR ld94stdr. LD96STDR ld96stdr.
         LD88HOPP ld88hopp. LD90HOPP ld90hopp. LD92HOPP ld92hopp.
         LD94HOPP ld94hopp. LD96HOPP ld96hopp. LD88HOPR ld88hopr.
         LD90HOPR ld90hopr. LD92HOPR ld92hopr. LD94HOPR ld94hopr.
         LD96HOPR ld96hopr. LD88OOPP ld88oopp. LD90OOPP ld90oopp.
         LD92OOPP ld92oopp. LD94OOPP ld94oopp. LD96OOPP ld96oopp.
         LD88OOPR ld88oopr. LD90OOPR ld90oopr. LD92OOPR ld92oopr.
         LD94OOPR ld94oopr. LD96OOPR ld96oopr. LD88HCMP ld88hcmp.
         LD90HCMP ld90hcmp. LD92HCMP ld92hcmp. LD94HCMP ld94hcmp.
         LD96HCMP ld96hcmp. LD88HCMR ld88hcmr. LD90HCMR ld90hcmr.
         LD92HCMR ld92hcmr. LD94HCMR ld94hcmr. LD96HCMR ld96hcmr.
         LD88OCMP ld88ocmp. LD90OCMP ld90ocmp. LD92OCMP ld92ocmp.
         LD94OCMP ld94ocmp. LD96OCMP ld96ocmp. LD88OCMR ld88ocmr.
         LD90OCMR ld90ocmr. LD92OCMR ld92ocmr. LD94OCMR ld94ocmr.
         LD96OCMR ld96ocmr. LD88MSP ld88msp. LD90MSP ld90msp.
         LD92MSP ld92msp. LD94MSP ld94msp. LD96MSP ld96msp.
         LD88MSR ld88msr. LD90MSR ld90msr. LD92MSR ld92msr.
         LD94MSR ld94msr. LD96MSR ld96msr. LD88HLP ld88hlp.
         LD90HLP ld90hlp. LD92HLP ld92hlp. LD94HLP ld94hlp.
         LD96HLP ld96hlp. LD88HLR ld88hlr. LD90HLR ld90hlr.
         LD92HLR ld92hlr. LD94HLR ld94hlr. LD96HLR ld96hlr.
         LD88OIPP ld88oipp. LD90OIPP ld90oipp. LD92OIPP ld92oipp.
         LD94OIPP ld94oipp. LD96OIPP ld96oipp. LD88OIPR ld88oipr.
         LD90OIPR ld90oipr. LD92OIPR ld92oipr. LD94OIPR ld94oipr.
         LD96OIPR ld96oipr. LDPOPEST ldpopest. LD88IDU ld88idu.
         LD88CONF ld88conf. LD88GEO ld88geo. LD88TRAN ld88tran.
         LD88IMM ld88imm. LD88EMI ld88emi. LD90IDU ld90idu.
         LD90CONF ld90conf. LD90GEO ld90geo. LD90TRAN ld90tran.
         LD90IMM ld90imm. LD90EMI ld90emi. LD92IDU ld92idu.
         LD92CONF ld92conf. LD92GEO ld92geo. LD92TRAN ld92tran.
         LD92IMM ld92imm. LD92EMI ld92emi. LD94IDU ld94idu.
         LD94CONF ld94conf. LD94GEO ld94geo. LD94TRAN ld94tran.
         LD94IMM ld94imm. LD94EMI ld94emi. LD96IDU ld96idu.
         LD96CONF ld96conf. LD96GEO ld96geo. LD96TRAN ld96tran.
         LD96IMM ld96imm. LD96EMI ld96emi. LD88HL ld88hl.
         LD88JAIL ld88jail. LD88TRNS ld88trns. LD88INST ld88inst.
         LD90HL ld90hl. LD90JAIL ld90jail. LD90TRNS ld90trns.
         LD90INST ld90inst. LD92HL ld92hl. LD92JAIL ld92jail.
         LD92TRNS ld92trns. LD92INST ld92inst. LD94HL ld94hl.
         LD94JAIL ld94jail. LD94TRNS ld94trns. LD94INST ld94inst.
         LD96HL ld96hl. LD96JAIL ld96jail. LD96TRNS ld96trns.
         LD96INST ld96inst. LD88MALE ld88male. LD90MALE ld90male.
         LD92MALE ld92male. LD94MALE ld94male. LD96MALE ld96male.
         LD88FEM ld88fem. LD90FEM ld90fem. LD92FEM ld92fem.
         LD94FEM ld94fem. LD96FEM ld96fem. LD88U25 ld88u25f.
         LD90U25 ld90u25f. LD92U25 ld92u25f. LD94U25 ld94u25f.
         LD96U25 ld96u25f. LD882535 ld88253f. LD902535 ld90253f.
         LD922535 ld92253f. LD942535 ld94253f. LD962535 ld96253f.
         LD88G35 ld88g35f. LD90G35 ld90g35f. LD92G35 ld92g35f.
         LD94G35 ld94g35f. LD96G35 ld96g35f. LD88BLA ld88bla.
         LD90BLA ld90bla. LD92BLA ld92bla. LD94BLA ld94bla.
         LD96BLA ld96bla. LD88WHIT ld88whit. LD90WHIT ld90whit.
         LD92WHIT ld92whit. LD94WHIT ld94whit. LD96WHIT ld96whit.
         LD88HISP ld88hisp. LD90HISP ld90hisp. LD92HISP ld92hisp.
         LD94HISP ld94hisp. LD96HISP ld96hisp. LD88OTHR ld88othr.
         LD90OTHR ld90othr. LD92OTHR ld92othr. LD94OTHR ld94othr.
         LD96OTHR ld96othr. LD88OTH ld88oth. LD90OTH ld90oth.
         LD92OTH ld92oth. LD94OTH ld94oth. LD96OTH ld96oth.
         LD88HER ld88her. LD90HER ld90her. LD92HER ld92her.
         LD94HER ld94her. LD96HER ld96her. LD88COC ld88coc.
         LD90COC ld90coc. LD92COC ld92coc. LD94COC ld94coc.
         LD96COC ld96coc. LD88SPED ld88sped. LD90SPED ld90sped.
         LD92SPED ld92sped. LD94SPED ld94sped. LD96SPED ld96sped.
         LD88METH ld88meth. LD90METH ld90meth. LD92METH ld92meth.
         LD94METH ld94meth. LD96METH ld96meth. LD88OTDR ld88otdr.
         LD90OTDR ld90otdr. LD92OTDR ld92otdr. LD94OTDR ld94otdr.
         LD96OTDR ld96otdr. LD88CON1 ld88co0f. LD90CON1 ld90co0f.
         LD92CON1 ld92co0f. LD94CON1 ld94co0f. LD96CON1 ld96co0f.
         LD88HERA ld88hera. LD90HERA ld90hera. LD92HERA ld92hera.
         LD94HERA ld94hera. LD96HERA ld96hera. LD88COCA ld88coca.
         LD90COCA ld90coca. LD92COCA ld92coca. LD94COCA ld94coca.
         LD96COCA ld96coca. LD88SPDA ld88spda. LD90SPDA ld90spda.
         LD92SPDA ld92spda. LD94SPDA ld94spda. LD96SPDA ld96spda.
         LD88META ld88meta. LD90META ld90meta. LD92META ld92meta.
         LD94META ld94meta. LD96META ld96meta. LD88OTHA ld88otha.
         LD90OTHA ld90otha. LD92OTHA ld92otha. LD94OTHA ld94otha.
         LD96OTHA ld96otha. LD88HERP ld88herp. LD90HERP ld90herp.
         LD92HERP ld92herp. LD94HERP ld94herp. LD96HERP ld96herp.
         LD88COCP ld88cocp. LD90COCP ld90cocp. LD92COCP ld92cocp.
         LD94COCP ld94cocp. LD96COCP ld96cocp. LD88SPDP ld88spdp.
         LD90SPDP ld90spdp. LD92SPDP ld92spdp. LD94SPDP ld94spdp.
         LD96SPDP ld96spdp. LD88METP ld88metp. LD90METP ld90metp.
         LD92METP ld92metp. LD94METP ld94metp. LD96METP ld96metp.
         LD88OTHP ld88othp. LD90OTHP ld90othp. LD92OTHP ld92othp.
         LD94OTHP ld94othp. LD96OTHP ld96othp. LD88POP ld88pop.
         LD90POP ld90pop. LD92POP ld92pop. LD94POP ld94pop.
         LD96POP ld96pop. LD88CON2 ld88co1f. LD90CON2 ld90co1f.
         LD92CON2 ld92co1f. LD94CON2 ld94co1f. LD96CON2 ld96co1f.
         LD88GAL ld88gal. LD90GAL ld90gal. LD92GAL ld92gal.
         LD94GAL ld94gal. LD96GAL ld96gal. LD88NGAL ld88ngal.
         LD90NGAL ld90ngal. LD92NGAL ld92ngal. LD94NGAL ld94ngal.
         LD96NGAL ld96ngal. LD88DISP ld88disp. LD90DISP ld90disp.
         LD92DISP ld92disp. LD94DISP ld94disp. LD96DISP ld96disp.
         LD88HAR ld88har. LD90HAR ld90har. LD92HAR ld92har.
         LD94HAR ld94har. LD96HAR ld96har. LD88INIT ld88init.
         LD90INIT ld90init. LD92INIT ld92init. LD94INIT ld94init.
         LD96INIT ld96init. LD88NINI ld88nini. LD90NINI ld90nini.
         LD92NINI ld92nini. LD94NINI ld94nini. LD96NINI ld96nini.
         LD88CON3 ld88co2f. LD90CON3 ld90co2f. LD92CON3 ld92co2f.
         LD94CON3 ld94co2f. LD96CON3 ld96co2f. LD88AVAI ld88avai.
         LD90AVAI ld90avai. LD92AVAI ld92avai. LD94AVAI ld94avai.
         LD96AVAI ld96avai. LD88BLCH ld88blch. LD90BLCH ld90blch.
         LD92BLCH ld92blch. LD94BLCH ld94blch. LD96BLCH ld96blch.
         LDINTYR ldintyr. LDINTSVC ldintsvc. LDINTNED ldintned.
         LDINTSRC ldintsrc. LDINTTRT ldinttrt. LDINTACC ldintacc.
         PHARMAVA pharmava. NEEDLEAV needleav. DIABAVA diabava.
         DEALERAV dealerav. GALLERAV gallerav. AVAIL avail.
         AVAIL88 avail88f. AVAIL90 avail90f. AVAIL92 avail92f.
         AVAIL94 avail94f. AVAIL96 avail96f. PHARMUSE pharmuse.
         NEEDLUSE needluse. DIABUSE diabuse. DLRUSE dlruse.
         GALLERUS gallerus. USED used. USED88 used88ff.
         USED90 used90ff. USED92 used92ff. USED94 used94ff.
         USED96 used96ff. NEP nep. NEP88 nep88fff.
         NEP90 nep90fff. NEP92 nep92fff. NEP94 nep94fff.
         NEP96 nep96fff. INTPRO88 intpro8f. INTPRO90 intpro9f.
         INTPRO92 intpro0f. INTPRO94 intpro1f. INTPRO96 intpro2f.
         RCHD88 rchd88ff. RCHD90 rchd90ff. RCHD92 rchd92ff.
         RCHD94 rchd94ff. RCHD96 rchd96ff. PROGTOT progtot.
         RCHDTOT rchdtot. NORX norx. DRUGTRTP drugtrtp.
         HIVTESTP hivtestp. STDPROG stdprog. HIVORPRG hivorprg.
         OTHORPRG othorprg. HIVCMPRG hivcmprg. OTHCMPRG othcmprg.
         MEDSVPRG medsvprg. HLPROG hlprog. OTHINTPR othintpr.
         DRUGTRTR drugtrtr. HIVTESTR hivtestr. STDRCHD stdrchd.
         HIVORRCH hivorrch. OTHORRCH othorrch. HIVCMRCH hivcmrch.
         OTHCMRCH othcmrch. MEDSVRCH medsvrch. HLRCHD hlrchd.
         OTHINTR othintr. EARLY early. DESIGN design.
          ;
*/

RUN ;
